@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-embed-popup-control.c,v 1.6 2003/10/16 17:28:40 marco Exp $
  */
 
 #include "ephy-embed-popup-control.h"
@@ -37,6 +39,8 @@ typedef enum
 	EMBED_POPUP_ELEMENT
 } EmbedPopupType;
 
+#define EPHY_EMBED_POPUP_CONTROL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_POPUP_CONTROL, EphyEmbedPopupControlPrivate))
+
 struct EphyEmbedPopupControlPrivate
 {
 	EphyEmbedEvent *event;
@@ -243,12 +247,15 @@ ephy_embed_popup_control_class_init (EphyEmbedPopupControlClass *klass)
                                                               "Bonobo control",
                                                               BONOBO_TYPE_CONTROL,
                                                               G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof(EphyEmbedPopupControlPrivate));
 }
 
 static void
 ephy_embed_popup_control_init (EphyEmbedPopupControl *gep)
 {
-        gep->priv = g_new0 (EphyEmbedPopupControlPrivate, 1);
+        gep->priv = EPHY_EMBED_POPUP_CONTROL_GET_PRIVATE (gep);
+
 	gep->priv->control = NULL;
 	gep->priv->embed = NULL;
 	gep->priv->event = NULL;
@@ -258,14 +265,7 @@ ephy_embed_popup_control_init (EphyEmbedPopupControl *gep)
 static void
 ephy_embed_popup_control_finalize (GObject *object)
 {
-	EphyEmbedPopupControl *gep;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_EPHY_EMBED_POPUP_CONTROL (object));
-
-        gep = EPHY_EMBED_POPUP_CONTROL (object);
-
-        g_return_if_fail (gep->priv != NULL);
+	EphyEmbedPopupControl *gep = EPHY_EMBED_POPUP_CONTROL (object);
 
 	if (gep->priv->event)
 	{
@@ -274,8 +274,6 @@ ephy_embed_popup_control_finalize (GObject *object)
 
 	g_free (gep->priv->selection);
 
-        g_free (gep->priv);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -291,11 +289,9 @@ ephy_embed_popup_control_new (BonoboControl *control)
 {
 	EphyEmbedPopupControl *p;
 
-        p = EPHY_EMBED_POPUP_CONTROL (g_object_new (EPHY_EMBED_POPUP_CONTROL_TYPE,
-						      "BonoboControl", control,
-						      NULL));
-
-        g_return_val_if_fail (p->priv != NULL, NULL);
+	p = EPHY_EMBED_POPUP_CONTROL (g_object_new (EPHY_TYPE_EMBED_POPUP_CONTROL,
+						    "BonoboControl", control,
+						    NULL));
 
         return p;
 }
@@ -434,7 +430,7 @@ ephy_embed_popup_control_connect_verbs (EphyEmbedPopupControl *p,
 EphyEmbedEvent *
 ephy_embed_popup_control_get_event (EphyEmbedPopupControl *p)
 {
-	g_return_val_if_fail (IS_EPHY_EMBED_POPUP_CONTROL (p), NULL);
+	g_return_val_if_fail (EPHY_IS_EMBED_POPUP_CONTROL (p), NULL);
 
 	return p->priv->event;
 }
@@ -484,7 +480,6 @@ static void
 save_property_url (EphyEmbedPopupControl *popup,
 		   const char *title,
 		   gboolean ask_dest,
-		   gboolean show_progress,
 		   const char *property)
 {
 	EphyEmbedEvent *info;
@@ -505,15 +500,9 @@ save_property_url (EphyEmbedPopupControl *popup,
 
 	ephy_embed_persist_set_source (persist, location);
 
-	if (show_progress)
-	{
-		ephy_embed_persist_set_flags (persist,
-					      EMBED_PERSIST_SHOW_PROGRESS);
-	}
-
 	ephy_embed_utils_save (window, title,
 			       CONF_STATE_DOWNLOADING_DIR,
-			       ask_dest, FALSE, persist);
+			       ask_dest, persist);
 }
 
 /* commands */
@@ -543,7 +532,7 @@ embed_popup_download_link_cmd (BonoboUIComponent *uic,
 			   _("Download Link"),
 		           eel_gconf_get_boolean
 		           (CONF_ASK_DOWNLOAD_DEST),
-		           TRUE, "link");
+		           "link");
 }
 
 static void
@@ -551,7 +540,7 @@ embed_popup_save_image_as_cmd (BonoboUIComponent *uic,
 			       EphyEmbedPopupControl *popup,
                                const char* verbname)
 {
-	save_property_url (popup, _("Save Image As"), TRUE, FALSE, "image");
+	save_property_url (popup, _("Save Image As"), TRUE, "image");
 }
 
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
@@ -632,7 +621,6 @@ static void
 save_url (EphyEmbedPopupControl *popup,
 	  const char *title,
 	  gboolean ask_dest,
-	  gboolean show_progress,
 	  const char *url)
 {
 	GtkWidget *widget;
@@ -645,15 +633,9 @@ save_url (EphyEmbedPopupControl *popup,
 	persist = ephy_embed_persist_new (popup->priv->embed);
 	ephy_embed_persist_set_source (persist, url);
 
-	if (show_progress)
-	{
-		ephy_embed_persist_set_flags (persist,
-						EMBED_PERSIST_SHOW_PROGRESS);
-	}
-
 	ephy_embed_utils_save (window, title,
 			       CONF_STATE_DOWNLOADING_DIR,
-			       ask_dest, FALSE, persist);
+			       ask_dest, persist);
 }
 
 static void
@@ -665,7 +647,7 @@ embed_popup_save_page_as_cmd (BonoboUIComponent *uic,
 
 	ephy_embed_get_location (popup->priv->embed,
 				   FALSE, &location);
-	save_url (popup, _("Save Page As"), TRUE, FALSE, location);
+	save_url (popup, _("Save Page As"), TRUE, location);
 	g_free (location);
 }
 
@@ -675,7 +657,7 @@ embed_popup_save_background_as_cmd (BonoboUIComponent *uic,
                                     const char* verbname)
 {
 	save_property_url (popup, _("Save Background As"),
-			   TRUE, FALSE, "background_image");
+			   TRUE, "background_image");
 }
 
 static void
