@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-embed-shell.c,v 1.15 2003/10/17 22:40:10 chpe Exp $
  */
 
 #include <config.h>
@@ -22,17 +24,21 @@
 #include "ephy-marshal.h"
 #include "ephy-favicon-cache.h"
 #include "mozilla-embed-single.h"
-#include "ephy-debug.h"
 #include "downloader-view.h"
+#include "ephy-encodings.h"
+#include "ephy-debug.h"
 
 #include <string.h>
 
+#define EPHY_EMBED_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SHELL, EphyEmbedShellPrivate))
+
 struct EphyEmbedShellPrivate
 {
 	EphyHistory *global_history;
 	DownloaderView *downloader_view;
 	EphyFaviconCache *favicon_cache;
 	EphyEmbedSingle *embed_single;
+	EphyEncodings *encodings;
 };
 
 static void
@@ -87,8 +93,11 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
         object_class->finalize = ephy_embed_shell_finalize;
+
 	klass->get_downloader_view = impl_get_downloader_view;
 	klass->get_global_history = impl_get_global_history;
+
+	g_type_class_add_private (object_class, sizeof(EphyEmbedShellPrivate));
 }
 
 static void
@@ -97,24 +106,18 @@ ephy_embed_shell_init (EphyEmbedShell *ges)
 	/* Singleton, globally accessible */
 	embed_shell = ges;
 
-	ges->priv = g_new0 (EphyEmbedShellPrivate, 1);
+	ges->priv = EPHY_EMBED_SHELL_GET_PRIVATE (ges);
 
 	ges->priv->global_history = NULL;
 	ges->priv->downloader_view = NULL;
 	ges->priv->favicon_cache = NULL;
+	ges->priv->encodings = NULL;
 }
 
 static void
 ephy_embed_shell_finalize (GObject *object)
 {
-	EphyEmbedShell *ges;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_EPHY_EMBED_SHELL (object));
-
-        ges = EPHY_EMBED_SHELL (object);
-
-        g_return_if_fail (ges->priv != NULL);
+	EphyEmbedShell *ges = EPHY_EMBED_SHELL (object);
 
 	LOG ("Unref history")
 	if (ges->priv->global_history)
@@ -137,28 +140,25 @@ ephy_embed_shell_finalize (GObject *object)
 		g_object_unref (G_OBJECT (ges->priv->favicon_cache));
 	}
 
+	LOG ("Unref encodings")
+	if (ges->priv->encodings)
+	{
+		g_object_unref (G_OBJECT (ges->priv->encodings));
+	}
+
 	LOG ("Unref embed single")
 	if (ges->priv->embed_single)
 	{
 		g_object_unref (G_OBJECT (ges->priv->embed_single));
 	}
 
-        g_free (ges->priv);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 EphyEmbedShell *
 ephy_embed_shell_new (const char *type)
 {
-	if (strcmp (type, "mozilla") == 0)
-	{
-		return EPHY_EMBED_SHELL (g_object_new
-			(EPHY_EMBED_SHELL_TYPE, NULL));
-	}
-
-	g_assert_not_reached ();
-	return NULL;
+	return g_object_new (EPHY_TYPE_EMBED_SHELL, NULL);
 }
 
 /**
@@ -245,3 +245,13 @@ impl_get_downloader_view (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->downloader_view);
 }
 
+GObject *
+ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
+{
+	if (shell->priv->encodings == NULL)
+	{
+		shell->priv->encodings = ephy_encodings_new ();
+	}
+
+	return G_OBJECT (shell->priv->encodings);
+}
