@@ -14,15 +14,20 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-embed-single.c,v 1.10 2003/10/13 17:38:14 chpe Exp $
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ephy-embed-shell.h"
 #include "ephy-marshal.h"
 #include "ephy-favicon-cache.h"
 #include "mozilla-embed-single.h"
 #include "ephy-debug.h"
+#include "downloader-view.h"
 
 #include <string.h>
 
@@ -32,11 +37,12 @@ enum
 	LAST_SIGNAL
 };
 
+#define EPHY_EMBED_SINGLE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSinglePrivate))
+
 struct EphyEmbedSinglePrivate
 {
 	EphyHistory *global_history;
 	DownloaderView *downloader_view;
-	GList *embeds;
 	EphyFaviconCache *favicon_cache;
 };
 
@@ -44,10 +50,9 @@ static void
 ephy_embed_single_class_init (EphyEmbedSingleClass *klass);
 static void
 ephy_embed_single_init (EphyEmbedSingle *ges);
-static void
-ephy_embed_single_finalize (GObject *object);
 
 static GObjectClass *parent_class = NULL;
+
 static guint ephy_embed_single_signals[LAST_SIGNAL] = { 0 };
 
 GType
@@ -85,8 +90,6 @@ ephy_embed_single_class_init (EphyEmbedSingleClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
-        object_class->finalize = ephy_embed_single_finalize;
-
 	ephy_embed_single_signals[NEW_WINDOW] =
                 g_signal_new ("new_window_orphan",
                               G_OBJECT_CLASS_TYPE (object_class),
@@ -98,50 +101,21 @@ ephy_embed_single_class_init (EphyEmbedSingleClass *klass)
                               2,
                               G_TYPE_POINTER,
 			      G_TYPE_INT);
+
+	g_type_class_add_private (object_class, sizeof(EphyEmbedSinglePrivate));
 }
 
 static void
 ephy_embed_single_init (EphyEmbedSingle *ges)
 {
-	ges->priv = g_new0 (EphyEmbedSinglePrivate, 1);
+	ges->priv = EPHY_EMBED_SINGLE_GET_PRIVATE (ges);
 
 	ges->priv->global_history = NULL;
 	ges->priv->downloader_view = NULL;
-	ges->priv->embeds = NULL;
 
 	ges->priv->favicon_cache = NULL;
 }
 
-static void
-ephy_embed_single_finalize (GObject *object)
-{
-	EphyEmbedSingle *ges;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_EPHY_EMBED_SINGLE (object));
-
-        ges = EPHY_EMBED_SINGLE (object);
-
-        g_return_if_fail (ges->priv != NULL);
-
-        g_free (ges->priv);
-
-        G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-EphyEmbedSingle *
-ephy_embed_single_new (const char *type)
-{
-	if (strcmp (type, "mozilla") == 0)
-	{
-		return EPHY_EMBED_SINGLE (g_object_new
-			(MOZILLA_EMBED_SINGLE_TYPE, NULL));
-	}
-
-	g_assert_not_reached ();
-	return NULL;
-}
-
 gresult
 ephy_embed_single_clear_cache (EphyEmbedSingle *shell)
 {
@@ -165,34 +139,13 @@ ephy_embed_single_load_proxy_autoconf (EphyEmbedSingle *shell,
         return klass->load_proxy_autoconf (shell, url);
 }
 
-gresult
-ephy_embed_single_get_encodings (EphyEmbedSingle *shell,
-				 LanguageGroup group,
-				 gboolean elide_underscores,
-				 GList **encodings)
-{
-	EphyEmbedSingleClass *klass = EPHY_EMBED_SINGLE_GET_CLASS (shell);
-	return klass->get_encodings (shell, group, elide_underscores, encodings);
-}
-
-gresult
-ephy_embed_single_get_language_groups (EphyEmbedSingle *shell,
-			              GList **groups)
-{
-	EphyEmbedSingleClass *klass = EPHY_EMBED_SINGLE_GET_CLASS (shell);
-	return klass->get_language_groups (shell, groups);
-}
-
 gresult
 ephy_embed_single_get_font_list (EphyEmbedSingle *shell,
 				const char *langGroup,
-				const char *fontType,
-				GList **fontList,
-				char **default_font)
+				GList **fontList)
 {
 	EphyEmbedSingleClass *klass = EPHY_EMBED_SINGLE_GET_CLASS (shell);
-        return klass->get_font_list (shell, langGroup, fontType, fontList,
-				     default_font);
+        return klass->get_font_list (shell, langGroup, fontList);
 }
 
 gresult
@@ -307,4 +260,3 @@ ephy_embed_single_free_passwords (EphyEmbedSingle *shell,
 
 	return G_OK;
 }
-
