@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-embed-utils.c,v 1.21 2003/10/17 22:40:10 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,7 +54,6 @@ ephy_embed_utils_save (GtkWidget *window,
 		       const char *title,
 		       const char *default_dir_pref,
 		       gboolean ask_dest,
-		       gboolean with_content,
 		       EphyEmbedPersist *persist)
 {
 	GnomeVFSURI *uri;
@@ -153,13 +154,10 @@ ephy_embed_utils_save (GtkWidget *window,
 		/* set default save dir */
 		eel_gconf_set_string (default_dir_pref, ret_dir);
 		g_free (ret_dir);
-		
 	}
 
         if (ret == G_OK)
         {
-		if (with_content) flags |= EMBED_PERSIST_SAVE_CONTENT;
-
 		ephy_embed_persist_set_flags (persist, flags);
 
 		ephy_embed_persist_set_dest (persist, retPath);
@@ -189,96 +187,6 @@ ephy_embed_utils_save (GtkWidget *window,
 	g_free (target);
 }
 
-/**
- * ephy_embed_utils_build_encodings_submenu:
- * @ui_component: the parent #BonoboUIComponent
- * @path: the bonoboui path where to create the submenu.
- * It's recommended to use a <placeholder/>
- * @fn: callback to report the selected encodings
- * @data: the data passed to the callback
- *
- * Create a encoding submenu using bonobo ui.
- **/
-void
-ephy_embed_utils_build_encodings_submenu (BonoboUIComponent *ui_component,
-					  const char *path,
-					  BonoboUIVerbFn fn,
-					  gpointer view)
-{
-	gchar *tmp, *verb;
-	GString *xml_string;
-	GList *groups, *gl, *encodings, *l;
-	GList *verbs = NULL;
-	EphyEmbedSingle *single;
-
-	single = ephy_embed_shell_get_embed_single (EPHY_EMBED_SHELL (embed_shell));
-	g_return_if_fail (IS_EPHY_EMBED_SHELL (embed_shell));
-
-	START_PROFILER ("Encodings menu")
-
-	ephy_embed_single_get_language_groups (single, &groups);
-	g_return_if_fail (groups != NULL);
-	
-	xml_string = g_string_new (NULL);
-	g_string_append (xml_string, "<submenu name=\"Encoding\" _label=\"_Encoding\">");
-
-	for (gl = groups; gl != NULL; gl = gl->next)
-        {
-		const LanguageGroupInfo *lang_info = (LanguageGroupInfo *) gl->data;
-
-		tmp = g_strdup_printf ("<submenu label=\"%s\" name=\"EncodingGroup%d\">\n", 
-					lang_info->title, lang_info->group);
-		xml_string = g_string_append (xml_string, tmp);
-		g_free (tmp);
-
-		ephy_embed_single_get_encodings (single, lang_info->group,
-						FALSE, &encodings);
-		
-		for (l = encodings; l != NULL; l = l->next)
-                {
-			const EncodingInfo *info = (EncodingInfo *) l->data;
-
-			verb = g_strdup_printf ("Encoding%s", info->encoding);
-			tmp = g_strdup_printf ("<menuitem label=\"%s\" name=\"%s\" verb=\"%s\"/>\n",
-						info->title, verb, verb);
-			xml_string = g_string_append (xml_string, tmp);
-
-			verbs = g_list_prepend (verbs, verb);
-
-			g_free (tmp);
-		}
-
-		g_list_foreach (encodings, (GFunc) encoding_info_free, NULL);
-		g_list_free (encodings);
-
-		g_string_append (xml_string, "</submenu>");
-	}
-
-	g_list_foreach (groups, (GFunc) language_group_info_free, NULL);
-	g_list_free (groups);
-
-	g_string_append (xml_string, "</submenu>");
-
-	bonobo_ui_component_set_translate (ui_component, path,
-					   xml_string->str, NULL);
-
-	verbs = g_list_reverse (verbs);
-
-	for (l = verbs; l != NULL; l = l->next)
-	{
-		bonobo_ui_component_add_verb (ui_component,
-					      (const char *) l->data,
-					      fn, view);
-	}
-
-	g_list_foreach (verbs, (GFunc) g_free, NULL);
-	g_list_free (verbs);
-
-	g_string_free (xml_string, TRUE);
-
-	STOP_PROFILER ("Encodings menu")
-}
-
 /**
  * ephy_embed_utils_handlernotfound_dialog_run:
  * @parent: the dialog parent window
