@@ -30,14 +30,8 @@ void ephy_embed_utils_save			(GtkWidget *window,
 						 const char *title,
 						 const char *default_dir_pref,
 						 gboolean ask_dest,
-						 gboolean with_content,
 						 EphyEmbedPersist *persist);
 
-void ephy_embed_utils_build_encodings_submenu   (BonoboUIComponent *ui_component,
-						 const char *path,
-						 BonoboUIVerbFn fn,
-						 gpointer view);
-
 void ephy_embed_utils_nohandler_dialog_run      (GtkWidget *parent);
 
 G_END_DECLS
