@@ -21,6 +21,7 @@
 
 #include "ephy-embed-types.h"
 #include "ephy-embed-event.h"
+#include "ephy-encodings.h"
 
 #include <glib-object.h>
 #include <glib.h>
@@ -28,15 +29,14 @@
 
 G_BEGIN_DECLS
 
+#define EPHY_TYPE_EMBED			(ephy_embed_get_type ())
+#define EPHY_EMBED(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_EMBED, EphyEmbed))
+#define EPHY_EMBED_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED, EphyEmbedClass))
+#define EPHY_IS_EMBED(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_EMBED))
+#define EPHY_IS_EMBED_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED))
+#define EPHY_EMBED_GET_CLASS(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_EMBED, EphyEmbedClass))
+
 typedef struct EphyEmbedClass EphyEmbedClass;
-
-#define EPHY_EMBED_TYPE             (ephy_embed_get_type ())
-#define EPHY_EMBED(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_EMBED_TYPE, EphyEmbed))
-#define EPHY_EMBED_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST ((vtable), EPHY_EMBED_TYPE, EphyEmbedClass))
-#define IS_EPHY_EMBED(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EPHY_EMBED_TYPE))
-#define IS_EPHY_EMBED_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE ((vtable), EPHY_EMBED_TYPE))
-#define EPHY_EMBED_GET_CLASS(inst)  (G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_EMBED_TYPE, EphyEmbedClass))
-
 typedef struct _EphyEmbed EphyEmbed;
 
 typedef enum
@@ -271,6 +271,8 @@ struct EphyEmbedClass
 						 gint pageNum);
 	gresult   (* set_encoding)         (EphyEmbed *embed,
 					    const char *encoding);
+	gresult   (* get_encoding_info)    (EphyEmbed *embed,
+					    EphyEncodingInfo **info);
 };
 
 GType         ephy_embed_get_type             (void);
@@ -391,6 +393,9 @@ gresult	      ephy_embed_find_next	      (EphyEmbed *embed,
 gresult       ephy_embed_set_encoding         (EphyEmbed *embed,
 					       const char *encoding);
 
+gresult       ephy_embed_get_encoding_info    (EphyEmbed *embed,
+					       EphyEncodingInfo **info);
+
 gresult       ephy_embed_activate             (EphyEmbed *embed);
 
 /* Printing */
