@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-favicon-cache.c,v 1.23 2003/10/16 17:29:48 marco Exp $
  */
 
 #include <libxml/tree.h>
@@ -29,6 +31,7 @@
 #include "ephy-node.h"
 #include "ephy-debug.h"
 
+#define EPHY_FAVICON_CACHE_XML_ROOT    "ephy_favicons_cache"
 #define EPHY_FAVICON_CACHE_XML_VERSION "1.0"
 
 #define EPHY_FAVICON_CACHE_OBSOLETE_DAYS 30
@@ -37,6 +40,8 @@ static void ephy_favicon_cache_class_init (EphyFaviconCacheClass *klass);
 static void ephy_favicon_cache_init (EphyFaviconCache *ma);
 static void ephy_favicon_cache_finalize (GObject *object);
 
+#define EPHY_FAVICON_CACHE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_FAVICON_CACHE, EphyFaviconCachePrivate))
+
 struct EphyFaviconCachePrivate
 {
 	char *directory;
@@ -105,6 +110,8 @@ ephy_favicon_cache_class_init (EphyFaviconCacheClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING);
+
+	g_type_class_add_private (object_class, sizeof(EphyFaviconCachePrivate));
 }
 
 EphyFaviconCache *
@@ -114,39 +121,9 @@ ephy_favicon_cache_new (void)
 
 	cache = EPHY_FAVICON_CACHE (g_object_new (EPHY_TYPE_FAVICON_CACHE, NULL));
 
-	g_return_val_if_fail (cache->priv != NULL, NULL);
-
 	return cache;
 }
 
-static void
-ephy_favicon_cache_load (EphyFaviconCache *eb)
-{
-	xmlDocPtr doc;
-	xmlNodePtr root, child;
-
-	if (g_file_test (eb->priv->xml_file, G_FILE_TEST_EXISTS) == FALSE)
-		return;
-
-	doc = xmlParseFile (eb->priv->xml_file);
-	if (doc == NULL)
-	{
-		g_warning ("Failed to load favicon cache.\n");
-		return;
-	}
-
-	root = xmlDocGetRootElement (doc);
-
-	for (child = root->children; child != NULL; child = child->next)
-	{
-		EphyNode *node;
-
-		node = ephy_node_new_from_xml (eb->priv->db, child);
-	}
-
-	xmlFreeDoc (doc);
-}
-
 static gboolean
 icon_is_obsolete (EphyNode *node, GDate *now)
 {
@@ -262,7 +239,7 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 {
 	EphyNodeDb *db;
 
-	cache->priv = g_new0 (EphyFaviconCachePrivate, 1);
+	cache->priv = EPHY_FAVICON_CACHE_GET_PRIVATE (cache);
 
 	db = ephy_node_db_new (EPHY_NODE_DB_SITEICONS);
 	cache->priv->db = db;
@@ -304,7 +281,9 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 				         (EphyNodeCallback) icons_removed_cb,
 				         G_OBJECT (cache));
 
-	ephy_favicon_cache_load (cache);
+	ephy_node_db_load_from_file (cache->priv->db, cache->priv->xml_file,
+				     EPHY_FAVICON_CACHE_XML_ROOT,
+				     EPHY_FAVICON_CACHE_XML_VERSION);
 }
 
 static gboolean
@@ -339,17 +318,10 @@ cleanup_downloads_hash (EphyFaviconCache *cache)
 static void
 ephy_favicon_cache_finalize (GObject *object)
 {
-	EphyFaviconCache *cache;
+	EphyFaviconCache *cache = EPHY_FAVICON_CACHE (object);
 
 	LOG ("Finalize favicon cache")
 
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (EPHY_IS_FAVICON_CACHE (object));
-
-	cache = EPHY_FAVICON_CACHE (object);
-
-	g_return_if_fail (cache->priv != NULL);
-
 	cleanup_downloads_hash (cache);
 	remove_obsolete_icons (cache);
 	ephy_favicon_cache_save (cache);
@@ -363,8 +335,6 @@ ephy_favicon_cache_finalize (GObject *object)
 
 	g_object_unref (cache->priv->db);
 
-	g_free (cache->priv);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -418,7 +388,8 @@ ephy_favicon_cache_download (EphyFaviconCache *cache,
 	persist = ephy_embed_persist_new (NULL);
 
 	ephy_embed_persist_set_max_size (persist, 100);
-	ephy_embed_persist_set_flags    (persist, EMBED_PERSIST_BYPASSCACHE);
+	ephy_embed_persist_set_flags    (persist, EMBED_PERSIST_BYPASSCACHE |
+						  EMBED_PERSIST_NO_VIEW);
 	ephy_embed_persist_set_source   (persist, favicon_url);
 	ephy_embed_persist_set_dest     (persist, dest);
 
