@@ -159,7 +159,6 @@ extern "C" {
 #include "ephy-gui.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
-#include "ProgressListener.h"
 #include "ContentHandler.h"
 
 #include <gtk/gtkentry.h>
@@ -184,28 +183,23 @@ extern "C" {
 #include "nsString.h"
 #include "nsIURI.h"
 #include "nsIURL.h"
-#include "nsIMIMEInfo.h"
 #include "nsIChannel.h"
-#include "nsIFTPChannel.h"
 #include "nsILocalFile.h"
 #include "nsIPrefService.h"
 #include "nsIDOMWindow.h"
 #include "nsIDOMWindowInternal.h"
+#include "nsIMIMEInfo.h"
 
 class GContentHandler;
-class GDownloadProgressListener;
+//class GDownloadProgressListener;
 struct MimeAskActionDialog;
 struct HelperAppChooserDialog;
 
-extern "C"
-void mime_ask_dialog_save_clicked_cb (GtkButton *button,
-				      MimeAskActionDialog *dialog);
-extern "C"
-void mime_ask_dialog_open_clicked_cb (GtkButton *button,
-				      MimeAskActionDialog *dialog);
-extern "C"
-gint mime_ask_dialog_cancel_clicked_cb (GtkButton *button,
-					MimeAskActionDialog *dialog);
+enum
+{
+	RESPONSE_SAVE = 1,
+	RESPONSE_OPEN = 2
+};
 
 /*
  * MimeAskActionDialog: the representation of dialogs used to ask
@@ -231,8 +225,7 @@ NS_IMPL_ISUPPORTS1(GContentHandler, nsIHelperAppLauncherDialog)
 
 GContentHandler::GContentHandler() : mUri(nsnull),
 				     mMimeType(nsnull),
-				     mDownloadCanceled(PR_FALSE),
-				     mHelperProgress(PR_FALSE)
+				     mDownloadCanceled(PR_FALSE)
 {
 	NS_INIT_ISUPPORTS();
 	/* member initializers and constructor code */
@@ -249,10 +242,20 @@ GContentHandler::~GContentHandler()
 // begin nsIHelperAppLauncher impl
 ////////////////////////////////////////////////////////////////////////////////
 
+#if MOZILLA_SNAPSHOT > 9
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
+NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
+				    nsISupports *aContext,
+				    PRBool aForced)
+#else
 NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aContext)
+#endif
 {
+	/* aForced reflects if the content being sent is normally viewable
+	 * in mozilla or not. That fact doesn't affect us, so ignore it
+         */
+
 	nsresult rv;
 
 	mLauncher = aLauncher;
@@ -265,8 +268,11 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 }
 
 /* nsILocalFile promptForSaveToFile (in nsISupports aWindowContext, in wstring aDefaultFile, in wstring aSuggestedFileExtension); */
-NS_IMETHODIMP GContentHandler::
-		PromptForSaveToFile(nsISupports *aWindowContext,
+NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
+#if MOZILLA_SNAPSHOT > 10
+				    nsIHelperAppLauncher *aLauncher,
+#endif				    
+				    nsISupports *aWindowContext,
 				    const PRUnichar *aDefaultFile,
 				    const PRUnichar *aSuggestedFileExtension,
 				    nsILocalFile **_retval)
@@ -281,8 +287,11 @@ NS_IMETHODIMP GContentHandler::
 	nsCOMPtr<nsILocalFile> saveDir;
 	char *dirName;
 	
-	/* FIXME persist download dir */
-	dirName = g_strdup (g_get_home_dir());
+	dirName = eel_gconf_get_string (CONF_STATE_DOWNLOADING_DIR);
+	if (dirName == NULL)
+	{
+		dirName = g_strdup (g_get_home_dir());
+	}
 
 	saveDir = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
 	saveDir->InitWithPath (NS_ConvertUTF8toUCS2(dirName));
@@ -292,45 +301,52 @@ NS_IMETHODIMP GContentHandler::
 
 	PRInt16 okToSave = nsIFilePicker::returnCancel;
 
-	if (okToSave == nsIFilePicker::returnCancel)
+	nsCOMPtr<nsIFilePicker> filePicker =
+				do_CreateInstance (G_FILEPICKER_CONTRACTID);
+
+	const nsAString &title = NS_ConvertUTF8toUCS2(_("Select the destination filename"));
+
+	filePicker->Init (windowInternal,
+			   PromiseFlatString(title).get(), 
+			   nsIFilePicker::modeSave);
+	filePicker->SetDefaultString (aDefaultFile);
+	filePicker->SetDisplayDirectory (saveDir);
+
+	filePicker->Show (&okToSave);
+
+	if (okToSave == nsIFilePicker::returnOK)
 	{
-		nsCOMPtr<nsIFilePicker> filePicker =
-					do_CreateInstance (G_FILEPICKER_CONTRACTID);
+		filePicker->GetFile (getter_AddRefs(saveFile));
 
-		const nsAString &title = NS_ConvertUTF8toUCS2(_("Select the destination filename"));
+		nsString uFileName;
+		saveFile->GetPath(uFileName);
+		const nsCString &aFileName = NS_ConvertUCS2toUTF8(uFileName);
 
-		filePicker->Init (windowInternal,
-				   PromiseFlatString(title).get(), 
-				   nsIFilePicker::modeSave);
-		filePicker->SetDefaultString (aDefaultFile);
-		filePicker->SetDisplayDirectory (saveDir);
+		char *dir = g_path_get_dirname (aFileName.get());
 
-		filePicker->Show (&okToSave);
+		eel_gconf_set_string (CONF_STATE_DOWNLOADING_DIR, dir);
+		g_free (dir);
 
-		if (okToSave == nsIFilePicker::returnOK)
-		{
-			filePicker->GetFile (getter_AddRefs(saveFile));
-		}
-	}
-
-	if (okToSave == nsIFilePicker::returnCancel)
-		return NS_ERROR_FAILURE;
-	else
-	{
 		nsCOMPtr<nsIFile> directory;
 		rv = saveFile->GetParent (getter_AddRefs(directory));
 
 		NS_IF_ADDREF (*_retval = saveFile);
 		return NS_OK;
 	}
+	else
+	{
+		return NS_ERROR_FAILURE;
+	}
 }
 
+#if MOZILLA_SNAPSHOT < 10
 /* void showProgressDialog (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_METHOD GContentHandler::ShowProgressDialog(nsIHelperAppLauncher *aLauncher,
 					      nsISupports *aContext)
 {
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
+#endif
 
 ////////////////////////////////////////////////////////////////////////////////
 // begin local public methods impl
@@ -393,12 +409,6 @@ NS_METHOD GContentHandler::LaunchHelperApp (void)
 	return NS_OK;
 }
 
-NS_METHOD GContentHandler::ShowHelperProgressDialog (void)
-{
-	mHelperProgress = PR_TRUE;
-	return ShowProgressDialog (mLauncher,mContext);
-}
-
 NS_METHOD GContentHandler::GetLauncher (nsIHelperAppLauncher * *_retval)
 {
 	NS_IF_ADDREF (*_retval = mLauncher);
@@ -444,15 +454,20 @@ NS_METHOD GContentHandler::SetHelperApp(GnomeVFSMimeApplication *aHelperApp,
 NS_METHOD GContentHandler::SynchroniseMIMEInfo (void)
 {
 	nsresult rv;
+	char *command_with_path;
+
 	nsCOMPtr<nsIMIMEInfo> mimeInfo;
 	rv = mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
 	if(NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
+	command_with_path = g_find_program_in_path (mHelperApp->command);
+	if (command_with_path == NULL) return NS_ERROR_FAILURE;
 	nsCOMPtr<nsILocalFile> helperFile;
-	rv = NS_NewNativeLocalFile(nsDependentCString(mHelperApp->command),
+	rv = NS_NewNativeLocalFile(nsDependentCString(command_with_path),
 				   PR_TRUE,
 				   getter_AddRefs(helperFile));
 	if(NS_FAILED(rv)) return NS_ERROR_FAILURE;
+	g_free (command_with_path);
 
 	rv = mimeInfo->SetPreferredApplicationHandler(helperFile);
 	if(NS_FAILED(rv)) return NS_ERROR_FAILURE;	
@@ -483,19 +498,19 @@ NS_METHOD GContentHandler::Init (void)
 	nsCOMPtr<nsIMIMEInfo> MIMEInfo;
 	rv = mLauncher->GetMIMEInfo (getter_AddRefs(MIMEInfo));
 	rv = MIMEInfo->GetMIMEType (&mMimeType);
-	
+
+#if MOZILLA_SNAPSHOT > 11
+	rv = mLauncher->GetSource(getter_AddRefs(mUri));
+	rv = mLauncher->GetTargetFile(getter_AddRefs(mTempFile));
+#else
 	rv = mLauncher->GetDownloadInfo(getter_AddRefs(mUri),
 					&mTimeDownloadStarted,
 					getter_AddRefs(mTempFile));
+#endif
+	
 	rv = mUri->GetSpec (mUrl);
 	rv = mUri->GetScheme (mScheme);
-#if 0
-	/* GetSource seems redundant and isn't in 0.9 This code is here while
-	   it remains unclear what GetSource is for. --phil */
-	nsCOMPtr<nsIURI> uri;
-	rv = mLauncher->GetSource(getter_AddRefs(uri));
-	rv = uri->GetSpec (mUrl);
-#endif	
+
 	ProcessMimeInfo ();
 
 	return NS_OK;
@@ -543,6 +558,7 @@ MimeAskActionDialog::MimeAskActionDialog(GContentHandler *aContentHandler,
 					 mContentHandler(aContentHandler),
 					 mParent(aParentWidget)
 {
+	GdkPixbuf *mime_icon;
 	GtkWidget *label;
 	GtkWidget *dialogWidget;
 	const char *description;
@@ -556,8 +572,9 @@ MimeAskActionDialog::MimeAskActionDialog(GContentHandler *aContentHandler,
 
 	GtkWidget *aMimeIcon = glade_xml_get_widget (mGXml,
 						     "mime_ask_action_icon");
-	gtk_image_set_from_file(GTK_IMAGE(aMimeIcon),
-				gnome_vfs_mime_get_icon(aMimeType));						     
+	mime_icon = ephy_gui_get_pixbuf_from_mime_type (aMimeType, 32);
+	gtk_image_set_from_pixbuf (GTK_IMAGE(aMimeIcon), mime_icon);
+	g_object_unref (mime_icon);
 
 	description = gnome_vfs_mime_get_description (aMimeType);
 	if (!description) description = aMimeType;
@@ -587,8 +604,8 @@ MimeAskActionDialog::~MimeAskActionDialog()
 // begin MIMEAskActionDialog callbacks.
 ////////////////////////////////////////////////////////////////////////////////
 
-extern "C" void
-mime_ask_dialog_save_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
+static void
+mime_ask_dialog_save (MimeAskActionDialog *dialog)
 {
 	gtk_widget_hide (glade_xml_get_widget (dialog->mGXml, 
 					       "mime_ask_action_dialog"));
@@ -603,7 +620,7 @@ mime_ask_dialog_save_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
 }
 
 static void
-mime_ask_dialog_download_cancel (MimeAskActionDialog *dialog)
+mime_ask_dialog_cancel (MimeAskActionDialog *dialog)
 {
 	nsresult rv;
 	nsCOMPtr<nsIHelperAppLauncher> launcher;
@@ -614,8 +631,8 @@ mime_ask_dialog_download_cancel (MimeAskActionDialog *dialog)
 	delete dialog;
 }
 
-extern "C" void
-mime_ask_dialog_open_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
+static void
+mime_ask_dialog_open (MimeAskActionDialog *dialog)
 {
 	nsresult rv;
 	nsCOMPtr<nsIHelperAppLauncher> launcher;
@@ -630,15 +647,24 @@ mime_ask_dialog_open_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
 	}
 	else
 	{	
-		mime_ask_dialog_download_cancel (dialog);
+		mime_ask_dialog_cancel (dialog);
 		ephy_embed_utils_nohandler_dialog_run (dialog->mParent);
 	}
 }
 
-extern "C" gint
-mime_ask_dialog_cancel_clicked_cb (GtkButton *button,
-				   MimeAskActionDialog *dialog)
+extern "C" void
+mime_ask_dialog_response_cb (GtkDialog *gtkdialog, int response, MimeAskActionDialog *dialog)
 {
-	mime_ask_dialog_download_cancel (dialog);
-	return 0; /* FIXME: philipl, is this the right thing to return? */
+	switch (response)
+	{
+		case RESPONSE_SAVE:
+			mime_ask_dialog_save (dialog);
+			break;
+		case RESPONSE_OPEN:
+			mime_ask_dialog_open (dialog);
+			break;
+		default:
+			mime_ask_dialog_cancel (dialog);
+			break;
+	}
 }
