@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,11 +14,17 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: EphyWrapper.cpp,v 1.25 2003/10/17 22:57:27 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "EphyWrapper.h"
 #include "GlobalHistory.h"
-#include "ProgressListener.h"
+//#include "ProgressListener.h"
 #include "ephy-embed.h"
 #include "ephy-string.h"
 
@@ -66,6 +72,8 @@
 #include "nsIDOMHTMLElement.h"
 #include "nsIDeviceContext.h"
 #include "nsIPresContext.h"
+#include "nsIAtom.h"
+#include "nsIDocumentCharsetInfo.h"
 #include "ContentHandler.h"
 #include "EphyEventListener.h"
 
@@ -685,7 +693,7 @@ nsresult EphyWrapper::ForceEncoding (const char *encoding)
 								  &result);
 	if (NS_FAILED(result) || !mdv) return NS_ERROR_FAILURE;
 
-#if MOZILLA_SNAPSHOT > 8
+#if MOZILLA_SNAPSHOT > 9 
 	result = mdv->SetForceCharacterSet (nsDependentCString(encoding));
 #else
 	result = mdv->SetForceCharacterSet (NS_ConvertUTF8toUCS2(encoding).get());
@@ -749,3 +757,119 @@ nsresult EphyWrapper::PopTargetDocument ()
 
 	return NS_OK;
 }
+
+nsresult EphyWrapper::GetEncodingInfo (EphyEncodingInfo **infoptr)
+{
+	nsresult result;
+	EphyEncodingInfo *info;
+
+	nsCOMPtr<nsIDOMDocument> domDoc;
+	result = GetDOMDocument (getter_AddRefs(domDoc));
+	if (NS_FAILED (result) || !domDoc) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIDocument> doc = do_QueryInterface(domDoc, &result);
+	if (NS_FAILED (result) || !doc) return NS_ERROR_FAILURE;
+
+	info = g_new0 (EphyEncodingInfo, 1);
+	*infoptr = info;
+
+#if MOZILLA_SNAPSHOT >= 10
+	nsCAutoString enc;	
+	result = doc->GetDocumentCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+
+	info->encoding = g_strdup (enc.get());
+#else
+	nsAutoString enc;
+	result = doc->GetDocumentCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+
+	info->encoding = g_strdup (NS_ConvertUCS2toUTF8(enc).get());
+#endif
+
+	PRInt32 source;
+	result = doc->GetDocumentCharacterSetSource (&source);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->encoding_source = (EphyEncodingSource) source;
+
+	nsCOMPtr<nsIDocShell> ds;
+	result = GetDocShell (getter_AddRefs(ds));
+	if (NS_FAILED(result) || !ds) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIDocumentCharsetInfo> ci;
+	result = ds->GetDocumentCharsetInfo (getter_AddRefs (ci));
+	if (NS_FAILED(result) || !ci) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIAtom> atom;
+	result = ci->GetForcedCharset (getter_AddRefs (atom));
+	if (NS_FAILED(result)) return NS_ERROR_FAILURE;
+	if (atom)
+	{
+		nsCAutoString atomstr;
+		atom->ToUTF8String (atomstr);
+		info->forced_encoding = g_strdup (atomstr.get());
+	}
+
+	result = ci->GetParentCharset (getter_AddRefs (atom));
+	if (NS_FAILED(result)) return NS_ERROR_FAILURE;
+	if (atom)
+	{
+		nsCAutoString atomstr;
+		atom->ToUTF8String (atomstr);
+		info->parent_encoding = g_strdup (atomstr.get());
+	}
+
+	result = ci->GetParentCharsetSource (&source);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->parent_encoding_source = (EphyEncodingSource) source;
+
+	nsCOMPtr<nsIContentViewer> contentViewer;	
+	result = ds->GetContentViewer (getter_AddRefs(contentViewer));
+	if (!NS_SUCCEEDED (result) || !contentViewer) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer,
+								  &result);
+	if (NS_FAILED(result) || !mdv) return NS_ERROR_FAILURE;
+
+#if MOZILLA_SNAPSHOT >= 10
+	result = mdv->GetDefaultCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->default_encoding = g_strdup (enc.get());
+
+	result = mdv->GetForceCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->forced_encoding = g_strdup (enc.get());
+
+	result = mdv->GetHintCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->hint_encoding = g_strdup (enc.get());
+
+	result = mdv->GetPrevDocCharacterSet (enc);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->prev_doc_encoding = g_strdup (enc.get());
+#else
+	PRUnichar *str;
+
+	result = mdv->GetDefaultCharacterSet (&str);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->default_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
+
+	result = mdv->GetForceCharacterSet (&str);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->forced_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
+
+	result = mdv->GetHintCharacterSet (&str);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->hint_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
+
+	result = mdv->GetPrevDocCharacterSet (&str);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->prev_doc_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
+#endif
+
+	mdv->GetHintCharacterSetSource (&source);
+	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
+	info->hint_encoding_source = (EphyEncodingSource) source;
+
+	return NS_OK;
+}
