@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,14 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: EventContext.cpp,v 1.12 2003/10/15 19:16:10 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "EventContext.h"
 #include "nsIDOMEventTarget.h"
 #include "nsIDocument.h"
@@ -140,7 +146,7 @@ nsresult EventContext::ResolveBaseURL (nsIDocument *doc, const nsAString &relurl
 {
 	nsresult rv;
 	nsCOMPtr<nsIURI> base;
-#if MOZILLA_SNAPSHOT > 9
+#if MOZILLA_SNAPSHOT > 9 
 	rv = doc->GetBaseURL (getter_AddRefs(base));
 #else
 	rv = doc->GetBaseURL (*getter_AddRefs(base));
