@@ -32,6 +32,10 @@
  * ContentHandler for a way to do this.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "ephy-string.h"
 #include "ephy-gui.h"
 
@@ -75,8 +79,7 @@
 /* Implementation file */
 NS_IMPL_ISUPPORTS1(GFilePicker, nsIFilePicker)
 
-GFilePicker::GFilePicker(FileFormat *aFileFormats) :
-			mFileFormats(aFileFormats)
+GFilePicker::GFilePicker()
 {
 	NS_INIT_ISUPPORTS();
 
@@ -243,33 +246,6 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 		gtk_window_set_transient_for(GTK_WINDOW(mFileSelector),
 					     GTK_WINDOW(mParentWidget));
 
-	if (mFileFormats)
-	{
-		mFormatChooser = gtk_option_menu_new();
-		GtkMenu *options = GTK_MENU(gtk_menu_new());
-
-		FileFormat *current = mFileFormats;
-		while (current->description != NULL)
-		{
-			/* FIXME: the label should include the extensions too */
-			gchar *label = current->description;
-			GtkWidget *item = gtk_menu_item_new_with_label(label);
-			gtk_widget_show(item);
-			gtk_menu_shell_append(GTK_MENU_SHELL(options), item);
-			current++;
-		}
-		gtk_option_menu_set_menu(GTK_OPTION_MENU(mFormatChooser),
-					 GTK_WIDGET(options));
-		gtk_widget_show(mFormatChooser);
-		gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION (mFileSelector)->action_area),
-				   mFormatChooser,
-				   FALSE, TRUE, 0);
-	}
-	else
-	{
-		mFormatChooser = NULL;
-	}
-
 	if (mMode == nsIFilePicker::modeGetFolder)
 	{
 		gtk_widget_set_sensitive(GTK_FILE_SELECTION(mFileSelector)
@@ -280,16 +256,17 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 
 	gint retVal = gtk_dialog_run(GTK_DIALOG(mFileSelector));
 	
-	if (retVal == GTK_RESPONSE_OK)
-	{
-		HandleFilePickerResult(_retval);
-	}
-	else
+	HandleFilePickerResult();
+
+	if (retVal != GTK_RESPONSE_OK)
 	{
 		*_retval = returnCancel;
 	}
+	else
+	{	
+		ValidateFilePickerResult(_retval);
+	}
 
-	gtk_widget_hide(mFileSelector);
 	gtk_widget_destroy(mFileSelector);
 
 	return NS_OK;
@@ -405,24 +382,12 @@ NS_METHOD GFilePicker::SanityCheck (PRBool *retIsSane)
 // begin local private methods impl
 ////////////////////////////////////////////////////////////////////////////////
 
-NS_METHOD GFilePicker::HandleFilePickerResult(PRInt16 *retval)
+NS_METHOD GFilePicker::HandleFilePickerResult()
 {
-	*retval = returnCancel;
-	nsresult rv;
-
 	const char *fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(mFileSelector));
 
 	if (!fileName || strlen(fileName) == 0) return NS_ERROR_FAILURE;
 
-	if (mMode == nsIFilePicker::modeSave)
-	{
-		if (!ephy_gui_confirm_overwrite_file (mFileSelector,
-					              fileName))
-		{
-			return NS_OK;
-		}
-	}
-
 	const nsACString &cFileName = nsDependentCString(fileName);
 	mFile->InitWithNativePath(cFileName);
 
@@ -439,25 +404,26 @@ NS_METHOD GFilePicker::HandleFilePickerResult(PRInt16 *retval)
 		mFile->GetNativeLeafName(mDefaultString);
 	}
 
+	return NS_OK;
+}
+
+NS_METHOD GFilePicker::ValidateFilePickerResult(PRInt16 *retval)
+{
+	nsresult rv;
+	const char *fileName = gtk_file_selection_get_filename(GTK_FILE_SELECTION(mFileSelector));
+
+	*retval = returnCancel;
+
 	PRBool passesSanityCheck;
 	rv = SanityCheck(&passesSanityCheck);
 	if (NS_SUCCEEDED(rv) && !passesSanityCheck) return NS_ERROR_FAILURE;
 
-	if (mFormatChooser)
+	if (mMode == nsIFilePicker::modeSave)
 	{
-		GtkWidget *menu = gtk_option_menu_get_menu 
-			(GTK_OPTION_MENU(mFormatChooser));
-		GtkWidget *selected = gtk_menu_get_active (GTK_MENU(menu));
-
-		gint i(0);
-		for (GList *iterator = GTK_MENU_SHELL(menu)->children ;
-		     iterator ; iterator = iterator->next, i++)
+		if (!ephy_gui_confirm_overwrite_file (mFileSelector,
+					              fileName))
 		{
-			if (iterator->data == selected) 
-			{
-				mSelectedFileFormat = i;
-				break;
-			}
+			return NS_OK;
 		}
 	}
 
@@ -465,5 +431,3 @@ NS_METHOD GFilePicker::HandleFilePickerResult(PRInt16 *retval)
 
 	return NS_OK;
 }
-
-
