@@ -22,15 +22,17 @@
 
 #include "ContentHandler.h"
 #include "FilePicker.h"
-#include "FtpProtocolHandler.h"
 #include "GlobalHistory.h"
-#include "IRCProtocolHandler.h"
-#include "MailtoProtocolHandler.h"
+#include "ExternalProtocolHandlers.h"
 #include "PrintingPromptService.h"
-#include "ProgressListener.h"
+#include "MozDownload.h"
 #include "ExternalProtocolService.h"
 #include "EphyAboutRedirector.h"
 
+#ifdef HAVE_MOZILLA_PSM
+#include "GtkNSSDialogs.h"
+#endif
+
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
 #include <nsCOMPtr.h>
@@ -39,15 +41,20 @@
 #include <glib.h>
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutRedirector)
-NS_GENERIC_FACTORY_CONSTRUCTOR(GProgressListener)
+NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)	
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GIRCProtocolHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFtpProtocolHandler)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GNewsProtocolHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GExternalProtocolService)
 
+#ifdef HAVE_MOZILLA_PSM
+NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
+#endif
+
 static const nsModuleComponentInfo sAppComps[] = {
 	{
 		G_EXTERNALPROTOCOLSERVICE_CLASSNAME,
@@ -56,16 +63,10 @@ static const nsModuleComponentInfo sAppComps[] = {
  		GExternalProtocolServiceConstructor
 	},
 	{
-		G_PROGRESSDIALOG_CLASSNAME,
-		G_PROGRESSDIALOG_CID,
-		G_PROGRESSDIALOG_CONTRACTID,
-		GProgressListenerConstructor
-	},
-	{
-		G_PROGRESSDIALOG_CLASSNAME,
-		G_PROGRESSDIALOG_CID,
+		MOZ_DOWNLOAD_CLASSNAME,
+		MOZ_DOWNLOAD_CID,
 		NS_DOWNLOAD_CONTRACTID,
-		GProgressListenerConstructor
+		MozDownloadConstructor
 	},
 	{
 		G_FILEPICKER_CLASSNAME,
@@ -73,6 +74,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		G_FILEPICKER_CONTRACTID,
 		GFilePickerConstructor
 	},
+#ifdef HAVE_MOZILLA_PSM
+	{
+		GTK_NSSDIALOGS_CLASSNAME,
+		GTK_NSSDIALOGS_CID,
+		NS_BADCERTLISTENER_CONTRACTID,
+		GtkNSSDialogsConstructor
+	},
+#endif
 	{
 		NS_IHELPERAPPLAUNCHERDLG_CLASSNAME,
 		G_CONTENTHANDLER_CID,
@@ -103,6 +112,18 @@ static const nsModuleComponentInfo sAppComps[] = {
 		G_IRC_CONTENT_CONTRACTID,
 		GIRCProtocolHandlerConstructor
 	},
+	{
+		G_NEWS_PROTOCOL_CLASSNAME,
+		G_NEWS_PROTOCOL_CID,
+		G_NEWS_PROTOCOL_CONTRACTID,
+		GNewsProtocolHandlerConstructor
+	},
+	{
+		G_NEWS_CONTENT_CLASSNAME,
+		G_NEWS_PROTOCOL_CID,
+		G_NEWS_CONTENT_CONTRACTID,
+		GNewsProtocolHandlerConstructor
+	},
 	{
 		G_FTP_CONTENT_CLASSNAME,
 		G_FTP_PROTOCOL_CID,
@@ -173,13 +194,11 @@ static const nsModuleComponentInfo sModuleComps[] = {
 
 static NS_DEFINE_CID(knsFtpProtocolHandlerCID, NS_FTPPROTOCOLHANDLER_CID);
 
-//Annoying globals to track the mozilla ftp handler so it can be restored.
+/* Annoying globals to track the mozilla ftp handler so it can be restored. */
 static PRBool ftpRegistered = PR_FALSE;
 static nsCOMPtr<nsIFactory> nsFtpFactory;
 
-/* FIXME why we need to use "C" here ???? */
-
-extern  "C" gboolean
+gboolean
 mozilla_register_components (void)
 {
 	gboolean ret = TRUE;
@@ -214,7 +233,8 @@ mozilla_register_components (void)
 /**
  * mozilla_register_FtpProtocolHandler: Register Ftp Protocol Handler
  */
-extern "C" gboolean mozilla_register_FtpProtocolHandler (void)
+gboolean
+mozilla_register_FtpProtocolHandler (void)
 {
 	if (ftpRegistered == PR_TRUE) return TRUE;
 
@@ -251,7 +271,8 @@ extern "C" gboolean mozilla_register_FtpProtocolHandler (void)
 /**
  * mozilla_unregister_FtpProtocolHandler: Unregister Ftp Protocol Handler
  */
-extern "C" gboolean mozilla_unregister_FtpProtocolHandler (void)
+gboolean
+mozilla_unregister_FtpProtocolHandler (void)
 {
 	if (ftpRegistered == PR_FALSE) return FALSE;
         
@@ -273,7 +294,7 @@ extern "C" gboolean mozilla_unregister_FtpProtocolHandler (void)
 /**
  * mozilla_register_MailtoProtocolHandler: Register Mailto Protocol Handler
  */
-extern "C" gboolean 
+gboolean 
 mozilla_register_MailtoProtocolHandler (void)
 {
 	gboolean retVal = TRUE;
