@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: mozilla-embed.cpp,v 1.33 2003/10/17 22:40:13 chpe Exp $
  */
 
 #include "gtkmozembed.h"
@@ -43,8 +45,6 @@ mozilla_embed_class_init (MozillaEmbedClass *klass);
 static void
 mozilla_embed_init (MozillaEmbed *gs);
 static void
-mozilla_embed_finalize (GObject *object);
-static void
 mozilla_embed_destroy (GtkObject *object);
 static void
 ephy_embed_init (EphyEmbedClass *embed_class);
@@ -147,7 +147,9 @@ impl_get_security_level (EphyEmbed *embed,
 static gresult
 impl_set_encoding (EphyEmbed *embed,
                    const char *encoding);
-
+static gresult
+impl_get_encoding_info (EphyEmbed *embed,
+			EphyEncodingInfo **info);
 static gresult
 impl_print (EphyEmbed *embed, 
             EmbedPrintInfo *info);
@@ -233,6 +235,8 @@ signal_connections[] =
         { NULL, NULL } 
 };
 
+#define MOZILLA_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED, MozillaEmbedPrivate))
+
 struct MozillaEmbedPrivate
 {
 	MozillaEmbedPrivate() : wrapper(NULL), security_state(-1), no_page(1)
@@ -284,7 +288,7 @@ mozilla_embed_get_type (void)
 							     &our_info, 
 							     (GTypeFlags)0);
 		g_type_add_interface_static (mozilla_embed_type,
-                                   	     EPHY_EMBED_TYPE,
+                                   	     EPHY_TYPE_EMBED,
                                    	     &embed_info);
         }
 
@@ -311,7 +315,7 @@ impl_find_next (EphyEmbed *embed,
 static gresult
 impl_activate (EphyEmbed *embed) 
 {
-	g_return_val_if_fail (IS_EPHY_EMBED (embed), G_FAILED);
+	g_return_val_if_fail (EPHY_IS_EMBED (embed), G_FAILED);
 
 	gtk_widget_grab_focus (GTK_BIN (embed)->child);
 	
@@ -376,6 +380,7 @@ ephy_embed_init (EphyEmbedClass *embed_class)
 	embed_class->activate = impl_activate;
 	embed_class->find_set_properties = impl_find_set_properties;
 	embed_class->set_encoding = impl_set_encoding;
+	embed_class->get_encoding_info = impl_get_encoding_info;
 	embed_class->select_all = impl_select_all;
 	embed_class->print = impl_print;
 	embed_class->print_preview_close = impl_print_preview_close;
@@ -388,16 +393,19 @@ mozilla_embed_class_init (MozillaEmbedClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
      	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass); 
+
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
-	
+
 	gtk_object_class->destroy = mozilla_embed_destroy;
-        object_class->finalize = mozilla_embed_finalize;
+
+	g_type_class_add_private (object_class, sizeof(MozillaEmbedPrivate));
 }
 
 static void
 mozilla_embed_init (MozillaEmbed *embed)
 {
-        embed->priv = g_new0 (MozillaEmbedPrivate, 1);
+        embed->priv = MOZILLA_EMBED_GET_PRIVATE (embed);
+
 	embed->priv->no_page = 1;
 
 	mozilla_embed_connect_signals (embed);
@@ -453,25 +461,6 @@ mozilla_embed_destroy (GtkObject *object)
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
-static void
-mozilla_embed_finalize (GObject *object)
-{
-        MozillaEmbed *embed;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_MOZILLA_EMBED (object));
-
-	embed = MOZILLA_EMBED (object);
-	
-	g_return_if_fail (embed->priv != NULL);
-	
-	g_free (embed->priv);
-	
-        G_OBJECT_CLASS (parent_class)->finalize (object);
-
-	LOG ("MozillaEmbed finalized %p", embed)
-}
-
 static void
 impl_get_capabilities (EphyEmbed *embed,
                        EmbedCapabilities *caps)
@@ -540,24 +529,22 @@ impl_can_go_forward (EphyEmbed *embed)
 static gresult 
 impl_can_go_up (EphyEmbed *embed)
 {
-	char *location = NULL;
+	char *location;
 	char *s;
-	gresult result = G_FAILED;
+	gresult result;
 
 	if (ephy_embed_get_location (embed, TRUE, &location) != G_OK)
-	{
-		g_free (location);
-
-		return G_FAILED;
-	}
-
+	  return G_FAILED;
 	g_return_val_if_fail (location != NULL, G_FAILED);
-
 	if ((s = mozilla_embed_get_uri_parent (location)) != NULL)
 	{
 		g_free (s);
 		result = G_OK;
 	}
+	else
+	{
+		result = G_FAILED;
+	}
 
 	g_free (location);
 
@@ -567,20 +554,14 @@ impl_can_go_up (EphyEmbed *embed)
 static gresult
 impl_get_go_up_list (EphyEmbed *embed, GSList **l)
 {
-	char *location = NULL;
+	char *location;
 	char *s;
 	
-	*l = NULL;
-
 	if (ephy_embed_get_location (embed, TRUE, &location) != G_OK)
-	{
-		g_free (location);
-
 		return G_FAILED;
-	}
-
 	g_return_val_if_fail (location != NULL, G_FAILED);
 	
+	*l = NULL;
 	s = location;
 	while ((s = mozilla_embed_get_uri_parent (s)) != NULL)
 	{
@@ -588,7 +569,6 @@ impl_get_go_up_list (EphyEmbed *embed, GSList **l)
 	}				
 
 	g_free (location);
-
 	*l = g_slist_reverse (*l);
 
 	return G_OK;
@@ -613,25 +593,15 @@ impl_go_forward (EphyEmbed *embed)
 static gresult
 impl_go_up (EphyEmbed *embed)
 {
-	char *uri = NULL;
+	char *uri;
 	char *parent_uri;
-
-	if (ephy_embed_get_location (embed, TRUE, &uri) != G_OK)
-	{
-		g_free (uri);
-
-		return G_FAILED;
-	}
-
+	
+	ephy_embed_get_location (embed, TRUE, &uri);
 	g_return_val_if_fail (uri != NULL, G_FAILED);
 	
 	parent_uri = mozilla_embed_get_uri_parent (uri);
 	g_free (uri);
-
-	if (parent_uri == NULL)
-	{
-		return G_FAILED;
-	}
+	g_return_val_if_fail (parent_uri != NULL, G_FAILED);
 	
 	ephy_embed_load_url (embed, parent_uri);
 
@@ -1157,8 +1127,6 @@ impl_print (EphyEmbed *embed,
 
 	result = wrapper->Print(options, info->preview);
 
-	options->SetPrintSilent (PR_FALSE);
-
 	return NS_SUCCEEDED (result) ? G_OK : G_FAILED;
 }
 
@@ -1208,7 +1176,7 @@ static gresult
 impl_set_encoding (EphyEmbed *embed,
 		   const char *encoding)
 {
-	nsresult result = NS_OK;
+	nsresult result;
 	EphyWrapper *wrapper;
 	
 	wrapper = MOZILLA_EMBED(embed)->priv->wrapper;
@@ -1223,6 +1191,26 @@ impl_set_encoding (EphyEmbed *embed,
 	return NS_SUCCEEDED(result) ? G_OK : G_FAILED;
 }
 
+static gresult
+impl_get_encoding_info (EphyEmbed *embed,
+			EphyEncodingInfo **info)
+{
+	nsresult result;
+	EphyWrapper *wrapper;
+
+	g_return_val_if_fail (info != NULL, G_FAILED);
+	*info = NULL;
+
+	wrapper = MOZILLA_EMBED(embed)->priv->wrapper;
+	// we want to use get_encoding_info on newly opened tabs too :/
+	//g_return_val_if_fail (wrapper != NULL, G_FAILED);
+	if (wrapper == NULL) return G_FAILED;
+
+	result = wrapper->GetEncodingInfo (info);
+
+	return NS_SUCCEEDED(result) ? G_OK : G_FAILED;
+}
+
 static void
 mozilla_embed_location_changed_cb (GtkMozEmbed *embed, 
 				   MozillaEmbed *membed)
@@ -1246,7 +1234,7 @@ static void
 mozilla_embed_title_changed_cb (GtkMozEmbed *embed, 
 				MozillaEmbed *membed)
 {
-	g_return_if_fail (IS_MOZILLA_EMBED (membed));
+	g_return_if_fail (MOZILLA_IS_EMBED (membed));
 	g_return_if_fail (GTK_IS_WIDGET (embed));
 	g_signal_emit_by_name (membed, "ge_title");
 }
