@@ -39,6 +39,8 @@
 #include "nsIPrefService.h"
 #include "nsIServiceManager.h"
 
+#define MOZILLA_PREF_NO_PROXIES "network.proxy.no_proxies_on"
+
 static void
 mozilla_cache_size_notifier (GConfClient *client,
 		             guint cnxn_id,
@@ -103,10 +105,10 @@ mozilla_cookies_accept_notifier (GConfClient *client,
 		                 GConfEntry *entry,
 		                 char *pref);
 static void
-mozilla_cache_compare_notifier (GConfClient *client,
-		                guint cnxn_id,
-		                GConfEntry *entry,
-		                char *pref);
+mozilla_proxy_ignore_notifier (GConfClient *client,
+		               guint cnxn_id,
+		               GConfEntry *entry,
+		               EphyEmbedSingle *single);
 
 /* Keeps the list of the notifiers we installed for mozilla prefs */
 /* to be able to remove them when exiting */
@@ -165,10 +167,10 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_proxy_autoconfig_notifier },
 	{ CONF_NETWORK_CACHE_SIZE,
           (GConfClientNotifyFunc) mozilla_cache_size_notifier },
-	{ CONF_NETWORK_CACHE_COMPARE,
-	  (GConfClientNotifyFunc) mozilla_cache_compare_notifier },
 	{ CONF_SECURITY_COOKIES_ACCEPT,
 	  (GConfClientNotifyFunc) mozilla_cookies_accept_notifier },
+ 	{ CONF_NETWORK_PROXY_IGNORE_HOSTS,
+ 	  (GConfClientNotifyFunc) mozilla_proxy_ignore_notifier },
 
 	{ NULL, NULL }
 };
@@ -239,7 +241,7 @@ mozilla_cache_size_notifier (GConfClient *client,
 {
 	int cache_size;
 
-	cache_size = gconf_value_get_int(entry->value) * 1024;
+	cache_size = eel_gconf_get_integer (entry->key) * 1024;
 
 	mozilla_prefs_set_int ("browser.cache.disk.capacity", cache_size);
 }
@@ -252,9 +254,11 @@ mozilla_font_size_notifier (GConfClient *client,
 {
 	char key[255];
 	
+	if (entry->value == NULL) return;
+
 	sprintf (key, "font.%s", pref);
 
-	mozilla_prefs_set_int (key, gconf_value_get_int(entry->value));
+	mozilla_prefs_set_int (key, eel_gconf_get_integer (entry->key));
 }
 
 static void
@@ -263,10 +267,11 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 		             GConfEntry *entry,
 		             EphyEmbedSingle *single)
 {
-	const char *mode;
+	char *mode;
 	int mozilla_mode = 0;
 	
-	mode = gconf_value_get_string(entry->value);
+	mode = eel_gconf_get_string (entry->key);
+	if (mode == NULL) return;
 	
 	if (strcmp (mode, "manual") == 0)
 	{
@@ -278,6 +283,8 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 	}
 
 	mozilla_prefs_set_int ("network.proxy.type", mozilla_mode);
+
+	g_free (mode);
 }
 
 static void
@@ -286,10 +293,11 @@ mozilla_cookies_accept_notifier (GConfClient *client,
 		                 GConfEntry *entry,
 		                 char *pref)
 {
-	const char *mode;
+	char *mode;
 	int mozilla_mode = 0;
 	
-	mode = gconf_value_get_string(entry->value);
+	mode = eel_gconf_get_string (entry->key);
+	if (mode == NULL) return;
 	
 	if (strcmp (mode, "anywhere") == 0)
 	{
@@ -305,37 +313,8 @@ mozilla_cookies_accept_notifier (GConfClient *client,
 	}
 
 	mozilla_prefs_set_int ("network.cookie.cookieBehavior", mozilla_mode);
-}
 
-static void
-mozilla_cache_compare_notifier (GConfClient *client,
-		                guint cnxn_id,
-		                GConfEntry *entry,
-		                char *pref)
-{
-	const char *mode;
-	int mozilla_mode = 0;
-	
-	mode = gconf_value_get_string(entry->value);
-	
-	if (strcmp (mode, "once per session") == 0)
-	{
-		mozilla_mode = 0;
-	}
-	else if (strcmp (mode, "every time") == 0)
-	{
-		mozilla_mode = 1;
-	}
-	else if (strcmp (mode, "never") == 0)
-	{
-		mozilla_mode = 2;
-	}
-	else if (strcmp (mode, "automatic") == 0)
-	{
-		mozilla_mode = 3;
-	}
-
-	mozilla_prefs_set_int ("browser.cache.check_doc_frequency", mozilla_mode);
+	g_free (mode);
 }
 
 static void
@@ -345,10 +324,18 @@ mozilla_font_notifier (GConfClient *client,
 		       char *pref)
 {
 	char key[255];
+	char *name;
+
+	if (entry->value == NULL) return;
 	
 	sprintf (key, "font.name.%s", pref);
 
-	mozilla_prefs_set_string (key, gconf_value_get_string(entry->value));
+	name = eel_gconf_get_string (entry->key);
+	if (name)
+	{
+		mozilla_prefs_set_string (key, name);
+		g_free (name);
+	}
 }
 
 static void
@@ -357,8 +344,16 @@ mozilla_proxy_autoconfig_notifier (GConfClient *client,
 		       		   GConfEntry *entry,
 		       		   EphyEmbedSingle *single)
 {
-	ephy_embed_single_load_proxy_autoconf 
-		(single, gconf_value_get_string(entry->value));
+	char *url;
+
+	url = eel_gconf_get_string (entry->key);
+
+	if (url)
+	{
+		ephy_embed_single_load_proxy_autoconf (single, url);
+	}
+
+	g_free (url);
 }
 
 static void
@@ -384,18 +379,7 @@ add_notification_and_notify (GConfClient		*client,
 	mozilla_notifiers = g_list_append (mozilla_notifiers,
 			                   GUINT_TO_POINTER (cnxn_id));
 
-	entry = gconf_client_get_entry (client, key, NULL, TRUE, &error);
-	if (eel_gconf_handle_error (&error))
-	{
-		return;
-	}
-	g_return_if_fail (entry != NULL);
-
-	if (entry->value != NULL)
-	{
-		func (client, cnxn_id, entry, user_data);
-	}
-	gconf_entry_free (entry);
+	gconf_client_notify (client, key);
 }
 
 void 
@@ -403,8 +387,8 @@ mozilla_notifiers_init(EphyEmbedSingle *single)
 {
 	GConfClient *client = eel_gconf_client_get_global ();
 	guint i;
-	guint n_fonts_languages;
-	const FontsLanguageInfo *fonts_language;
+	const EphyFontsLanguageInfo *font_languages;
+	guint n_font_languages;
 
 	for (i = 0; conversion_table[i].gconf_key != NULL; i++)
 	{
@@ -442,63 +426,58 @@ mozilla_notifiers_init(EphyEmbedSingle *single)
 	}
 
 	/* fonts notifiers */
-	n_fonts_languages = ephy_langs_get_n_font_languages ();
-	fonts_language = ephy_langs_get_font_languages ();
-	for (i = 0; i < n_fonts_languages; i++)
+	font_languages = ephy_font_languages ();
+	n_font_languages = ephy_font_n_languages ();
+
+	for (i=0; i < n_font_languages; i++)
 	{
+		const char *code = font_languages[i].code;
 		guint k;
-		char *types [] = { "serif", "sans-serif", "cursive", "fantasy", "monospace" };
+		char *types [] = { "variable", "monospace" };
 		char key[255];
 		char *info;
 		
 		for (k = 0; k < G_N_ELEMENTS (types); k++)
 		{
-			info = g_strconcat (types[k], ".", fonts_language[i].code, NULL);
+			info = g_strconcat (types[k], ".", code, NULL);
 			
 			g_snprintf (key, 255, "%s_%s_%s", CONF_RENDERING_FONT, 
-			 	    types[k], 
-                 	 	    fonts_language[i].code);
+			 	    types[k], code);
 			add_notification_and_notify (client, key,
 						     (GConfClientNotifyFunc)mozilla_font_notifier,
 						     info);
-			font_infos = g_list_append (font_infos, info);
+			font_infos = g_list_prepend (font_infos, info);
 		}
 
-		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_MIN_SIZE, fonts_language[i].code);
-		info = g_strconcat ("minimum-size", ".", fonts_language[i].code, NULL);
+		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_MIN_SIZE, code);
+		info = g_strconcat ("minimum-size", ".", code, NULL);
 		add_notification_and_notify (client, key,
 					     (GConfClientNotifyFunc)mozilla_font_size_notifier,
 					     info);
-		font_infos = g_list_append (font_infos, info);
+		font_infos = g_list_prepend (font_infos, info);
 
-		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_FIXED_SIZE, fonts_language[i].code);
-		info = g_strconcat ("size.fixed", ".", fonts_language[i].code, NULL);
+		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_FIXED_SIZE, code);
+		info = g_strconcat ("size.fixed", ".", code, NULL);
 		add_notification_and_notify (client, key,
 					     (GConfClientNotifyFunc)mozilla_font_size_notifier,
 					     info);
-		font_infos = g_list_append (font_infos, info);
+		font_infos = g_list_prepend (font_infos, info);
 
-		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_VAR_SIZE, fonts_language[i].code);
-		info = g_strconcat ("size.variable", ".", fonts_language[i].code, NULL);
+		g_snprintf (key, 255, "%s_%s", CONF_RENDERING_FONT_VAR_SIZE, code);
+		info = g_strconcat ("size.variable", ".", code, NULL);
 		add_notification_and_notify (client, key,
 					     (GConfClientNotifyFunc)mozilla_font_size_notifier,
 					     info);
-		font_infos = g_list_append (font_infos, info);		
+		font_infos = g_list_prepend (font_infos, info);		
 	}
 }
 
 void 
 mozilla_notifiers_free (void)
 {
-	GList *l;
-	
 	ephy_notification_remove (&mozilla_notifiers);
 
-	for (l = font_infos; l != NULL; l = l->next)
-	{
-		g_free (l->data);
-	}
-	
+	g_list_foreach (font_infos, (GFunc) g_free, NULL);
 	g_list_free (font_infos);
 }
 
@@ -512,24 +491,14 @@ generic_mozilla_string_notifier(GConfClient *client,
 				GConfEntry *entry,
 				const char *pref_name)
 {
-	const gchar *value;
+	char *value;
 
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
+	value = eel_gconf_get_string (entry->key);
+	if (value)
 	{
-		case GCONF_VALUE_STRING:
-			value = gconf_value_get_string(entry->value);
-			if (value)
-			{
-				mozilla_prefs_set_string
-					(pref_name,
-					 gconf_value_get_string(entry->value));
-			}
-			break;
-
-		default:	
-			g_warning("Unsupported variable type");
-	} 
+		mozilla_prefs_set_string (pref_name, value);
+		g_free (value);
+	}
 }
 
 
@@ -543,20 +512,10 @@ generic_mozilla_int_notifier(GConfClient *client,
 			     GConfEntry *entry,
 			     const char *pref_name)
 {
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
-	{
-		case GCONF_VALUE_INT:	mozilla_prefs_set_int(pref_name,
-						gconf_value_get_int(entry->value));
-					break;
-		case GCONF_VALUE_BOOL:	mozilla_prefs_set_boolean(pref_name,
-						gconf_value_get_bool(entry->value));
-					break;
-		case GCONF_VALUE_STRING:	mozilla_prefs_set_string(pref_name,
-						gconf_value_get_string(entry->value));
-					break;
-		default:	g_warning("Unsupported variable type");
-	}
+	int value;
+
+	value = eel_gconf_get_integer (entry->key);
+	mozilla_prefs_set_int (pref_name, value);
 }
 
 
@@ -570,17 +529,10 @@ generic_mozilla_bool_notifier(GConfClient *client,
 			      GConfEntry *entry,
 			      const char *pref_name)
 {
-	/* determine type of gconf key, in order of likelyhood */
-	switch (entry->value->type)
-	{
-		case GCONF_VALUE_BOOL:	mozilla_prefs_set_boolean(pref_name,
-						gconf_value_get_bool(entry->value));
-					break;
-		case GCONF_VALUE_INT:	mozilla_prefs_set_int(pref_name,
-						gconf_value_get_int(entry->value));
-					break;
-		default:	g_warning("Unsupported variable type");
-	}
+	gboolean value;
+
+	value = eel_gconf_get_boolean (entry->key);
+	mozilla_prefs_set_boolean (pref_name, value);
 }
 
 static void
@@ -589,8 +541,10 @@ mozilla_own_colors_notifier(GConfClient *client,
 			    GConfEntry *entry,
 			    EphyEmbedSingle *single)
 {
-	mozilla_prefs_set_boolean("browser.display.use_document_colors",
-				       !gconf_value_get_bool(entry->value));
+	gboolean value;
+
+	value = eel_gconf_get_boolean (entry->key);
+	mozilla_prefs_set_boolean ("browser.display.use_document_colors", !value);
 }
 
 static void
@@ -601,7 +555,7 @@ mozilla_own_fonts_notifier(GConfClient *client,
 {
 	int value;
 
-	value = gconf_value_get_bool(entry->value) ? 0 : 1;
+	value = eel_gconf_get_boolean (entry->key) ? 0 : 1;
 	mozilla_prefs_set_int("browser.display.use_document_fonts", value);
 }
 
@@ -611,9 +565,10 @@ mozilla_allow_popups_notifier(GConfClient *client,
 			      GConfEntry *entry,
 			      EphyEmbedSingle *single)
 {
-	gboolean new_val = eel_gconf_get_boolean(CONF_SECURITY_ALLOW_POPUPS);
-	mozilla_prefs_set_boolean ("dom.disable_open_during_load", 
-					!new_val);
+	gboolean value;
+
+	value = eel_gconf_get_boolean (entry->key);
+	mozilla_prefs_set_boolean ("dom.disable_open_during_load", !value);
 }
 
 static char *
@@ -623,9 +578,15 @@ get_system_language ()
 	const char *lang;
 
 	/**
-	 * translate this as the comma separated list of language ranges
-	 * for your locale, as specified by RFC 2616, 14.4. 
-	 * for example for en_NZ locale this could be "en-nz,en-au,en-gb,en"
+	 * This is a comma separated list of language ranges, as specified
+	 * by RFC 2616, 14.4.
+	 * Always include the basic language code last.
+	 *
+	 * Examples:
+	 * "pt"    translation: "pt"
+	 * "pt_BR" translation: "pt-br,pt"
+	 * "zh_CN" translation: "zh-cn,zh"
+	 * "zh_HK" translation: "zh-hk,zh" or maybe "zh-hk,zh-tw,zh"
 	 */
 	lang = _("system-language");
 	
@@ -648,7 +609,7 @@ get_system_language ()
 		}
 	}
 
-	return NULL;
+	return g_strdup ("en");
 }
 
 static void
@@ -661,7 +622,7 @@ mozilla_language_notifier(GConfClient *client,
 	GString *result;
 
 	languages = eel_gconf_get_string_list (CONF_RENDERING_LANGUAGE);
-	g_return_if_fail (languages != NULL);
+	if (languages == NULL) return;
 
 	result = g_string_new ("");
 
@@ -695,3 +656,39 @@ mozilla_language_notifier(GConfClient *client,
 	g_slist_foreach (languages, (GFunc) g_free, NULL);
 	g_slist_free (languages);
 }
+
+static void
+mozilla_proxy_ignore_notifier (GConfClient *client,
+		               guint cnxn_id,
+		               GConfEntry *entry,
+		               EphyEmbedSingle *single)
+{
+	GSList *hosts, *l;
+	char **strings, *mozilla_ignore_list;
+	int i = 0;
+
+	hosts = eel_gconf_get_string_list (entry->key);
+
+	strings = g_new (gchar*, g_slist_length (hosts) + 1);
+	for (l = hosts; l != NULL; l = l->next)
+	{
+		char *item = (char *) l->data;
+
+		if (item && item[0] != '\0')
+		{
+			strings[i] = item;
+			i++;
+		}
+	}
+	strings[i] = NULL;
+
+	mozilla_ignore_list = g_strjoinv (", ", strings);
+	mozilla_prefs_set_string (MOZILLA_PREF_NO_PROXIES,
+				  mozilla_ignore_list);
+
+	g_free (mozilla_ignore_list);
+	g_free (strings);
+	g_slist_foreach (hosts, (GFunc) g_free, NULL);
+	g_slist_free (hosts);
+}
+
