@@ -14,12 +14,15 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: print-dialog.c,v 1.11 2003/09/30 07:18:46 chpe Exp $
  */
 
 #include "print-dialog.h"
 #include "ephy-prefs.h"
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkstock.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #define CONF_PRINT_BOTTOM_MARGIN "/apps/epiphany/dialogs/print_bottom_margin"
 #define CONF_PRINT_TOP_MARGIN "/apps/epiphany/dialogs/print_top_margin"
@@ -39,7 +42,6 @@
 
 static void print_dialog_class_init (PrintDialogClass *klass);
 static void print_dialog_init (PrintDialog *dialog);
-static void print_dialog_finalize (GObject *object);
 
 /* Glade callbacks */
 void
@@ -54,9 +56,10 @@ print_preview_button_cb (GtkWidget *widget,
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_PRINT_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PRINT_DIALOG, PrintDialogPrivate))
+
 struct PrintDialogPrivate
 {
-	gpointer dummy;
 	GtkWidget *window;
 };
 
@@ -142,7 +145,7 @@ print_dialog_get_type (void)
                         (GInstanceInitFunc) print_dialog_init
                 };
 
-                print_dialog_type = g_type_register_static (EPHY_EMBED_DIALOG_TYPE,
+                print_dialog_type = g_type_register_static (EPHY_TYPE_EMBED_DIALOG,
 						            "PrintDialog",
 						            &our_info, 0);
         }
@@ -158,8 +161,6 @@ print_dialog_class_init (PrintDialogClass *klass)
 
         parent_class = g_type_class_peek_parent (klass);
 
-        object_class->finalize = print_dialog_finalize;
-
 	print_dialog_signals[PREVIEW] =
                 g_signal_new ("preview",
                               G_OBJECT_CLASS_TYPE (object_class),
@@ -169,16 +170,17 @@ print_dialog_class_init (PrintDialogClass *klass)
                               g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
                               0);
+
+	g_type_class_add_private (object_class, sizeof(PrintDialogPrivate));
 }
 
 static void
 print_dialog_init (PrintDialog *dialog)
 {
 	GdkPixbuf *icon;
-	dialog->priv = g_new0 (PrintDialogPrivate, 1);
+	dialog->priv = EPHY_PRINT_DIALOG_GET_PRIVATE (dialog);
 
 	dialog->only_collect_info = FALSE;
-
 	dialog->ret_info = NULL;
 
 	ephy_dialog_construct (EPHY_DIALOG(dialog),
@@ -198,32 +200,15 @@ print_dialog_init (PrintDialog *dialog)
 	g_object_unref (icon);
 }
 
-static void
-print_dialog_finalize (GObject *object)
-{
-	PrintDialog *dialog;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_PRINT_DIALOG (object));
-
-	dialog = PRINT_DIALOG (object);
-
-        g_return_if_fail (dialog->priv != NULL);
-
-        g_free (dialog->priv);
-
-        G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
 EphyDialog *
 print_dialog_new (EphyEmbed *embed,
 		  EmbedPrintInfo **ret_info)
 {
 	PrintDialog *dialog;
 
-	dialog = PRINT_DIALOG (g_object_new (PRINT_DIALOG_TYPE,
-				     "embed", embed,
-				     NULL));
+	dialog = EPHY_PRINT_DIALOG (g_object_new (EPHY_TYPE_PRINT_DIALOG,
+						  "embed", embed,
+						  NULL));
 
 	if (!embed) dialog->only_collect_info = TRUE;
 	dialog->ret_info = ret_info;
@@ -238,10 +223,10 @@ print_dialog_new_with_parent (GtkWidget *window,
 {
 	PrintDialog *dialog;
 
-	dialog = PRINT_DIALOG (g_object_new (PRINT_DIALOG_TYPE,
-				     "embed", embed,
-				     "ParentWindow", window,
-				     NULL));
+	dialog = EPHY_PRINT_DIALOG (g_object_new (EPHY_TYPE_PRINT_DIALOG,
+						  "embed", embed,
+						  "ParentWindow", window,
+						  NULL));
 
 	if (!embed) dialog->only_collect_info = TRUE;
 	dialog->ret_info = ret_info;
@@ -256,8 +241,10 @@ print_free_info (EmbedPrintInfo *info)
 	g_free (info->file);
 	g_free (info->paper);
 	g_free (info->header_left_string);
+	g_free (info->header_center_string);
 	g_free (info->header_right_string);
 	g_free (info->footer_left_string);
+	g_free (info->footer_center_string);
 	g_free (info->footer_right_string);
 	g_free (info);
 }
@@ -265,7 +252,7 @@ print_free_info (EmbedPrintInfo *info)
 static EmbedPrintInfo *
 print_get_info (EphyDialog *dialog)
 {
-        EmbedPrintInfo *info;
+	EmbedPrintInfo *info;
 	GValue print_to_file = {0, };
 	GValue printer = {0, };
 	GValue file = {0, };
@@ -283,68 +270,94 @@ print_get_info (EphyDialog *dialog)
 	GValue page_url = {0, };
 	GValue date = {0, };
 	GValue page_numbers = {0, };
+	const char *filename;
 
-        info = g_new0 (EmbedPrintInfo, 1);
+	info = g_new0 (EmbedPrintInfo, 1);
 
 	ephy_dialog_get_value (dialog, PRINTON_PROP, &print_to_file);
-        info->print_to_file = g_value_get_int (&print_to_file);
+	info->print_to_file = g_value_get_int (&print_to_file);
+	g_value_unset (&print_to_file);
 
 	ephy_dialog_get_value (dialog, PRINTER_PROP, &printer);
 	info->printer = g_strdup (g_value_get_string (&printer));
+	g_value_unset (&printer);
 
 	ephy_dialog_get_value (dialog, FILE_PROP, &file);
-        info->file = g_strdup (g_value_get_string (&file));
+	filename = g_value_get_string (&file);
+	if (filename != NULL)
+	{
+		info->file = gnome_vfs_expand_initial_tilde (g_value_get_string (&file));
+	}
+	else
+	{
+		info->file = NULL;
+	}
+	g_value_unset (&file);
 
 	ephy_dialog_get_value (dialog, BOTTOM_PROP, &bottom_margin);
-        info->bottom_margin = g_value_get_float (&bottom_margin);
+	info->bottom_margin = g_value_get_float (&bottom_margin);
+	g_value_unset (&bottom_margin);
 
 	ephy_dialog_get_value (dialog, LEFT_PROP, &left_margin);
-        info->left_margin = g_value_get_float (&left_margin);
+	info->left_margin = g_value_get_float (&left_margin);
+	g_value_unset (&left_margin);
 
 	ephy_dialog_get_value (dialog, TOP_PROP, &top_margin);
-        info->top_margin = g_value_get_float (&top_margin);
+	info->top_margin = g_value_get_float (&top_margin);
+	g_value_unset (&top_margin);
 
 	ephy_dialog_get_value (dialog, RIGHT_PROP, &right_margin);
-        info->right_margin = g_value_get_float (&right_margin);
+	info->right_margin = g_value_get_float (&right_margin);
+	g_value_unset (&right_margin);
 
 	ephy_dialog_get_value (dialog, FROM_PROP, &from_page);
-        info->from_page = g_value_get_float (&from_page);
+	info->from_page = g_value_get_float (&from_page);
+	g_value_unset (&from_page);
 
 	ephy_dialog_get_value (dialog, TO_PROP, &to_page);
-        info->to_page = g_value_get_float (&to_page);
+	info->to_page = g_value_get_float (&to_page);
+	g_value_unset (&to_page);
 
 	ephy_dialog_get_value (dialog, PAPER_PROP, &paper);
-        info->paper = g_strdup (paper_format_enum[g_value_get_int (&paper)]);
+	info->paper = g_strdup (paper_format_enum[g_value_get_int (&paper)]);
+	g_value_unset (&paper);
 
 	ephy_dialog_get_value (dialog, ALL_PAGES_PROP, &pages);
-        info->pages = g_value_get_int (&pages);
+	info->pages = g_value_get_int (&pages);
+	g_value_unset (&pages);
 
 	ephy_dialog_get_value (dialog, COLOR_PROP, &print_color);
-        info->print_color = !g_value_get_int (&print_color);
+	info->print_color = !g_value_get_int (&print_color);
+	g_value_unset (&print_color);
 
 	ephy_dialog_get_value (dialog, ORIENTATION_PROP, &orientation);
-        info->orientation = g_value_get_int (&orientation);
+	info->orientation = g_value_get_int (&orientation);
+	g_value_unset (&orientation);
 
-        info->frame_type = 0;
+	info->frame_type = 0;
 
 	ephy_dialog_get_value (dialog, PAGE_TITLE_PROP, &page_title);
-        info->header_left_string = g_value_get_boolean (&page_title) ?
+	info->header_left_string = g_value_get_boolean (&page_title) ?
 				   g_strdup ("&T") : g_strdup ("");
+	g_value_unset (&page_title);
 
 	ephy_dialog_get_value (dialog, PAGE_URL_PROP, &page_url);
-        info->header_right_string = g_value_get_boolean (&page_url) ?
+	info->header_right_string = g_value_get_boolean (&page_url) ?
 				    g_strdup ("&U") : g_strdup ("");
+	g_value_unset (&page_url);
 
 	ephy_dialog_get_value (dialog, PAGE_NUMBERS_PROP, &page_numbers);
-        info->footer_left_string = g_value_get_boolean (&page_numbers) ?
+	info->footer_left_string = g_value_get_boolean (&page_numbers) ?
 				   g_strdup ("&PT") : g_strdup ("");
+	g_value_unset (&page_numbers);
 
 	ephy_dialog_get_value (dialog, DATE_PROP, &date);
-        info->footer_right_string = g_value_get_boolean (&date) ?
+	info->footer_right_string = g_value_get_boolean (&date) ?
 				    g_strdup ("&D") : g_strdup ("");
+	g_value_unset (&date);
 
-        info->header_center_string = g_strdup("");
-        info->footer_center_string = g_strdup("");
+	info->header_center_string = g_strdup("");
+	info->footer_center_string = g_strdup("");
 
 	return info;
 }
@@ -357,9 +370,9 @@ print_dialog_print (EphyDialog *dialog)
 
 	info = print_get_info (dialog);
 
-	if(PRINT_DIALOG(dialog)->only_collect_info && PRINT_DIALOG(dialog)->ret_info)
+	if(EPHY_PRINT_DIALOG(dialog)->only_collect_info && EPHY_PRINT_DIALOG(dialog)->ret_info)
 	{
-		*(PRINT_DIALOG(dialog)->ret_info) = info;
+		*(EPHY_PRINT_DIALOG(dialog)->ret_info) = info;
 	}
 	else
 	{
@@ -383,9 +396,9 @@ print_dialog_preview (EphyDialog *dialog)
 
 	info = print_get_info (dialog);
 
-	if(PRINT_DIALOG(dialog)->only_collect_info && PRINT_DIALOG(dialog)->ret_info)
+	if(EPHY_PRINT_DIALOG(dialog)->only_collect_info && EPHY_PRINT_DIALOG(dialog)->ret_info)
 	{
-		*(PRINT_DIALOG(dialog)->ret_info) = info;
+		*(EPHY_PRINT_DIALOG(dialog)->ret_info) = info;
 	}
 	else
 	{
@@ -421,7 +434,7 @@ print_preview_button_cb (GtkWidget *widget,
 		         EphyDialog *dialog)
 {
 	//FIXME: Don't show preview button at all.
-	if(!(PRINT_DIALOG(dialog)->only_collect_info))
+	if(!(EPHY_PRINT_DIALOG(dialog)->only_collect_info))
 		print_dialog_preview (dialog);
 }
 
