@@ -135,7 +135,7 @@ egg_toolbars_model_to_xml (EggToolbarsModel *t)
   return doc;
 }
 
-gboolean
+static gboolean
 safe_save_xml (const char *xml_file, xmlDocPtr doc)
 {
 	char *tmp_file;
@@ -314,7 +314,7 @@ egg_toolbars_model_add_separator (EggToolbarsModel *t,
 		 toolbar_position, real_position);
 }
 
-gboolean
+static gboolean
 impl_add_item (EggToolbarsModel    *t,
 	       int		    toolbar_position,
 	       int		    position,
@@ -410,12 +410,20 @@ parse_toolbars (EggToolbarsModel *t,
       if (xmlStrEqual (child->name, "toolbar"))
 	{
 	  xmlChar *name;
+	  xmlChar *style;
 	  int position;
 
 	  name = xmlGetProp (child, "name");
 	  position = egg_toolbars_model_add_toolbar (t, -1, name);
 	  xmlFree (name);
 
+	  style = xmlGetProp (child, "style");
+	  if (style && strcmp (style, "icons-only") == 0)
+	    {
+	      egg_toolbars_model_set_flags (t, EGG_TB_MODEL_ICONS_ONLY, 0);
+	    }
+	  xmlFree (style);
+
 	  parse_item_list (t, child->children, position);
 	}
 
@@ -423,7 +431,7 @@ parse_toolbars (EggToolbarsModel *t,
     }
 }
 
-gboolean
+void
 egg_toolbars_model_load (EggToolbarsModel *t,
 			 const char *xml_file)
 {
@@ -436,7 +444,7 @@ egg_toolbars_model_load (EggToolbarsModel *t,
   if (doc == NULL)
   {
     g_warning ("Failed to load XML data from %s", xml_file);
-    return FALSE;
+    return;
   }
   root = xmlDocGetRootElement (doc);
 
@@ -444,11 +452,9 @@ egg_toolbars_model_load (EggToolbarsModel *t,
   parse_toolbars (t, root->children);
 
   xmlFreeDoc (doc);
-
-  return TRUE;
 }
 
-char *
+static char *
 impl_get_item_id (EggToolbarsModel *t,
 		  const char       *type,
 		  const char       *name)
@@ -461,7 +467,7 @@ impl_get_item_id (EggToolbarsModel *t,
   return NULL;
 }
 
-char *
+static char *
 impl_get_item_name (EggToolbarsModel *t,
 		    const char       *type,
 		    const char       *id)
@@ -474,7 +480,7 @@ impl_get_item_name (EggToolbarsModel *t,
   return NULL;
 }
 
-char *
+static char *
 impl_get_item_type (EggToolbarsModel *t,
 		    GdkAtom type)
 {
