@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-dialog.c,v 1.15 2003/10/10 19:24:30 marco Exp $
  */
 
 #include "ephy-dialog.h"
@@ -22,6 +24,7 @@
 #include "ephy-gui.h"
 #include "eel-gconf-extensions.h"
 
+#include <stdlib.h>
 #include <string.h>
 #include <gtk/gtktogglebutton.h>
 
@@ -78,7 +81,6 @@ typedef enum
         PT_TOGGLEBUTTON,
         PT_RADIOBUTTON,
         PT_SPINBUTTON,
-        PT_COLOR,
         PT_OPTIONMENU,
         PT_ENTRY,
 	PT_UNKNOWN
@@ -94,6 +96,8 @@ typedef struct
 	GList *string_enum;
 } PropertyInfo;
 
+#define EPHY_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_DIALOG, EphyDialogPrivate))
+
 struct EphyDialogPrivate
 {
 	GtkWidget *parent;
@@ -188,6 +192,8 @@ ephy_dialog_class_init (EphyDialogClass *klass)
                                                                "Modal dialog",
                                                                FALSE,
                                                                G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof (EphyDialogPrivate));
 }
 
 static void
@@ -328,23 +334,6 @@ set_config_from_togglebutton (GtkWidget *togglebutton, const char *config_name)
 	eel_gconf_set_boolean (config_name, value);
 }
 
-static void
-set_config_from_color (GtkWidget *colorpicker, const char *config_name)
-{
-	guint8 r, g, b, a;
-	gchar color_string[9];
-
-	/* get color values from color picker */
-	gnome_color_picker_get_i8 (GNOME_COLOR_PICKER (colorpicker),
-				   &r, &g, &b, &a);
-
-	/* write into string (bounded size) */
-	g_snprintf (color_string, 9, "#%02X%02X%02X", r, g, b);
-
-	/* set the configuration value */
-	eel_gconf_set_string (config_name, color_string);
-}
-
 static void
 set_editable_from_config (GtkWidget *editable, const char *config_name)
 {
@@ -496,26 +485,6 @@ set_togglebutton_from_config (GtkWidget *togglebutton, const char *config_name)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (togglebutton), value);
 }
 
-static void
-set_color_from_config (GtkWidget *colorpicker, const char *config_name)
-{
-	gchar *color_string;
-	guint r, g, b;
-
-	/* get the string from config */
-	color_string = eel_gconf_get_string (config_name);
-
-	if (color_string)
-	{
-		/* parse it and setup the color picker */
-		sscanf (color_string, "#%2X%2X%2X", &r, &g, &b);
-		gnome_color_picker_set_i8 (GNOME_COLOR_PICKER (colorpicker),
-					   r, g, b, 0);
-		/* free the string */
-		g_free (color_string);
-	}
-}
-
 static PrefType
 get_pref_type_from_widget (GtkWidget *widget)
 {
@@ -539,10 +508,6 @@ get_pref_type_from_widget (GtkWidget *widget)
 	{
 		return PT_ENTRY;
 	}
-	else if (GNOME_IS_COLOR_PICKER (widget))
-	{
-		return PT_COLOR;
-	}
 
 	return PT_UNKNOWN;
 }
@@ -698,16 +663,6 @@ prefs_spinbutton_changed_cb (GtkWidget *widget, PropertyInfo *pi)
 		       dialog);
 }
 
-static void
-prefs_color_changed_cb (GtkWidget *widget, guint r, guint g,
-			guint b, guint a, const PropertyInfo *pi)
-{
-	if (pi->type == PT_AUTOAPPLY)
-	{
-		set_config_from_color (widget,  pi->pref);
-	}
-}
-
 static void
 prefs_entry_changed_cb (GtkWidget *widget, PropertyInfo *pi)
 {
@@ -773,11 +728,6 @@ prefs_connect_signals (EphyDialog *dialog)
 					  G_CALLBACK(prefs_spinbutton_changed_cb),
 					  (gpointer)info);
 			break;
-		case PT_COLOR:
-			g_signal_connect (G_OBJECT (info->widget), "color_set",
-					  G_CALLBACK(prefs_color_changed_cb),
-					  (gpointer)info);
-			break;
 		case PT_OPTIONMENU:
 			g_signal_connect (G_OBJECT (info->widget),
 					  "changed",
@@ -798,7 +748,7 @@ prefs_connect_signals (EphyDialog *dialog)
 static void
 ephy_dialog_init (EphyDialog *dialog)
 {
-        dialog->priv = g_new0 (EphyDialogPrivate, 1);
+	dialog->priv = EPHY_DIALOG_GET_PRIVATE (dialog);
 
 	dialog->priv->parent = NULL;
 	dialog->priv->dialog = NULL;
@@ -869,11 +819,6 @@ load_props (PropertyInfo *props)
 						    props[i].pref,
 						    props[i].string_enum);
 		}
-		else if (GNOME_IS_COLOR_PICKER(props[i].widget))
-		{
-			set_color_from_config (props[i].widget,
-					       props[i].pref);
-		}
 	}
 
 }
@@ -916,11 +861,6 @@ save_props (PropertyInfo *props)
 						    props[i].pref,
 						    props[i].string_enum);
 		}
-		else if (GNOME_IS_COLOR_PICKER(props[i].widget))
-		{
-			set_config_from_color (props[i].widget,
-					       props[i].pref);
-		}
 	}
 }
 
@@ -939,20 +879,12 @@ free_props (PropertyInfo *properties)
 static void
 ephy_dialog_finalize (GObject *object)
 {
-        EphyDialog *dialog;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_EPHY_DIALOG (object));
-
-        dialog = EPHY_DIALOG (object);
-
-        g_return_if_fail (dialog->priv != NULL);
+        EphyDialog *dialog = EPHY_DIALOG (object);
 
 	free_props (dialog->priv->props);
 
 	g_free (dialog->priv->name);
 	g_free (dialog->priv->props);
-        g_free (dialog->priv);
 
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -1011,13 +943,13 @@ ephy_dialog_set_parent (EphyDialog *dialog,
 EphyDialog *
 ephy_dialog_new (void)
 {
-	return EPHY_DIALOG (g_object_new (EPHY_DIALOG_TYPE, NULL));
+	return EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG, NULL));
 }
 
 EphyDialog *
 ephy_dialog_new_with_parent (GtkWidget *parent_window)
 {
-	return EPHY_DIALOG (g_object_new (EPHY_DIALOG_TYPE,
+	return EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG,
 					    "ParentWindow", parent_window,
 					    NULL));
 }
@@ -1180,7 +1112,7 @@ setup_default_size (EphyDialog *dialog)
 static gint
 impl_run (EphyDialog *dialog)
 {
-	ephy_dialog_show (dialog);
+	setup_default_size (dialog);
 
 	return gtk_dialog_run (GTK_DIALOG(dialog->priv->dialog));
 }
