@@ -15,10 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.c,v 1.5.2.1 2003/12/18 12:48:42 chpe Exp $
+ *  $Id: ephy-node-db.c,v 1.7 2003/09/17 22:04:46 chpe Exp $
  */
 
 #include "ephy-node-db.h"
+#include "ephy-debug.h"
+
+#include <libxml/xmlreader.h>
 
 static void ephy_node_db_class_init (EphyNodeDbClass *klass);
 static void ephy_node_db_init (EphyNodeDb *node);
@@ -33,12 +36,16 @@ enum
 	PROP_NAME
 };
 
+#define EPHY_NODE_DB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_DB, EphyNodeDbPrivate))
+
 struct EphyNodeDbPrivate
 {
 	char *name;
 
+	GMutex *id_factory_lock;
 	long id_factory;
 
+	GStaticRWLock *id_to_node_lock;
 	GPtrArray *id_to_node;
 };
 
@@ -140,32 +147,32 @@ ephy_node_db_class_init (EphyNodeDbClass *klass)
                                                                "Name",
                                                                NULL,
                                                                G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof (EphyNodeDbPrivate));
 }
 
 static void
 ephy_node_db_init (EphyNodeDb *db)
 {
-	db->priv = g_new0 (EphyNodeDbPrivate, 1);
+	db->priv = EPHY_NODE_DB_GET_PRIVATE (db);
 
 	db->priv->name = NULL;
 
 	/* id to node */
 	db->priv->id_to_node = g_ptr_array_new ();
 
+	db->priv->id_to_node_lock = g_new0 (GStaticRWLock, 1);
+	g_static_rw_lock_init (db->priv->id_to_node_lock);
+
 	/* id factory */
 	db->priv->id_factory = RESERVED_IDS;
+	db->priv->id_factory_lock = g_mutex_new ();
 }
 
 static void
 ephy_node_db_finalize (GObject *object)
 {
-	EphyNodeDb *db;
-
-	g_return_if_fail (object != NULL);
-
-	db = EPHY_NODE_DB (object);
-
-	g_return_if_fail (db->priv != NULL);
+	EphyNodeDb *db = EPHY_NODE_DB (object);
 
 	g_hash_table_remove (ephy_node_databases, db->priv->name);
 	if (g_hash_table_size (ephy_node_databases) == 0)
@@ -175,9 +182,11 @@ ephy_node_db_finalize (GObject *object)
 
 	g_ptr_array_free (db->priv->id_to_node, FALSE);
 
-	g_free (db->priv->name);
+	g_static_rw_lock_free (db->priv->id_to_node_lock);
 
-	g_free (db->priv);
+	g_mutex_free (db->priv->id_factory_lock);
+
+	g_free (db->priv->name);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -228,8 +237,12 @@ ephy_node_db_get_node_from_id (EphyNodeDb *db, long id)
 {
 	EphyNode *ret = NULL;
 
+	g_static_rw_lock_reader_lock (db->priv->id_to_node_lock);
+
 	ret = node_from_id_real (db, id);
 
+	g_static_rw_lock_reader_unlock (db->priv->id_to_node_lock);
+
 	return ret;
 }
 
@@ -238,6 +251,8 @@ _ephy_node_db_new_id (EphyNodeDb *db)
 {
 	long ret;
 
+	g_mutex_lock (db->priv->id_factory_lock);
+
 	while (node_from_id_real (db, db->priv->id_factory) != NULL)
 	{
 		db->priv->id_factory++;
@@ -245,6 +260,8 @@ _ephy_node_db_new_id (EphyNodeDb *db)
 
 	ret = db->priv->id_factory;
 
+	g_mutex_unlock (db->priv->id_factory_lock);
+
 	return ret;
 }
 
@@ -253,19 +270,108 @@ _ephy_node_db_add_id (EphyNodeDb *db,
 		      long id,
 		      EphyNode *node)
 {
+	g_static_rw_lock_writer_lock (db->priv->id_to_node_lock);
+
 	/* resize array if needed */
 	if (id >= db->priv->id_to_node->len)
 		g_ptr_array_set_size (db->priv->id_to_node, id + 1);
 
 	g_ptr_array_index (db->priv->id_to_node, id) = node;
+
+	g_static_rw_lock_writer_unlock (db->priv->id_to_node_lock);
 }
 
 void
 _ephy_node_db_remove_id (EphyNodeDb *db,
 			 long id)
 {
+	g_static_rw_lock_writer_lock (db->priv->id_to_node_lock);
+
 	g_ptr_array_index (db->priv->id_to_node, id) = NULL;
 
 	/* reset id factory so we use the freed node id */
 	db->priv->id_factory = RESERVED_IDS;
+
+	g_static_rw_lock_writer_unlock (db->priv->id_to_node_lock);
+}
+
+gboolean
+ephy_node_db_load_from_file (EphyNodeDb *db,
+			     const char *xml_file,
+			     const xmlChar *xml_root,
+			     const xmlChar *xml_version)
+{
+	xmlTextReaderPtr reader;
+	gboolean success = TRUE;
+	int ret;
+
+	LOG ("ephy_node_db_load_from_file %s", xml_file)
+
+	START_PROFILER ("loading node db")
+
+	if (g_file_test (xml_file, G_FILE_TEST_EXISTS) == FALSE)
+	{
+		return FALSE;
+	}
+
+	reader = xmlNewTextReaderFilename (xml_file);
+	if (reader == NULL)
+	{
+		return FALSE;
+	}
+
+	ret = xmlTextReaderRead (reader);
+	while (ret == 1)
+	{
+		xmlChar *name;
+		xmlReaderTypes type;
+		gboolean skip = FALSE;
+
+		name = xmlTextReaderName (reader);
+		type = xmlTextReaderNodeType (reader);
+
+		if (xmlStrEqual (name, "node")
+		    && type == XML_READER_TYPE_ELEMENT)
+		{
+			xmlNodePtr subtree;
+			EphyNode *node;
+
+			/* grow the subtree and load the node from it */
+			subtree = xmlTextReaderExpand (reader);
+
+			node = ephy_node_new_from_xml (db, subtree);
+			
+			skip = TRUE;
+		}
+		else if (xmlStrEqual (name, xml_root)
+			 && type == XML_READER_TYPE_ELEMENT)
+		{
+			xmlChar *version;
+
+			/* check version info */
+			version = xmlTextReaderGetAttribute (reader, "version");
+			if (xmlStrEqual (version, xml_version) == FALSE)
+			{
+				success = FALSE;
+				xmlFree (version);
+				xmlFree (name);
+
+				break;
+			}
+
+			xmlFree (version);
+		}
+
+		xmlFree (name);
+
+		/* next one, please */
+		ret = skip ? xmlTextReaderNext (reader)
+			   : xmlTextReaderRead (reader);
+	}
+
+	xmlFreeTextReader (reader);
+
+	STOP_PROFILER ("loading node db")
+
+	return (success && ret == 0);
 }
