@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.h,v 1.4 2003/05/24 22:37:39 mpeseng Exp $
+ *  $Id: ephy-node-db.h,v 1.5 2003/09/17 22:04:46 chpe Exp $
  */
 
 #ifndef EPHY_NODE_DB_H
@@ -56,6 +56,11 @@ EphyNodeDb   *ephy_node_db_get_by_name		(const char *name);
 
 EphyNodeDb   *ephy_node_db_new			(const char *name);
 
+gboolean      ephy_node_db_load_from_file	(EphyNodeDb *db,
+						 const char *xml_file,
+						 const xmlChar *xml_root,
+						 const xmlChar *xml_version);
+
 const char   *ephy_node_db_get_name		(EphyNodeDb *db);
 
 EphyNode     *ephy_node_db_get_node_from_id	(EphyNodeDb *db,
