@@ -30,6 +30,7 @@
 #include <gtk/gtkpaned.h>
 
 #define STATES_FILE "states.xml"
+#define EPHY_STATES_XML_ROOT    "ephy_states"
 #define EPHY_STATES_XML_VERSION "1.0"
 
 enum
@@ -47,54 +48,6 @@ enum
 static EphyNode *states = NULL;
 static EphyNodeDb *states_db = NULL;
 
-static void
-ephy_states_load (void)
-{
-	xmlDocPtr doc;
-	xmlNodePtr root, child;
-	char *xml_file;
-	char *tmp;
-
-	xml_file = g_build_filename (ephy_dot_dir (),
-                                     STATES_FILE,
-                                     NULL);
-
-	if (g_file_test (xml_file, G_FILE_TEST_EXISTS) == FALSE)
-		return;
-
-	doc = xmlParseFile (xml_file);
-	if (doc == NULL)
-	{
-		g_warning ("Failed to load state file.\n");
-		return;
-	}
-
-	root = xmlDocGetRootElement (doc);
-
-	tmp = xmlGetProp (root, "version");
-	if (tmp != NULL && strcmp (tmp, EPHY_STATES_XML_VERSION) == 0)
-	{
-		child = root->children;
-	}
-	else
-	{
-		g_warning ("Old version of states.xml discarded");
-		child = NULL;
-	}
-	g_free (tmp);
-
-	for (; child != NULL; child = child->next)
-	{
-		EphyNode *node;
-
-		node = ephy_node_new_from_xml (states_db, child);
-	}
-
-	xmlFreeDoc (doc);
-
-	g_free (xml_file);
-}
-
 static void
 ephy_states_save (void)
 {
@@ -127,6 +80,7 @@ ephy_states_save (void)
 
 		ephy_node_save_to_xml (kid, root);
 	}
+	ephy_node_thaw (states);
 
 	ephy_file_save_xml (xml_file, doc);
 	g_free (xml_file);
@@ -154,6 +108,7 @@ find_by_name (const char *name)
 			result = kid;
 		}
 	}
+	ephy_node_thaw (states);
 
 	return result;
 }
@@ -163,9 +118,19 @@ ensure_states (void)
 {
 	if (states == NULL)
 	{
+		char *xml_file;
+
+		xml_file = g_build_filename (ephy_dot_dir (),
+					     STATES_FILE,
+					     NULL);
+
 		states_db = ephy_node_db_new (EPHY_NODE_DB_STATES);
 		states = ephy_node_new_with_id (states_db, STATES_NODE_ID);
-		ephy_states_load ();
+		ephy_node_db_load_from_file (states_db, xml_file,
+					     EPHY_STATES_XML_ROOT,
+					     EPHY_STATES_XML_VERSION);
+	
+		g_free (xml_file);
 	}
 }
 
@@ -210,7 +175,7 @@ ephy_state_window_set_position (GtkWidget *window, EphyNode *node)
 	size = ephy_node_get_property_boolean (node, EPHY_NODE_STATE_PROP_POSITION);
 
 	/* Don't set the position of the window if it is maximized */
-	if ((!maximize) && size)
+	if (!maximize & size)
 	{
 		x = ephy_node_get_property_int (node, EPHY_NODE_STATE_PROP_POSITION_X);
 		y = ephy_node_get_property_int (node, EPHY_NODE_STATE_PROP_POSITION_Y);
