@@ -15,8 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-arrow-toolbutton.c,v 1.5 2003/08/05 16:17:22 chpe Exp $
- *
+ *  $Id: ephy-arrow-toolbutton.c,v 1.7 2003/09/01 23:20:11 chpe Exp $
  */
 
 #include "ephy-arrow-toolbutton.h"
@@ -30,6 +29,8 @@
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkmain.h>
 
+#define EPHY_ARROW_TOOLBUTTON_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ARROW_TOOLBUTTON, EphyArrowToolButtonPrivate))
+
 struct EphyArrowToolButtonPrivate
 {
 	GtkWidget *arrow_widget;
@@ -71,7 +72,7 @@ ephy_arrow_toolbutton_get_type (void)
 				(GInstanceInitFunc) ephy_arrow_toolbutton_init
 			};
 
-                ephy_arrow_toolbutton_type = g_type_register_static (EGG_TYPE_TOOL_BUTTON,
+                ephy_arrow_toolbutton_type = g_type_register_static (GTK_TYPE_TOOL_BUTTON,
 							             "EphyArrowToolButton",
 							             &our_info, 0);
         }
@@ -81,14 +82,14 @@ ephy_arrow_toolbutton_get_type (void)
 
 
 static gboolean
-ephy_arrow_toolbutton_set_tooltip (EggToolItem *tool_item,
+ephy_arrow_toolbutton_set_tooltip (GtkToolItem *tool_item,
 				   GtkTooltips *tooltips,
 				   const char *tip_text,
 				   const char *tip_private)
 {
 	EphyArrowToolButton *button = EPHY_ARROW_TOOLBUTTON (tool_item);
 
-	g_return_val_if_fail (IS_EPHY_ARROW_TOOLBUTTON (button), FALSE);
+	g_return_val_if_fail (EPHY_IS_ARROW_TOOLBUTTON (button), FALSE);
 
 	gtk_tooltips_set_tip (tooltips, button->priv->button, tip_text, tip_private);
 
@@ -99,7 +100,7 @@ static void
 ephy_arrow_toolbutton_class_init (EphyArrowToolButtonClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	EggToolItemClass *tool_item_class = EGG_TOOL_ITEM_CLASS (klass);
+	GtkToolItemClass *tool_item_class = GTK_TOOL_ITEM_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
@@ -115,6 +116,8 @@ ephy_arrow_toolbutton_class_init (EphyArrowToolButtonClass *klass)
 		 NULL, NULL,
 		 ephy_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
+
+	g_type_class_add_private (object_class, sizeof (EphyArrowToolButtonPrivate));
 }
 
 static void
@@ -202,13 +205,13 @@ ephy_arrow_toolbutton_init (EphyArrowToolButton *arrowtb)
 	GtkWidget *arrow_button;
 	GtkWidget *real_button;
 
-	arrowtb->priv = g_new (EphyArrowToolButtonPrivate, 1);
+	arrowtb->priv = EPHY_ARROW_TOOLBUTTON_GET_PRIVATE (arrowtb);
 
-	egg_tool_item_set_homogeneous (EGG_TOOL_ITEM (arrowtb), FALSE);
+	gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (arrowtb), FALSE);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
-	real_button = EGG_TOOL_BUTTON (arrowtb)->button;
+	real_button = GTK_BIN (arrowtb)->child;
 	g_object_ref (real_button);
 	gtk_container_remove (GTK_CONTAINER (arrowtb), real_button);
 	gtk_container_add (GTK_CONTAINER (hbox), real_button);
@@ -256,8 +259,6 @@ ephy_arrow_toolbutton_finalize (GObject *object)
 
 	gtk_widget_destroy (GTK_WIDGET (arrow_toolbutton->priv->menu));
 
-	g_free (arrow_toolbutton->priv);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
