@@ -26,7 +26,10 @@
  *
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "ephy-spinner.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
@@ -34,21 +37,16 @@
 #include "ephy-file-helpers.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtksignal.h>
-#include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-util.h>
-#include <math.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomeui/gnome-icon-theme.h>
+#include <gtk/gtkicontheme.h>
 
 #define spinner_DEFAULT_TIMEOUT 100	/* Milliseconds Per Frame */
 
+#define EPHY_SPINNER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SPINNER, EphySpinnerDetails))
+
 struct EphySpinnerDetails {
 	GList	*image_list;
 	GdkPixbuf *quiescent_pixbuf;
-	GnomeIconTheme *icon_theme;
+	GtkIconTheme *icon_theme;
 
 	int	max_frame;
 	int	delay;
@@ -64,14 +62,9 @@ static void ephy_spinner_init (EphySpinner *spinner);
 static void ephy_spinner_load_images            (EphySpinner *spinner);
 static void ephy_spinner_unload_images          (EphySpinner *spinner);
 static void ephy_spinner_remove_update_callback (EphySpinner *spinner);
-static void ephy_spinner_theme_changed     (GnomeIconTheme *icon_theme,
+static void ephy_spinner_theme_changed     (GtkIconTheme *icon_theme,
                                                  EphySpinner *spinner);
 
-static GList *spinner_directories = NULL;
-
-static void
-ephy_spinner_init_directory_list (void);
-
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -97,8 +90,6 @@ ephy_spinner_get_type (void)
                 ephy_spinner_type = g_type_register_static (GTK_TYPE_EVENT_BOX,
                                                               "EphySpinner",
                                                               &our_info, 0);
-
-		ephy_spinner_init_directory_list ();
         }
 
         return ephy_spinner_type;
@@ -119,7 +110,7 @@ ephy_spinner_new (void)
 {
         GtkWidget *s;
 
-        s = GTK_WIDGET (g_object_new (EPHY_SPINNER_TYPE, NULL));
+        s = GTK_WIDGET (g_object_new (EPHY_TYPE_SPINNER, NULL));
 
         return s;
 }
@@ -184,10 +175,10 @@ ephy_spinner_init (EphySpinner *spinner)
 			       | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
 			       | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 
-	spinner->details = g_new0 (EphySpinnerDetails, 1);
+	spinner->details = EPHY_SPINNER_GET_PRIVATE (spinner);
 
 	spinner->details->delay = spinner_DEFAULT_TIMEOUT;
-	spinner->details->icon_theme = gnome_icon_theme_new ();
+	spinner->details->icon_theme = gtk_icon_theme_get_default ();
 	g_signal_connect (spinner->details->icon_theme,
 			  "changed",
 			  G_CALLBACK (ephy_spinner_theme_changed),
@@ -199,7 +190,7 @@ ephy_spinner_init (EphySpinner *spinner)
 
 /* handler for handling theme changes */
 static void
-ephy_spinner_theme_changed (GnomeIconTheme *icon_theme, EphySpinner *spinner)
+ephy_spinner_theme_changed (GtkIconTheme *icon_theme, EphySpinner *spinner)
 {
 	gtk_widget_hide (GTK_WIDGET (spinner));
 	ephy_spinner_load_images (spinner);
@@ -242,7 +233,7 @@ ephy_spinner_expose (GtkWidget *widget, GdkEventExpose *event)
 	int x_offset, y_offset, width, height;
 	GdkRectangle pix_area, dest;
 
-	g_return_val_if_fail (IS_EPHY_SPINNER (widget), FALSE);
+	g_return_val_if_fail (EPHY_IS_SPINNER (widget), FALSE);
 
 	spinner = EPHY_SPINNER (widget);
 
@@ -426,20 +417,25 @@ static void
 ephy_spinner_load_images (EphySpinner *spinner)
 {
 	int grid_width, grid_height, x, y, size;
-	char *icon;
+	const char *icon;
 	GdkPixbuf *icon_pixbuf, *pixbuf;
 	GList *image_list;
+	GtkIconInfo *icon_info;
 
 	ephy_spinner_unload_images (spinner);
 
 	/* Load the animation */
-	icon = gnome_icon_theme_lookup_icon (spinner->details->icon_theme,
-					     "gnome-spinner", -1, NULL, &size);
-	if (icon == NULL) {
+	icon_info = gtk_icon_theme_lookup_icon (spinner->details->icon_theme,
+					        "gnome-spinner", -1, 0);
+	if (icon_info == NULL) {
 		g_warning ("Throbber animation not found");
 		return;
 	}
 
+	size = gtk_icon_info_get_base_size (icon_info);
+	icon = gtk_icon_info_get_filename (icon_info);
+	g_return_if_fail (icon_info != NULL);
+
 	icon_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
 	grid_width = gdk_pixbuf_get_width (icon_pixbuf);
 	grid_height = gdk_pixbuf_get_height (icon_pixbuf);
@@ -462,22 +458,24 @@ ephy_spinner_load_images (EphySpinner *spinner)
 	spinner->details->image_list = g_list_reverse (image_list);
 	spinner->details->max_frame = g_list_length (spinner->details->image_list);
 
-	g_free (icon);
+	gtk_icon_info_free (icon_info);
 	g_object_unref (icon_pixbuf);
 
 	/* Load the rest icon */
-	icon = gnome_icon_theme_lookup_icon (spinner->details->icon_theme,
-					     "gnome-spinner-rest", -1, NULL, &size);
+	icon_info = gtk_icon_theme_lookup_icon (spinner->details->icon_theme,
+					        "gnome-spinner-rest", -1, 0);
 	if (icon == NULL) {
 		g_warning ("Throbber rest icon not found");
 		return;
 	}
 
+	size = gtk_icon_info_get_base_size (icon_info);
+	icon = gtk_icon_info_get_filename (icon_info);
 	icon_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
 	spinner->details->quiescent_pixbuf = scale_to_real_size (spinner, icon_pixbuf);
 
 	g_object_unref (icon_pixbuf);
-	g_free (icon);
+	gtk_icon_info_free (icon_info);
 }
 
 /*
@@ -517,44 +515,29 @@ ephy_spinner_size_request (GtkWidget *widget, GtkRequisition *requisition)
 static void
 ephy_spinner_finalize (GObject *object)
 {
-	EphySpinner *spinner;
-
-	spinner = EPHY_SPINNER (object);
+	EphySpinner *spinner = EPHY_SPINNER (object);
 
 	ephy_spinner_remove_update_callback (spinner);
 	ephy_spinner_unload_images (spinner);
 
-	g_object_unref (spinner->details->icon_theme);
-
-	g_free (spinner->details);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
 ephy_spinner_class_init (EphySpinnerClass *class)
 {
+	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (class);
+	object_class = G_OBJECT_CLASS (class);
 	widget_class = GTK_WIDGET_CLASS (class);
 
-	G_OBJECT_CLASS (class)->finalize = ephy_spinner_finalize;
+	parent_class = g_type_class_peek_parent (class);
+
+	object_class->finalize = ephy_spinner_finalize;
 
 	widget_class->expose_event = ephy_spinner_expose;
 	widget_class->size_request = ephy_spinner_size_request;
-}
 
-static void
-ephy_spinner_init_directory_list (void)
-{
-	gchar *path;
-
-	path = g_build_filename (SHARE_DIR, "..", "pixmaps", "nautilus", NULL);
-	spinner_directories = g_list_append (spinner_directories, path);
-
-#ifdef NAUTILUS_PREFIX
-	path = g_build_filename (NAUTILUS_PREFIX, "share", "pixmaps", "nautilus", NULL);
-	spinner_directories = g_list_append (spinner_directories, path);
-#endif
+	g_type_class_add_private (object_class, sizeof (EphySpinnerDetails));
 }
