@@ -22,26 +22,30 @@
 
 #include "ephy-bookmarks-menu.h"
 #include "ephy-bookmark-action.h"
-#include "egg-menu-merge.h"
 #include "ephy-shell.h"
 #include "ephy-node-common.h"
+#include "ephy-string.h"
 #include "ephy-debug.h"
 
-#include <string.h>
-#include <stdlib.h>
-#include <libxml/entities.h>
+//#include <libxml/entities.h>
+#include <glib/gprintf.h>
 #include <bonobo/bonobo-i18n.h>
+#include <gtk/gtkuimanager.h>
 
-#define EMPTY_ACTION_NAME "GoBookmarkEmpty"
+#define BOOKMARKS_MENU_PATH "/menubar/BookmarksMenu"
 
 /**
  * Private data
  */
+ 
+#define EPHY_BOOKMARKS_MENU_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARKS_MENU, EphyBookmarksMenuPrivate))
+
 struct _EphyBookmarksMenuPrivate
 {
+	GtkUIManager *merge;
 	EphyWindow *window;
 	EphyBookmarks *bookmarks;
-	EggActionGroup *action_group;
+	GtkActionGroup *action_group;
 	guint ui_id;
 	guint update_tag;
 };
@@ -92,24 +96,23 @@ static void
 ephy_bookmarks_menu_clean (EphyBookmarksMenu *menu)
 {
 	EphyBookmarksMenuPrivate *p = menu->priv;
-	EggMenuMerge *merge = EGG_MENU_MERGE (p->window->ui_merge);
 
 	if (p->ui_id > 0)
 	{
-		egg_menu_merge_remove_ui (merge, p->ui_id);
-		egg_menu_merge_ensure_update (merge);
+		gtk_ui_manager_remove_ui (p->merge, p->ui_id);
+		gtk_ui_manager_ensure_update (p->merge);
 		p->ui_id = 0;
 	}
 
 	if (p->action_group != NULL)
 	{
-		egg_menu_merge_remove_action_group (merge, p->action_group);
+		gtk_ui_manager_remove_action_group (p->merge, p->action_group);
 		g_object_unref (p->action_group);
 	}
 }
 
 static void
-go_location_cb (EggAction *action, char *location, EphyWindow *window)
+go_location_cb (GtkAction *action, char *location, EphyWindow *window)
 {
 	ephy_window_load_url (window, location);
 }
@@ -181,78 +184,60 @@ sort_bookmarks (gconstpointer a, gconstpointer b)
 }
 
 static void
-add_bookmarks_menu (EphyBookmarksMenu *menu, EphyNode *node, GString *xml)
+add_bookmarks_menu (EphyBookmarksMenu *menu, EphyNode *node, const char *path)
 {
 	GPtrArray *children;
 	EphyBookmarksMenuPrivate *p = menu->priv;
+	GList *node_list = NULL, *l;
+	int i;
 
 	children = ephy_node_get_children (node);
-
-	if (children->len < 1)
+	for (i = 0; i < children->len; ++i)
 	{
-		g_string_append (xml, "<menuitem name=\"");
-		g_string_append (xml, EMPTY_ACTION_NAME"Menu");
-		g_string_append (xml, "Menu");
-		g_string_append (xml, "\" verb=\"");
-		g_string_append (xml, EMPTY_ACTION_NAME);
-		g_string_append (xml, "\"/>\n");
+		node_list = g_list_prepend (node_list,
+					    g_ptr_array_index (children, i));
 	}
-	else
+
+	if (node_list != NULL)
 	{
-		GList *node_list = NULL, *l;
-		int i;
-
-		for (i = 0; i < children->len; ++i)
-		{
-			node_list = g_list_prepend (node_list,
-						    g_ptr_array_index (children, i));
-		}
-
 		node_list = g_list_sort (node_list, (GCompareFunc)sort_bookmarks);
-
 		for (l = node_list; l != NULL; l = l->next)
 		{
-			EggAction *action;
+			GtkAction *action;
 			EphyNode *child;
 			long id;
-			char *verb;
+			char verb[30], name[30];
 
 			child = l->data;
 			id = ephy_node_get_id (child);
-			verb = g_strdup_printf ("OpenBookmark%ld", id);
+			g_sprintf (verb, "OpenTopic%ld", ephy_node_get_id (child));
+			g_sprintf (name, "%sName", verb);
 
 			action = ephy_bookmark_action_new (verb, id);
-			egg_action_group_add_action (p->action_group, action);
+			gtk_action_group_add_action (p->action_group, action);
 			g_object_unref (action);
 			g_signal_connect (action, "go_location",
 					  G_CALLBACK (go_location_cb), p->window);
 
-			g_string_append (xml, "<menuitem name=\"");
-			g_string_append (xml, verb);
-			g_string_append (xml, "Menu");
-			g_string_append (xml, "\" verb=\"");
-			g_string_append (xml, verb);
-			g_string_append (xml, "\"/>\n");
-
-			g_free (verb);
+			gtk_ui_manager_add_ui (p->merge, p->ui_id, path,
+					       name, verb,
+					       GTK_UI_MANAGER_MENUITEM, FALSE);
 		}
-
 		g_list_free (node_list);
 	}
+
+	ephy_node_thaw (node);
 }
 
 static void
 ephy_bookmarks_menu_rebuild (EphyBookmarksMenu *menu)
 {
 	EphyBookmarksMenuPrivate *p = menu->priv;
-	GString *xml;
 	gint i;
 	EphyNode *topics;
 	EphyNode *not_categorized;
 	GPtrArray *children;
-	EggMenuMerge *merge = EGG_MENU_MERGE (p->window->ui_merge);
 	GList *node_list = NULL, *l;
-	EggAction *empty;
 
 	LOG ("Rebuilding bookmarks menu")
 
@@ -264,22 +249,10 @@ ephy_bookmarks_menu_rebuild (EphyBookmarksMenu *menu)
 	not_categorized = ephy_bookmarks_get_not_categorized (p->bookmarks);
 	children = ephy_node_get_children (topics);
 
-	xml = g_string_new (NULL);
-	g_string_append (xml, "<Root><menu><submenu name=\"BookmarksMenu\">"
-			      "<placeholder name=\"BookmarksTree\">"
-			      "<separator name=\"BookmarksSep1\"/>");
+	p->ui_id = gtk_ui_manager_new_merge_id (p->merge);
 
-	p->action_group = egg_action_group_new ("BookmarksActions");
-	egg_menu_merge_insert_action_group (merge, p->action_group, 0);
-
-	empty = g_object_new (EGG_TYPE_ACTION,
-			      "name", EMPTY_ACTION_NAME,
-			      /* This is the adjective, not the verb */
-			      "label", _("Empty"),
-			      "sensitive", FALSE,
-			      NULL);
-	egg_action_group_add_action (p->action_group, empty);
-	g_object_unref (empty);
+	p->action_group = gtk_action_group_new ("BookmarksActions");
+	gtk_ui_manager_insert_action_group (p->merge, p->action_group, 0);
 
 	for (i = 0; i < children->len; ++i)
 	{
@@ -296,62 +269,62 @@ ephy_bookmarks_menu_rebuild (EphyBookmarksMenu *menu)
 			node_list = g_list_prepend (node_list, kid);
 		}
 	}
+	ephy_node_thaw (topics);
 
 	node_list = g_list_sort (node_list, (GCompareFunc)sort_topics);
 
 	for (l = node_list; l != NULL; l = l->next)
 	{
-		char *verb;
-		const char *title;
+		char verb[30], name[30], path[60];
+		const char *tmp;
+		char *title;
 		EphyNode *child;
-		EggAction *action;
+		GtkAction *action;
 
 		child = l->data;
-		title = ephy_node_get_property_string (child, EPHY_NODE_KEYWORD_PROP_NAME);
 
-		verb = g_strdup_printf ("OpenTopic%ld", ephy_node_get_id (child));
-		action = g_object_new (EGG_TYPE_ACTION,
+		tmp = ephy_node_get_property_string (child, EPHY_NODE_KEYWORD_PROP_NAME);
+		title = ephy_string_double_underscores (tmp);
+		
+		g_sprintf (verb, "OpenTopic%ld", ephy_node_get_id (child));
+		g_sprintf (name, "%sName", verb);
+		g_sprintf (path, "%s/%s", BOOKMARKS_MENU_PATH, name);
+
+		action = g_object_new (GTK_TYPE_ACTION,
 				       "name", verb,
 				       "label", title,
+				       "hide_if_empty", FALSE,
 				       NULL);
-		egg_action_group_add_action (p->action_group, action);
+		gtk_action_group_add_action (p->action_group, action);
 		g_object_unref (action);
+		g_free (title);
 
-		g_string_append (xml, "<submenu name=\"");
-		g_string_append (xml, verb);
-		g_string_append (xml, "Menu");
-		g_string_append (xml, "\" verb=\"");
-		g_string_append (xml, verb);
-		g_string_append (xml, "\">\n");
+		gtk_ui_manager_add_ui (p->merge, p->ui_id,
+				       BOOKMARKS_MENU_PATH,
+				       name, verb,
+				       GTK_UI_MANAGER_MENU, FALSE);
 
-		add_bookmarks_menu (menu, child, xml);
-
-		g_string_append (xml, "</submenu>");
-
-		g_free (verb);
+		add_bookmarks_menu (menu, child, path);
 	}
 
 	if (ephy_node_get_n_children (not_categorized) > 0)
 	{
-		add_bookmarks_menu (menu, not_categorized, xml);
+		add_bookmarks_menu (menu, not_categorized, BOOKMARKS_MENU_PATH);
 	}
 
-	g_string_append (xml, "</placeholder></submenu></menu></Root>");
-
-	if (children->len > 0)
-	{
-		GError *error = NULL;
-		LOG ("Merging ui\n%s",xml->str);
-		p->ui_id = egg_menu_merge_add_ui_from_string
-			(merge, xml->str, -1, &error);
-	}
-
-	g_string_free (xml, TRUE);
 	g_list_free (node_list);
 
 	STOP_PROFILER ("Rebuilding bookmarks menu")
 }
 
+static void
+ephy_bookmarks_menu_set_window (EphyBookmarksMenu *menu, EphyWindow *window)
+{
+	menu->priv->window = window;
+	menu->priv->merge = GTK_UI_MANAGER (window->ui_merge);
+	ephy_bookmarks_menu_rebuild (menu);
+}
+
 static void
 ephy_bookmarks_menu_set_property (GObject *object,
 				  guint prop_id,
@@ -363,8 +336,8 @@ ephy_bookmarks_menu_set_property (GObject *object,
         switch (prop_id)
         {
                 case PROP_EPHY_WINDOW:
-                        m->priv->window = g_value_get_object (value);
-			ephy_bookmarks_menu_rebuild (m);
+                        ephy_bookmarks_menu_set_window
+				(m, g_value_get_object (value));
                         break;
         }
 }
@@ -402,9 +375,11 @@ ephy_bookmarks_menu_class_init (EphyBookmarksMenuClass *klass)
                                          g_param_spec_object ("EphyWindow",
                                                               "EphyWindow",
                                                               "Parent window",
-                                                              EPHY_WINDOW_TYPE,
+                                                              EPHY_TYPE_WINDOW,
                                                               G_PARAM_READWRITE |
 							      G_PARAM_CONSTRUCT_ONLY));
+
+	g_type_class_add_private (object_class, sizeof(EphyBookmarksMenuPrivate));
 }
 
 static gboolean
@@ -429,7 +404,7 @@ bookmarks_tree_changed_cb (EphyBookmarks *bookmarks, EphyBookmarksMenu *menu)
 static void
 ephy_bookmarks_menu_init (EphyBookmarksMenu *menu)
 {
-	EphyBookmarksMenuPrivate *p = g_new0 (EphyBookmarksMenuPrivate, 1);
+	EphyBookmarksMenuPrivate *p = EPHY_BOOKMARKS_MENU_GET_PRIVATE (menu);
 
 	menu->priv = p;
 
@@ -456,14 +431,9 @@ ephy_bookmarks_menu_finalize (GObject *o)
 
 	if (p->action_group != NULL)
 	{
-		egg_menu_merge_remove_action_group
-			(EGG_MENU_MERGE (p->window->ui_merge),
-			 p->action_group);
 		g_object_unref (p->action_group);
 	}
 
-	g_free (p);
-
 	G_OBJECT_CLASS (parent_class)->finalize (o);
 }
 
