@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.59.2.3 2003/12/18 12:48:45 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.64 2003/10/18 11:29:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,17 +32,19 @@
 #include "ephy-toolbars-model.h"
 #include "ephy-bookmarks-export.h"
 #include "ephy-bookmarks-import.h"
-#include "ephy-autocompletion.h"
 #include "session.h"
 
 #include <string.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#define EPHY_BOOKMARKS_XML_VERSION "1.0"
+#define EPHY_BOOKMARKS_XML_ROOT    "ephy_bookmarks"
+#define EPHY_BOOKMARKS_XML_VERSION "1.01"
 #define BOOKMARKS_SAVE_DELAY (3 * 1000)
 #define MAX_FAVORITES_NUM 10
 
+#define EPHY_BOOKMARKS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARKS, EphyBookmarksPrivate))
+
 struct EphyBookmarksPrivate
 {
 	EphyToolbarsModel *toolbars_model;
@@ -56,6 +58,7 @@ struct EphyBookmarksPrivate
 	EphyNode *keywords;
 	EphyNode *favorites;
 	EphyNode *notcategorized;
+	EphyNode *smartbookmarks;
 	EphyNode *lower_fav;
 	double lower_score;
 };
@@ -109,8 +112,6 @@ static void
 ephy_bookmarks_init (EphyBookmarks *tab);
 static void
 ephy_bookmarks_finalize (GObject *object);
-static void
-ephy_bookmarks_autocompletion_source_init (EphyAutocompletionSourceIface *iface);
 
 static GObjectClass *parent_class = NULL;
 
@@ -134,77 +135,14 @@ ephy_bookmarks_get_type (void)
                         (GInstanceInitFunc) ephy_bookmarks_init
                 };
 
-		static const GInterfaceInfo autocompletion_source_info =
-		{
-			(GInterfaceInitFunc) ephy_bookmarks_autocompletion_source_init,
-			NULL,
-			NULL
-		};
-
                 ephy_bookmarks_type = g_type_register_static (G_TYPE_OBJECT,
 							      "EphyBookmarks",
 							      &our_info, 0);
-
-		g_type_add_interface_static (ephy_bookmarks_type,
-					     EPHY_TYPE_AUTOCOMPLETION_SOURCE,
-					     &autocompletion_source_info);
         }
 
         return ephy_bookmarks_type;
 }
 
-static void
-ephy_bookmarks_autocompletion_source_set_basic_key (EphyAutocompletionSource *source,
-						    const gchar *basic_key)
-{
-	/* nothing to do here */
-}
-
-static void
-ephy_bookmarks_autocompletion_source_foreach (EphyAutocompletionSource *source,
-					      const gchar *current_text,
-					      EphyAutocompletionSourceForeachFunc func,
-					      gpointer data)
-{
-	GPtrArray *children;
-	int i;
-	EphyBookmarks *eb = EPHY_BOOKMARKS (source);
-
-	children = ephy_node_get_children (eb->priv->bookmarks);
-	for (i = 0; i < children->len; i++)
-	{
-		EphyNode *kid;
-		const char *url, *title, *keywords;
-		gboolean smart_url;
-
-		kid = g_ptr_array_index (children, i);
-		url = ephy_node_get_property_string
-			(kid, EPHY_NODE_BMK_PROP_LOCATION);
-		smart_url = ephy_node_get_property_boolean
-			(kid, EPHY_NODE_BMK_PROP_HAS_SMART_ADDRESS);
-		title = ephy_node_get_property_string
-			(kid, EPHY_NODE_BMK_PROP_TITLE);
-		keywords = ephy_node_get_property_string
-			(kid, EPHY_NODE_BMK_PROP_KEYWORDS);
-
-		func (source, keywords, title, url, smart_url,
-		      !smart_url, 0, data);
-	}
-}
-
-static void
-ephy_bookmarks_emit_data_changed (EphyBookmarks *eb)
-{
-	g_signal_emit_by_name (eb, "data-changed");
-}
-
-static void
-ephy_bookmarks_autocompletion_source_init (EphyAutocompletionSourceIface *iface)
-{
-	iface->foreach = ephy_bookmarks_autocompletion_source_foreach;
-	iface->set_basic_key = ephy_bookmarks_autocompletion_source_set_basic_key;
-}
-
 static void
 ephy_bookmarks_init_defaults (EphyBookmarks *eb)
 {
@@ -302,52 +240,10 @@ ephy_bookmarks_class_init (EphyBookmarksClass *klass)
                                          g_param_spec_object ("toolbars_model",
                                                               "Toolbars model",
                                                               "Toolbars model",
-                                                              EPHY_TOOLBARS_MODEL_TYPE,
+                                                              EPHY_TYPE_TOOLBARS_MODEL,
                                                               G_PARAM_READWRITE));
 
-}
-
-static gboolean
-ephy_bookmarks_load (EphyBookmarks *eb)
-{
-	xmlDocPtr doc;
-	xmlNodePtr root, child;
-	char *tmp;
-	gboolean result = TRUE;
-
-	if (g_file_test (eb->priv->xml_file, G_FILE_TEST_EXISTS) == FALSE)
-		return FALSE;
-
-	doc = xmlParseFile (eb->priv->xml_file);
-	if (doc == NULL)
-	{
-		g_warning ("Failed to load bookmarks file %s!\n", eb->priv->xml_file);
-		return FALSE;
-	}
-
-	root = xmlDocGetRootElement (doc);
-	child = root->children;
-	
-	tmp = xmlGetProp (root, "version");
-	if (tmp != NULL && strcmp (tmp, EPHY_BOOKMARKS_XML_VERSION) != 0)
-	{
-		g_warning ("Old bookmarks database format detected");
-
-		child = NULL;
-		result = FALSE;
-	}
-	g_free (tmp);
-
-	for (; child != NULL; child = child->next)
-	{
-		EphyNode *node;
-
-		node = ephy_node_new_from_xml (eb->priv->db, child);
-	}
-
-	xmlFreeDoc (doc);
-
-	return result;
+	g_type_class_add_private (object_class, sizeof(EphyBookmarksPrivate));
 }
 
 static void
@@ -386,6 +282,7 @@ ephy_bookmarks_save (EphyBookmarks *eb)
 			ephy_node_save_to_xml (kid, root);
 		}
 	}
+	ephy_node_thaw (eb->priv->keywords);
 
 	children = ephy_node_get_children (eb->priv->bookmarks);
 	for (i = 0; i < children->len; i++)
@@ -396,6 +293,7 @@ ephy_bookmarks_save (EphyBookmarks *eb)
 
 		ephy_node_save_to_xml (kid, root);
 	}
+	ephy_node_thaw (eb->priv->bookmarks);
 
 	ephy_file_save_xml (eb->priv->xml_file, doc);
 	xmlFreeDoc(doc);
@@ -473,6 +371,7 @@ compute_lower_fav (EphyNode *favorites, double *score)
 			result = child;
 		}
 	}
+	ephy_node_thaw (favorites);
 
 	if (result == NULL) *score = 0;
 
@@ -498,7 +397,7 @@ add_to_favorites (EphyBookmarks *eb, EphyNode *node, EphyHistory *eh)
 	url = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_LOCATION);
 	score = get_history_item_score (eh, url);
 	full_menu = ephy_node_get_n_children (eb->priv->favorites)
-		    > MAX_FAVORITES_NUM;
+		    >= MAX_FAVORITES_NUM;
 	if (full_menu && score < eb->priv->lower_score) return FALSE;
 
 	if (eb->priv->lower_fav && full_menu)
@@ -513,23 +412,6 @@ add_to_favorites (EphyBookmarks *eb, EphyNode *node, EphyHistory *eh)
 	return TRUE;
 }
 
-static void
-update_favorites_menus ()
-{
-	Session *session;
-	const GList *l;
-
-	session = SESSION (ephy_shell_get_session (ephy_shell));
-	l = session_get_windows (session);
-
-	for (; l != NULL; l = l->next)
-	{
-		EphyWindow *window = EPHY_WINDOW (l->data);
-
-		ephy_window_update_control (window, FavoritesControl);
-	}
-}
-
 static void
 history_site_visited_cb (EphyHistory *gh, const char *url, EphyBookmarks *eb)
 {
@@ -538,10 +420,7 @@ history_site_visited_cb (EphyHistory *gh, const char *url, EphyBookmarks *eb)
 	node = ephy_bookmarks_find_bookmark (eb, url);
 	if (node == NULL) return;
 
-	if (add_to_favorites (eb, node, gh))
-	{
-		update_favorites_menus ();
-	}
+	add_to_favorites (eb, node, gh);
 }
 
 static void
@@ -562,7 +441,6 @@ bookmarks_changed_cb (EphyNode *node,
 		      EphyNode *child,
 		      EphyBookmarks *eb)
 {
-	ephy_bookmarks_emit_data_changed (eb);
 	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
 }
 
@@ -572,7 +450,6 @@ bookmarks_removed_cb (EphyNode *node,
 		      guint old_index,
 		      EphyBookmarks *eb)
 {
-	ephy_bookmarks_emit_data_changed (eb);
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
 }
@@ -608,6 +485,7 @@ get_topics_list (EphyBookmarks *eb,
 			*no_topics = FALSE;
 		}
 	}
+	ephy_node_thaw (eb->priv->keywords);
 
 	return g_string_free (list, FALSE);
 }
@@ -655,6 +533,7 @@ topics_removed_cb (EphyNode *node,
 
 		g_free (list);
 	}
+	ephy_node_thaw (child);
 
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
@@ -665,9 +544,7 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	GValue value = { 0, };
 	EphyNodeDb *db;
 
-	LOG ("Init");
-
-        eb->priv = g_new0 (EphyBookmarksPrivate, 1);
+	eb->priv = EPHY_BOOKMARKS_GET_PRIVATE (eb);
 	eb->priv->toolbars_model = NULL;
 
 	db = ephy_node_db_new (EPHY_NODE_DB_BOOKMARKS);
@@ -750,16 +627,20 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 	g_value_unset (&value);
 	ephy_node_add_child (eb->priv->keywords, eb->priv->notcategorized);
 
-	if (!ephy_bookmarks_load (eb))
+	/* Smart bookmarks */
+	eb->priv->smartbookmarks = ephy_node_new_with_id (db, SMARTBOOKMARKS_NODE_ID);
+	ephy_node_ref (eb->priv->smartbookmarks);
+
+	if (ephy_node_db_load_from_file (eb->priv->db, eb->priv->xml_file,
+					 EPHY_BOOKMARKS_XML_ROOT,
+					 EPHY_BOOKMARKS_XML_VERSION) == FALSE)
 	{
-		if (!ephy_bookmarks_import_rdf (eb, eb->priv->rdf_file))
+		if (ephy_bookmarks_import_rdf (eb, eb->priv->rdf_file) == FALSE)
 		{
-			eb->priv->init_defaults = !ephy_bookmarks_load (eb);
+			eb->priv->init_defaults = TRUE;
 		}
 	}
 
-	ephy_bookmarks_emit_data_changed (eb);
-
 	ephy_setup_history_notifiers (eb);
 	ephy_bookmarks_update_favorites (eb);
 }
@@ -767,13 +648,7 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 static void
 ephy_bookmarks_finalize (GObject *object)
 {
-        EphyBookmarks *eb;
-
-	g_return_if_fail (IS_EPHY_BOOKMARKS (object));
-
-	eb = EPHY_BOOKMARKS (object);
-
-        g_return_if_fail (eb->priv != NULL);
+	EphyBookmarks *eb = EPHY_BOOKMARKS (object);
 
 	if (eb->priv->save_timeout_id != 0)
 	{
@@ -798,8 +673,6 @@ ephy_bookmarks_finalize (GObject *object)
 	g_free (eb->priv->xml_file);
 	g_free (eb->priv->rdf_file);
 
-        g_free (eb->priv);
-
 	LOG ("Bookmarks finalized")
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -808,29 +681,40 @@ ephy_bookmarks_finalize (GObject *object)
 EphyBookmarks *
 ephy_bookmarks_new ()
 {
-	EphyBookmarks *tab;
+	EphyBookmarks *eb;
 
-	tab = EPHY_BOOKMARKS (g_object_new (EPHY_BOOKMARKS_TYPE, NULL));
+	eb = EPHY_BOOKMARKS (g_object_new (EPHY_TYPE_BOOKMARKS, NULL));
 
-	return tab;
+	return eb;
 }
 
 static void
-update_has_smart_address (EphyNode *bmk, const char *address)
+update_has_smart_address (EphyBookmarks *bookmarks, EphyNode *bmk, const char *address)
 {
+	EphyNode *smart_bmks;
 	gboolean smart = FALSE;
-	GValue value = { 0, };
+
+	smart_bmks = bookmarks->priv->smartbookmarks;
 
 	if (address)
 	{
 		smart = strstr (address, "%s") != NULL;
 	}
 
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, smart);
-	ephy_node_set_property (bmk, EPHY_NODE_BMK_PROP_HAS_SMART_ADDRESS,
-			        &value);
-	g_value_unset (&value);
+	if (smart)
+	{
+		if (!ephy_node_has_child (smart_bmks, bmk))
+		{
+			ephy_node_add_child (smart_bmks, bmk);
+		}
+	}
+	else
+	{
+		if (ephy_node_has_child (smart_bmks, bmk))
+		{
+			ephy_node_add_child (smart_bmks, bmk);
+		}
+	}
 }
 
 EphyNode *
@@ -855,12 +739,11 @@ ephy_bookmarks_add (EphyBookmarks *eb,
 			        &value);
 	g_value_unset (&value);
 
-	update_has_smart_address (bm, url);
+	update_has_smart_address (eb, bm, url);
 
 	ephy_node_add_child (eb->priv->bookmarks, bm);
 	ephy_node_add_child (eb->priv->notcategorized, bm);
 
-	ephy_bookmarks_emit_data_changed (eb);
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 	ephy_bookmarks_save_delayed (eb, 0);
 
@@ -880,7 +763,7 @@ ephy_bookmarks_set_address (EphyBookmarks *eb,
 			        &value);
 	g_value_unset (&value);
 
-	update_has_smart_address (bookmark, address);
+	update_has_smart_address (eb, bookmark, address);
 }
 
 EphyNode *
@@ -890,7 +773,7 @@ ephy_bookmarks_find_bookmark (EphyBookmarks *eb,
 	GPtrArray *children;
 	int i;
 
-	g_return_val_if_fail (IS_EPHY_BOOKMARKS (eb), NULL);
+	g_return_val_if_fail (EPHY_IS_BOOKMARKS (eb), NULL);
 	g_return_val_if_fail (eb->priv->bookmarks != NULL, NULL);
 	g_return_val_if_fail (url != NULL, NULL);
 
@@ -906,9 +789,11 @@ ephy_bookmarks_find_bookmark (EphyBookmarks *eb,
 
 		if (location != NULL && strcmp (url, location) == 0)
 		{
+			ephy_node_thaw (eb->priv->bookmarks);
 			return kid;
 		}
 	}
+	ephy_node_thaw (eb->priv->bookmarks);
 
 	return NULL;
 }
@@ -1205,6 +1090,7 @@ ephy_bookmarks_find_keyword (EphyBookmarks *eb,
 			 node = kid;
 		 }
 	}
+	ephy_node_thaw (eb->priv->keywords);
 
 	return node;
 }
@@ -1272,6 +1158,12 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
 
+EphyNode *
+ephy_bookmarks_get_smart_bookmarks (EphyBookmarks *eb)
+{
+	return eb->priv->smartbookmarks;
+}
+
 EphyNode *
 ephy_bookmarks_get_keywords (EphyBookmarks *eb)
 {
