@@ -15,19 +15,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.25.2.1 2003/12/18 12:48:45 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.32 2003/10/10 19:24:33 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include "ephy-node-common.h"
+#include <gtk/gtktoolitem.h>
+#include <bonobo/bonobo-i18n.h>
+
 #include "ephy-topic-action.h"
+#include "ephy-node-common.h"
 #include "ephy-bookmarks.h"
 #include "ephy-favicon-cache.h"
 #include "ephy-shell.h"
-#include "eggtoolitem.h"
 #include "ephy-debug.h"
 #include "ephy-gui.h"
 #include "ephy-string.h"
@@ -35,6 +37,8 @@
 static void ephy_topic_action_init       (EphyTopicAction *action);
 static void ephy_topic_action_class_init (EphyTopicActionClass *class);
 
+#define EPHY_TOPIC_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOPIC_ACTION, EphyTopicActionPrivate))
+
 struct EphyTopicActionPrivate
 {
 	int topic_id;
@@ -76,7 +80,7 @@ ephy_topic_action_get_type (void)
 			(GInstanceInitFunc) ephy_topic_action_init,
 		};
 
-		type = g_type_register_static (EGG_TYPE_ACTION,
+		type = g_type_register_static (GTK_TYPE_ACTION,
 					       "EphyTopicAction",
 					       &type_info, 0);
 	}
@@ -84,7 +88,7 @@ ephy_topic_action_get_type (void)
 }
 
 static GtkWidget *
-create_tool_item (EggAction *action)
+create_tool_item (GtkAction *action)
 {
 	GtkWidget *item;
 	GtkWidget *button;
@@ -92,7 +96,7 @@ create_tool_item (EggAction *action)
 	GtkWidget *hbox;
 	GtkWidget *label;
 
-	item = (* EGG_ACTION_CLASS (parent_class)->create_tool_item) (action);
+	item = (* GTK_ACTION_CLASS (parent_class)->create_tool_item) (action);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
@@ -128,7 +132,7 @@ menu_deactivate_cb (GtkMenuShell *ms, GtkWidget *button)
 }
 
 static void
-menu_activate_cb (GtkWidget *item, EggAction *action)
+menu_activate_cb (GtkWidget *item, GtkAction *action)
 {
 	EphyNode *node;
 	const char *location;
@@ -141,13 +145,18 @@ menu_activate_cb (GtkWidget *item, EggAction *action)
 }
 
 static void
-ephy_topic_action_sync_label (EggAction *action, GParamSpec *pspec, GtkWidget *proxy)
+ephy_topic_action_sync_label (GtkAction *action, GParamSpec *pspec, GtkWidget *proxy)
 {
 	GtkWidget *label = NULL;
+	GValue value = { 0, };
+	const char *label_text;
 
-	LOG ("Set bookmark action proxy label to %s", action->label)
+	g_value_init (&value, G_TYPE_STRING);
+	g_object_get_property (G_OBJECT (action), "label", &value);
 
-	if (EGG_IS_TOOL_ITEM (proxy))
+	label_text = g_value_get_string (&value);
+
+	if (GTK_IS_TOOL_ITEM (proxy))
 	{
 		label = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "label"));
 	}
@@ -163,10 +172,12 @@ ephy_topic_action_sync_label (EggAction *action, GParamSpec *pspec, GtkWidget *p
 
 	g_return_if_fail (label != NULL);
 
-	if (action->label)
+	if (label_text)
 	{
-		gtk_label_set_label (GTK_LABEL (label), action->label);
+		gtk_label_set_label (GTK_LABEL (label), label_text);
 	}
+
+	g_value_unset (&value);
 }
 
 static int
@@ -282,6 +293,8 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 
 		g_list_free (node_list);
 	}
+
+	ephy_node_thaw (node);
 }
 
 static GtkWidget *
@@ -387,6 +400,7 @@ build_topics_menu (EphyTopicAction *action, EphyNode *node)
 		gtk_widget_show (bmk_menu);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), bmk_menu);
 	}
+	ephy_node_thaw (node);
 	g_list_free (node_list);
 
 	uncategorized = ephy_bookmarks_get_not_categorized (bookmarks);
@@ -442,13 +456,25 @@ button_pressed_cb (GtkWidget *button,
 }
 
 static GtkWidget *
-create_menu_item (EggAction *action)
+create_menu_item (GtkAction *action)
 {
 	GtkWidget *menu, *menu_item;
+	GValue value = { 0, };
+	const char *tmp;
+	char *label_text;
+
+	g_value_init (&value, G_TYPE_STRING);
+	g_object_get_property (G_OBJECT (action), "label", &value);
+
+	tmp = g_value_get_string (&value);
+	label_text = ephy_string_double_underscores (tmp);
 
 	LOG ("create_menu_item action %p", action)
 
-	menu_item = gtk_menu_item_new_with_label (action->label);
+	menu_item = gtk_menu_item_new_with_label (label_text);
+
+	g_value_unset (&value);
+	g_free (label_text);
 
 	menu = build_menu (EPHY_TOPIC_ACTION (action));
 	gtk_widget_show (menu);
@@ -459,7 +485,7 @@ create_menu_item (EggAction *action)
 }
 
 static gboolean
-create_menu_proxy (EggToolItem *item, EggAction *action)
+create_menu_proxy (GtkToolItem *item, GtkAction *action)
 {
 	GtkWidget *menu_item;
 	char *menu_id;
@@ -471,7 +497,7 @@ create_menu_proxy (EggToolItem *item, EggAction *action)
 	menu_id = g_strdup_printf ("ephy-topic-action-%d-menu-id",
 				   EPHY_TOPIC_ACTION (action)->priv->topic_id);
 
-	egg_tool_item_set_proxy_menu_item (item, menu_id, menu_item);
+	gtk_tool_item_set_proxy_menu_item (item, menu_id, menu_item);
 
 	g_free (menu_id);
 
@@ -479,19 +505,19 @@ create_menu_proxy (EggToolItem *item, EggAction *action)
 }
 
 static void
-connect_proxy (EggAction *action, GtkWidget *proxy)
+connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	GtkWidget *button;
 
 	LOG ("connect_proxy action %p, proxy %p", action, proxy)
 
-	(* EGG_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
+	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
 
 	ephy_topic_action_sync_label (action, NULL, proxy);
 	g_signal_connect_object (action, "notify::label",
 			         G_CALLBACK (ephy_topic_action_sync_label), proxy, 0);
 
-	if (EGG_IS_TOOL_ITEM (proxy))
+	if (GTK_IS_TOOL_ITEM (proxy))
 	{
 		g_signal_connect_object (proxy, "create_menu_proxy",
 					 G_CALLBACK (create_menu_proxy),
@@ -543,39 +569,19 @@ ephy_topic_action_get_property (GObject *object,
 	}
 }
 
-static void
-ephy_topic_action_finalize (GObject *object)
-{
-        EphyTopicAction *eba;
-
-	g_return_if_fail (EPHY_IS_TOPIC_ACTION (object));
-
-	eba = EPHY_TOPIC_ACTION (object);
-
-        g_return_if_fail (eba->priv != NULL);
-
-        g_free (eba->priv);
-
-	LOG ("Bookmark action finalized")
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
 static void
 ephy_topic_action_class_init (EphyTopicActionClass *class)
 {
-	EggActionClass *action_class;
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
 	parent_class = g_type_class_peek_parent (class);
-	action_class = EGG_ACTION_CLASS (class);
 
-	action_class->toolbar_item_type = EGG_TYPE_TOOL_ITEM;
+	action_class->toolbar_item_type = GTK_TYPE_TOOL_ITEM;
 	action_class->create_tool_item = create_tool_item;
 	action_class->create_menu_item = create_menu_item;
 	action_class->connect_proxy = connect_proxy;
 
-	object_class->finalize = ephy_topic_action_finalize;
 	object_class->set_property = ephy_topic_action_set_property;
 	object_class->get_property = ephy_topic_action_get_property;
 
@@ -599,21 +605,39 @@ ephy_topic_action_class_init (EphyTopicActionClass *class)
 							   G_MAXINT,
                                                            0,
                                                            G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof(EphyTopicActionPrivate));
 }
 
 static void
-sync_topic_properties (EggAction *action, EphyNode *bmk)
+sync_topic_properties (GtkAction *action, EphyNode *bmk)
 {
-	const char *title;
+	const char *tmp;
+	char *title;
+	int priority;
 
-	title = ephy_node_get_property_string
-		(bmk, EPHY_NODE_KEYWORD_PROP_NAME);
+	priority = ephy_node_get_property_int 
+		(bmk, EPHY_NODE_KEYWORD_PROP_PRIORITY);
+
+	if (priority == EPHY_NODE_ALL_PRIORITY)
+	{
+		tmp = _("Bookmarks");
+	}
+	else
+	{
+		tmp = ephy_node_get_property_string
+        	        (bmk, EPHY_NODE_KEYWORD_PROP_NAME);
+	}
+
+	title = ephy_string_double_underscores (tmp);
 
 	g_object_set (action, "label", title, NULL);
+
+	g_free (title);
 }
 
 static void
-topic_child_changed_cb (EphyNode *node, EphyNode *child, EggAction *action)
+topic_child_changed_cb (EphyNode *node, EphyNode *child, GtkAction *action)
 {
 	gulong id;
 
@@ -631,7 +655,7 @@ ephy_topic_action_init (EphyTopicAction *action)
 	EphyBookmarks *bookmarks;
 	EphyNode *node;
 
-	action->priv = g_new0 (EphyTopicActionPrivate, 1);
+	action->priv = EPHY_TOPIC_ACTION_GET_PRIVATE (action);
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	node = ephy_bookmarks_get_keywords (bookmarks);
@@ -640,19 +664,19 @@ ephy_topic_action_init (EphyTopicAction *action)
 				         G_OBJECT (action));
 }
 
-EggAction *
+GtkAction *
 ephy_topic_action_new (const char *name, guint id)
 {
 	EphyNode *bmk;
 	EphyBookmarks *bookmarks;
-	EggAction *action;
+	GtkAction *action;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 
 	bmk = ephy_bookmarks_get_from_id (bookmarks, id);
 	g_return_val_if_fail (bmk != NULL, NULL);
 
-	action = EGG_ACTION (g_object_new (EPHY_TYPE_TOPIC_ACTION,
+	action = GTK_ACTION (g_object_new (EPHY_TYPE_TOPIC_ACTION,
 					   "topic_id", id,
 					   "name", name,
 					   NULL));
