@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-automation.c,v 1.13 2003/09/24 19:15:32 chpe Exp $
  */
 
 #include "ephy-automation.h"
@@ -22,9 +24,10 @@
 #include "ephy-embed.h"
 #include "ephy-window.h"
 #include "session.h"
+#include "ephy-bookmarks.h"
+#include "ephy-bookmarks-import.h"
 
 #include <string.h>
-#include <bonobo/bonobo-generic-factory.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-context.h>
 
@@ -33,8 +36,11 @@ impl_ephy_automation_add_bookmark (PortableServer_Servant _servant,
 				   const CORBA_char * url,
 				   CORBA_Environment * ev);
 static void
+impl_ephy_automation_import_bookmarks (PortableServer_Servant _servant,
+				       const CORBA_char * filename,
+				       CORBA_Environment * ev);
+static void
 impl_ephy_automation_quit (PortableServer_Servant _servant,
-                           const CORBA_boolean disableServer,
                            CORBA_Environment * ev);
 static void
 impl_ephy_automation_load_session (PortableServer_Servant _servant,
@@ -62,23 +68,25 @@ ephy_automation_factory (BonoboGenericFactory *this_factory,
 {
         EphyAutomation *a;
 
-        a  = g_object_new (EPHY_AUTOMATION_TYPE, NULL);
+        a  = g_object_new (EPHY_TYPE_AUTOMATION, NULL);
 
         return BONOBO_OBJECT(a);
 }
 
-BonoboObject *
-ephy_automation_new (void)
+BonoboGenericFactory *
+ephy_automation_factory_new (void)
 {
-	BonoboGenericFactory   *factory;
+	BonoboGenericFactory *factory;
 
 	factory = bonobo_generic_factory_new (EPHY_FACTORY_OAFIID,
 					      ephy_automation_factory,
 					      NULL);
+	if (factory == NULL)
+	{
+		g_warning ("Could not initialize EphyAutomation factory");
+	}
 
-	g_return_val_if_fail (factory != NULL, NULL);
-
-	return BONOBO_OBJECT (factory);
+	return factory;
 }
 
 static void
@@ -95,11 +103,10 @@ impl_ephy_automation_loadurl (PortableServer_Servant _servant,
 	EphyWindow *window;
 	Session *session;
 
-	session = SESSION (ephy_shell_get_session (ephy_shell));
+	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
 
 	/* no window open, let's try to autoresume */
-	if (session_get_windows (session) == NULL
-	    && ephy_shell_get_server_mode (ephy_shell) == FALSE)
+	if (session_get_windows (session) == NULL)
 	{
 		gboolean res;
 		res = session_autoresume (session);
@@ -148,35 +155,28 @@ impl_ephy_automation_add_bookmark (PortableServer_Servant _servant,
 				   const CORBA_char * url,
 				   CORBA_Environment * ev)
 {
+	ephy_bookmarks_add (ephy_shell_get_bookmarks (ephy_shell),
+			    url /* title */, url);
+}
+
+static void
+impl_ephy_automation_import_bookmarks (PortableServer_Servant _servant,
+				       const CORBA_char * filename,
+				       CORBA_Environment * ev)
+{
+	ephy_bookmarks_import (ephy_shell_get_bookmarks (ephy_shell),
+			       filename);
 }
 
 static void
 impl_ephy_automation_quit (PortableServer_Servant _servant,
-                           const CORBA_boolean disableServer,
                            CORBA_Environment * ev)
 {
 	Session *session;
 
-	g_object_ref (ephy_shell);
-
-	session = SESSION (ephy_shell_get_session (ephy_shell));
+	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
 
 	session_close (session);
-
-	if (disableServer)
-	{
-		ephy_shell_set_server_mode (ephy_shell, FALSE);
-	}
-
-	g_object_unref (ephy_shell);
-}
-
-static void
-impl_ephy_automation_set_server_mode (PortableServer_Servant _servant,
-				      const CORBA_boolean mode,
-				      CORBA_Environment * ev)
-{
-	ephy_shell_set_server_mode (ephy_shell, mode ? TRUE : FALSE);
 }
 
 static void
@@ -186,7 +186,7 @@ impl_ephy_automation_load_session (PortableServer_Servant _servant,
 {
 	Session *session;
 
-	session = SESSION (ephy_shell_get_session (ephy_shell));
+	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
 	session_load (session, filename);
 }
 
@@ -210,10 +210,10 @@ ephy_automation_class_init (EphyAutomationClass *klass)
         /* connect implementation callbacks */
         epv->loadurl = impl_ephy_automation_loadurl;
 	epv->addBookmark = impl_ephy_automation_add_bookmark;
+	epv->importBookmarks = impl_ephy_automation_import_bookmarks;
 	epv->quit = impl_ephy_automation_quit;
 	epv->loadSession = impl_ephy_automation_load_session;
 	epv->openBookmarksEditor = impl_ephy_automation_open_bookmarks_editor;
-	epv->setServerMode = impl_ephy_automation_set_server_mode;
 }
 
 static void
