@@ -14,13 +14,16 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-location-action.h,v 1.7 2003/10/14 11:36:37 marco Exp $
  */
 
 #ifndef EPHY_LOCATION_ACTION_H
 #define EPHY_LOCATION_ACTION_H
 
-#include <gtk/gtk.h>
-#include <egg-action.h>
+#include <gtk/gtkaction.h>
+
+G_BEGIN_DECLS
 
 #define EPHY_TYPE_LOCATION_ACTION            (ephy_location_action_get_type ())
 #define EPHY_LOCATION_ACTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_TYPE_LOCATION_ACTION, EphyLocationAction))
@@ -29,23 +32,31 @@
 #define EPHY_IS_LOCATION_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), EPHY_TYPE_LOCATION_ACTION))
 #define EPHY_LOCATION_ACTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TYPE_LOCATION_ACTION, EphyLocationActionClass))
 
-typedef struct _EphyLocationAction      EphyLocationAction;
-typedef struct _EphyLocationActionClass EphyLocationActionClass;
-
+typedef struct _EphyLocationAction		EphyLocationAction;
+typedef struct _EphyLocationActionClass		EphyLocationActionClass;
+typedef struct _EphyLocationActionPrivate	EphyLocationActionPrivate;
+	
 struct _EphyLocationAction
 {
-	EggAction parent;
+	GtkAction parent;
+
+	EphyLocationActionPrivate *priv;
 };
 
 struct _EphyLocationActionClass
 {
-	EggActionClass parent_class;
+	GtkActionClass parent_class;
 
 	void (*go_location) (EphyLocationAction *action, char *location);
 };
 
-GType      ephy_location_action_get_type   (void);
+GType		ephy_location_action_get_type		(void);
 
-GtkWidget *ephy_location_action_get_widget (EphyLocationAction *action);
+const char     *ephy_location_action_get_address	(EphyLocationAction *action);
+
+void		ephy_location_action_set_address	(EphyLocationAction *action,
+							 const char *address);
+
+G_END_DECLS
 
 #endif
