@@ -1,5 +1,7 @@
 /*
- *  Copyright (C) 2001, 2002 Ricardo Fernndez Pascual
+ *  Copyright (C) 2001, 2002 Ricardo Fernández Pascual
+ *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +16,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-nautilus-view.c,v 1.20 2003/10/17 22:40:17 chpe Exp $
  */
 
 
@@ -29,10 +33,12 @@
 #include "ephy-embed-utils.h"
 #include "find-dialog.h"
 #include "print-dialog.h"
+#include "ephy-encoding-dialog.h"
 #include "ephy-zoom.h"
 #include "ephy-debug.h"
 
-static void		gnv_embed_location_cb 			(EphyEmbed *embed, 
+static void		gnv_embed_location_cb 			(EphyEmbed *embed,
+								 const char *new_uri,
 								 EphyNautilusView *view);
 static void		gnv_embed_title_cb 			(EphyEmbed *embed, 
 								 EphyNautilusView *view);
@@ -76,16 +82,15 @@ static void		gnv_zoomable_zoom_to_fit_cb		(BonoboZoomable *zoomable,
 static void		gnv_zoomable_zoom_to_default_cb		(BonoboZoomable *zoomable,
 								 EphyNautilusView *view);
 /* commands */
-static void		gnv_cmd_set_encoding			(BonoboUIComponent *uic, 
-								 EphyNautilusView *view,
-								 const char* verbname);
 static void 		gnv_cmd_file_print			(BonoboUIComponent *uic, 
 								 EphyNautilusView *view, 
 								 const char* verbname);
 static void 		gnv_cmd_edit_find			(BonoboUIComponent *uic, 
 								 EphyNautilusView *view, 
 								 const char* verbname);
-
+static void 		gnv_cmd_select_encoding			(BonoboUIComponent *uic, 
+								 EphyNautilusView *view, 
+								 const char* verbname);
 
 /* popups */
 static EphyNautilusView *gnv_view_from_popup			(EphyEmbedPopupControl*popup);
@@ -100,6 +105,8 @@ static void 		gnv_popup_cmd_frame_in_new_window	(BonoboUIComponent *uic,
 								 EphyEmbedPopupControl*popup, 
 								 const char* verbname);
 
+#define EPHY_NAUTILUS_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NAUTILUS_VIEW, EphyNautilusViewPrivate))
+
 struct EphyNautilusViewPrivate {
 	EphyEmbed *embed;
 	char *title;
@@ -126,12 +133,10 @@ static BonoboUIVerb ephy_popup_verbs [] = {
 BonoboUIVerb ephy_verbs [] = {
         BONOBO_UI_VERB ("FilePrint", (BonoboUIVerbFn) gnv_cmd_file_print),
         BONOBO_UI_VERB ("EditFind", (BonoboUIVerbFn) gnv_cmd_edit_find),
+	BONOBO_UI_VERB ("ViewEncoding", (BonoboUIVerbFn) gnv_cmd_select_encoding),
         BONOBO_UI_VERB_END
 };
 
-#define ENCODING_MENU_PATH "/menu/View/Encoding"
-
-
 BONOBO_CLASS_BOILERPLATE (EphyNautilusView, ephy_nautilus_view,
 			  NautilusView, NAUTILUS_TYPE_VIEW)
 
@@ -139,7 +144,7 @@ static void
 ephy_nautilus_view_instance_init (EphyNautilusView *view)
 {
 	GtkWidget *w;
-	EphyNautilusViewPrivate *p = g_new0 (EphyNautilusViewPrivate, 1);
+	EphyNautilusViewPrivate *p = EPHY_NAUTILUS_VIEW_GET_PRIVATE (view);
 	EphyEmbedSingle *single;
 	float *levels;
 	gchar **names;
@@ -270,7 +275,6 @@ ephy_nautilus_view_finalize (GObject *object)
 
 	g_free (p->title);
 	g_free (p->location);
-	g_free (p);
 
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 
@@ -280,7 +284,11 @@ ephy_nautilus_view_finalize (GObject *object)
 static void
 ephy_nautilus_view_class_init (EphyNautilusViewClass *class)
 {
-	G_OBJECT_CLASS (class)->finalize = ephy_nautilus_view_finalize;
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
+
+	object_class->finalize = ephy_nautilus_view_finalize;
+
+	g_type_class_add_private (object_class, sizeof(EphyNautilusViewPrivate));
 }
 
 static gint
@@ -334,33 +342,25 @@ gnv_embed_link_message_cb (EphyEmbed *embed, const char *message, EphyNautilusVi
 }
 
 static void
-gnv_embed_location_cb (EphyEmbed *embed, EphyNautilusView *view)
+gnv_embed_location_cb (EphyEmbed *embed, const char *new_uri, EphyNautilusView *view)
 {
-	EphyNautilusViewPrivate *p;
-	const gchar *prefixes_to_ignore[] = 
+	const char *prefixes_to_ignore[] = 
 		{
 			"about:",
 			"javascript:",
 			NULL 
 		};
 	int i = 0;
-	gchar *new_uri;
 
  	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-	p = view->priv;
 	g_return_if_fail (view->priv->embed == embed);
-
-	ephy_embed_get_location (embed, TRUE, &new_uri);
-
  	g_return_if_fail (new_uri != NULL);
 
-
 	/* don't inform nautilus about uris that it can't understand */
 	while (prefixes_to_ignore[i] != NULL)
 	{
-		if (!strncmp (prefixes_to_ignore[i], new_uri, strlen (prefixes_to_ignore[i])))
+		if (strncmp (prefixes_to_ignore[i], new_uri, strlen (prefixes_to_ignore[i])) == 0)
 		{
-			g_free (new_uri);
 			return;
 		}
 		++i;
@@ -368,8 +368,8 @@ gnv_embed_location_cb (EphyEmbed *embed, EphyNautilusView *view)
 
 	nautilus_view_report_location_change (NAUTILUS_VIEW (view), new_uri, NULL, new_uri);
 
-	g_free (p->location);
-	p->location = new_uri;
+	g_free (view->priv->location);
+	view->priv->location = g_strdup (new_uri);
 }
 
 static void
@@ -434,11 +434,6 @@ gnv_bonobo_control_activate_cb (BonoboControl *control, gboolean state, EphyNaut
 		p->ui = nautilus_view_set_up_ui (NAUTILUS_VIEW (view), SHARE_DIR,
 						 "nautilus-epiphany-view.xml", "EphyNautilusView");
 		g_return_if_fail (BONOBO_IS_UI_COMPONENT (p->ui));
-		
-		ephy_embed_utils_build_encodings_submenu (p->ui,
-							   ENCODING_MENU_PATH,
-							   (BonoboUIVerbFn) gnv_cmd_set_encoding,
-							   view);
 
 		bonobo_ui_component_add_verb_list_with_data (p->ui, ephy_verbs, view);
 	}
@@ -509,23 +504,19 @@ gnv_popup_cmd_frame_in_new_window (BonoboUIComponent *uic,
 	g_free (location);
 }
 
-void 
-gnv_cmd_set_encoding (BonoboUIComponent *uic, 
-		      EphyNautilusView *view,
-		      const char* verbname)
+static void
+gnv_cmd_select_encoding (BonoboUIComponent *uic, 
+			 EphyNautilusView *view, 
+			 const char* verbname)
 {
-	const char *encoding;
+	EphyDialog *dialog;
+	
+	dialog = EPHY_DIALOG (g_object_new (EPHY_TYPE_ENCODING_DIALOG,
+					    "embed", view->priv->embed,
+					    NULL));
 
-	g_return_if_fail (EPHY_IS_NAUTILUS_VIEW (view));
-
-	if (strncmp (verbname, "Encoding", 8) == 0)
-	{
-		encoding = verbname + 8;
-		
-		LOG ("Set encoding %s", encoding)
-
-		ephy_embed_set_encoding (view->priv->embed, encoding);
-	}
+	ephy_dialog_set_modal (dialog, TRUE);
+	ephy_dialog_show (dialog);
 }
 
 static void
@@ -558,7 +549,6 @@ gnv_cmd_edit_find (BonoboUIComponent *uic,
 	ephy_dialog_show (p->find_dialog);
 }
 
-
 /* zoomable */
 static void
 gnv_zoomable_set_zoom_level_cb (BonoboZoomable *zoomable,
