@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.18.2.1 2004/01/10 14:45:23 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.24 2003/10/06 13:53:56 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,10 +34,19 @@
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-favicon-cache.h"
-#include "ephy-event-box.h"
 
-#include <gtk/gtk.h>
 #include <glib-object.h>
+#include <gtk/gtkeventbox.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkwidget.h>
+#include <gtk/gtktooltips.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkiconfactory.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
@@ -46,6 +55,8 @@
 #define TAB_MIN_SIZE 60
 #define TAB_NB_MAX    8
 
+#define EPHY_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NOTEBOOK, EphyNotebookPrivate))
+
 struct EphyNotebookPrivate
 {
 	GList *focused_pages;
@@ -56,8 +67,6 @@ struct EphyNotebookPrivate
 	gint x_start, y_start;
 	gboolean drag_in_progress;
 	gboolean show_tabs;
-	EphyNotebook *src_notebook;
-	gint src_page;
 };
 
 static void ephy_notebook_init           (EphyNotebook *notebook);
@@ -69,7 +78,6 @@ static void move_tab_to_another_notebook (EphyNotebook *src,
 
 /* Local variables */
 static GdkCursor *cursor = NULL;
-static GList *notebooks  = NULL;
 
 static GtkTargetEntry url_drag_types [] = 
 {
@@ -167,6 +175,8 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      ephy_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+
+	g_type_class_add_private (object_class, sizeof(EphyNotebookPrivate));
 }
 
 static gboolean
@@ -193,36 +203,36 @@ is_in_notebook_window (EphyNotebook *notebook,
 static EphyNotebook *
 find_notebook_at_pointer (gint abs_x, gint abs_y)
 {
-	GList *l;
+	GdkWindow *win_at_pointer, *toplevel_win;
+	gpointer toplevel = NULL;
 	gint x, y;
-	GdkWindow *win_at_pointer = gdk_window_at_pointer (&x, &y);
-	GdkWindow *parent_at_pointer = NULL;
 
+	win_at_pointer = gdk_window_at_pointer (&x, &y);
 	if (win_at_pointer == NULL)
 	{
 		/* We are outside all windows containing a notebook */
 		return NULL;
 	}
 
-	gdk_window_get_toplevel (win_at_pointer);
-	/* When we are in the notebook event window, win_at_pointer will be
-	   this event window, and the toplevel window we are interested in
-	   will be its parent
-	*/
-	parent_at_pointer = gdk_window_get_parent (win_at_pointer);
+	toplevel_win = gdk_window_get_toplevel (win_at_pointer);
 
-	for (l = notebooks; l != NULL; l = l->next)
+	/* get the GtkWidget which owns the toplevel GdkWindow */
+	gdk_window_get_user_data (toplevel_win, &toplevel);
+
+	/* toplevel should be an EphyWindow */
+	if (toplevel != NULL && EPHY_IS_WINDOW (toplevel))
 	{
-		EphyNotebook *nb = EPHY_NOTEBOOK (l->data);
-		GdkWindow *win = GTK_WIDGET (nb)->window;
+		EphyNotebook *notebook;
 
-		win = gdk_window_get_toplevel (win);
-		if (((win == win_at_pointer) || (win == parent_at_pointer))
-		    && is_in_notebook_window (nb, abs_x, abs_y))
+		notebook = EPHY_NOTEBOOK (ephy_window_get_notebook
+					    (EPHY_WINDOW (toplevel)));
+
+		if (is_in_notebook_window (notebook, abs_x, abs_y))
 		{
-			return nb;
+			return notebook;
 		}
 	}
+
 	return NULL;
 }
 
@@ -361,13 +371,9 @@ ephy_notebook_move_page (EphyNotebook *src, EphyNotebook *dest,
 }
 
 static void
-drag_start (EphyNotebook *notebook,
-	    EphyNotebook *src_notebook,
-	    gint src_page)
+drag_start (EphyNotebook *notebook)
 {
 	notebook->priv->drag_in_progress = TRUE;
-	notebook->priv->src_notebook = src_notebook;
-	notebook->priv->src_page = src_page;
 
 	/* get a new cursor, if necessary */
 	if (!cursor) cursor = gdk_cursor_new (GDK_FLEUR);
@@ -391,8 +397,6 @@ drag_stop (EphyNotebook *notebook)
 	}
 
 	notebook->priv->drag_in_progress = FALSE;
-	notebook->priv->src_notebook = NULL;
-	notebook->priv->src_page = -1;
 	if (notebook->priv->motion_notify_handler_id != 0)
 	{
 		g_signal_handler_disconnect (G_OBJECT (notebook),
@@ -433,23 +437,19 @@ motion_notify_cb (EphyNotebook *notebook, GdkEventMotion *event,
 	gint page_num;
 	gint result;
 
-	/* If the notebook only has one tab, we don't want to do
-	 * anything since ephy can't handle empty notebooks
-	 */
-	if (g_list_length (GTK_NOTEBOOK (notebook)->children) <= 1) {
-		return FALSE;
-	}
-
-	if ((notebook->priv->drag_in_progress == FALSE)
-	    && (gtk_drag_check_threshold (GTK_WIDGET (notebook),
-					  notebook->priv->x_start,
-					  notebook->priv->y_start,
-					  event->x_root, event->y_root)))
+	if (notebook->priv->drag_in_progress == FALSE)
 	{
-		gint cur_page;
-
-		cur_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-		drag_start (notebook, notebook, cur_page);
+		if (gtk_drag_check_threshold (GTK_WIDGET (notebook),
+					      notebook->priv->x_start,
+					      notebook->priv->y_start,
+					      event->x_root, event->y_root))
+		{
+			drag_start (notebook);
+		}
+		else
+		{
+			return FALSE;
+		}
 	}
 
 	result = find_notebook_and_tab_at_pos ((gint)event->x_root,
@@ -485,21 +485,21 @@ move_tab_to_another_notebook(EphyNotebook *src,
 	 * to that new notebook, and let this notebook handle the
 	 * drag
 	*/
-	g_assert (dest != NULL);
+	g_assert (EPHY_IS_NOTEBOOK (dest));
 	g_assert (dest != src);
 
-	/* Move the widgets (tab label and tab content) to the new
-	 * notebook
-	 */
 	cur_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (src));
 	child    = gtk_notebook_get_nth_page (GTK_NOTEBOOK (src), cur_page);
-	ephy_notebook_move_page (src, dest, child, dest_page);
 
-	/* "Give" drag handling to the new notebook */
-	drag_start (dest, src->priv->src_notebook, src->priv->src_page);
+	/* stop drag in origin window */
 	drag_stop (src);
 	gtk_grab_remove (GTK_WIDGET (src));
 
+	ephy_notebook_move_page (src, dest, child, dest_page);
+
+	/* start drag handling in dest notebook */
+	drag_start (dest);
+
 	dest->priv->motion_notify_handler_id =
 		g_signal_connect (G_OBJECT (dest),
 				  "motion-notify-event",
@@ -522,7 +522,8 @@ button_release_cb (EphyNotebook *notebook, GdkEventButton *event,
 		cur_page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
 						      cur_page_num);
 
-		if (!is_in_notebook_window (notebook, event->x_root, event->y_root))
+		if (!is_in_notebook_window (notebook, event->x_root, event->y_root)
+		    && gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) > 1)
 		{
 			/* Tab was detached */
 			g_signal_emit (G_OBJECT (notebook),
@@ -573,7 +574,7 @@ button_press_cb (EphyNotebook *notebook,
 GtkWidget *
 ephy_notebook_new (void)
 {
-	return GTK_WIDGET (g_object_new (EPHY_NOTEBOOK_TYPE, NULL));
+	return GTK_WIDGET (g_object_new (EPHY_TYPE_NOTEBOOK, NULL));
 }
 
 static void
@@ -647,7 +648,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	if (uris == NULL) return;
 
 	toplevel = gtk_widget_get_toplevel (widget);
-	g_return_if_fail (IS_EPHY_WINDOW (toplevel));
+	g_return_if_fail (EPHY_IS_WINDOW (toplevel));
 	window = EPHY_WINDOW (toplevel);
 
 	if (child)
@@ -703,7 +704,7 @@ update_tabs_visibility (EphyNotebook *nb, gboolean before_inserting)
 
 	if (before_inserting) num++;
 
-	show_tabs = (eel_gconf_get_boolean (CONF_TABS_TABBED) || num > 1) &&
+	show_tabs = (eel_gconf_get_boolean (CONF_ALWAYS_SHOW_TABS_BAR) || num > 1) &&
 		    nb->priv->show_tabs == TRUE;
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
@@ -721,7 +722,7 @@ tabs_visibility_notifier (GConfClient *client,
 static void
 ephy_notebook_init (EphyNotebook *notebook)
 {
-	notebook->priv = g_new (EphyNotebookPrivate, 1);
+	notebook->priv = EPHY_NOTEBOOK_GET_PRIVATE (notebook);
 
 	notebook->priv->title_tips = gtk_tooltips_new ();
 	g_object_ref (G_OBJECT (notebook->priv->title_tips));
@@ -729,14 +730,10 @@ ephy_notebook_init (EphyNotebook *notebook)
 
 	notebook->priv->drag_in_progress = FALSE;
 	notebook->priv->motion_notify_handler_id = 0;
-	notebook->priv->src_notebook = NULL;
-	notebook->priv->src_page = -1;
 	notebook->priv->focused_pages = NULL;
 	notebook->priv->opened_tabs = NULL;
 	notebook->priv->show_tabs = TRUE;
 
-	notebooks = g_list_append (notebooks, notebook);
-
 	g_signal_connect (notebook, "button-press-event",
 			  (GCallback)button_press_cb, NULL);
 	g_signal_connect (notebook, "button-release-event",
@@ -757,7 +754,7 @@ ephy_notebook_init (EphyNotebook *notebook)
                            GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
 	notebook->priv->tabs_vis_notifier_id = eel_gconf_notification_add
-		(CONF_TABS_TABBED,
+		(CONF_ALWAYS_SHOW_TABS_BAR,
 		 (GConfClientNotifyFunc)tabs_visibility_notifier, notebook);
 }
 
@@ -766,8 +763,6 @@ ephy_notebook_finalize (GObject *object)
 {
 	EphyNotebook *notebook = EPHY_NOTEBOOK (object);
 
-	notebooks = g_list_remove (notebooks, notebook);
-
 	eel_gconf_notification_remove (notebook->priv->tabs_vis_notifier_id);
 
 	if (notebook->priv->focused_pages)
@@ -777,11 +772,7 @@ ephy_notebook_finalize (GObject *object)
 	g_list_free (notebook->priv->opened_tabs);
 	g_object_unref (notebook->priv->title_tips);
 
-	g_free (notebook->priv);
-
 	LOG ("EphyNotebook finalised %p", object)
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -907,7 +898,8 @@ build_tab_label (EphyNotebook *nb, GtkWidget *child)
 	gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	/* setup label */
-	label_ebox = ephy_event_box_new ();
+	label_ebox = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (label_ebox), FALSE);
         label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (label), 0.00, 0.5);
         gtk_misc_set_padding (GTK_MISC (label), 4, 0);
@@ -965,9 +957,9 @@ ephy_notebook_insert_page (EphyNotebook *nb,
 	EphyTab *tab;
 	GtkWidget *label;
 
-	g_return_if_fail (IS_EPHY_EMBED (child));
+	g_return_if_fail (EPHY_IS_EMBED (child));
 	tab = EPHY_TAB (g_object_get_data (G_OBJECT (child), "EphyTab"));
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	label = build_tab_label (nb, child);
 
@@ -1017,6 +1009,8 @@ ephy_notebook_insert_page (EphyNotebook *nb,
 	g_signal_connect_object (tab, "notify::load-status",
 				 G_CALLBACK (sync_load_status), label, 0);
 
+	g_signal_emit (G_OBJECT (nb), signals[TAB_ADDED], 0, child);
+
 	if (jump_to)
 	{
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (nb),
@@ -1024,8 +1018,6 @@ ephy_notebook_insert_page (EphyNotebook *nb,
 		g_object_set_data (G_OBJECT (child), "jump_to",
 				   GINT_TO_POINTER (jump_to));
 	}
-
-	g_signal_emit (G_OBJECT (nb), signals[TAB_ADDED], 0, child);
 }
 
 static void
@@ -1065,11 +1057,11 @@ ephy_notebook_remove_page (EphyNotebook *nb,
 	EphyTab *tab;
 	GtkWidget *label, *ebox;
 
-	g_return_if_fail (IS_EPHY_NOTEBOOK (nb));
-	g_return_if_fail (IS_EPHY_EMBED (child));
+	g_return_if_fail (EPHY_IS_NOTEBOOK (nb));
+	g_return_if_fail (EPHY_IS_EMBED (child));
 
 	tab = EPHY_TAB (g_object_get_data (G_OBJECT (child), "EphyTab"));
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 	if (num <= 1)
