@@ -14,16 +14,21 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-spinner-action.c,v 1.13 2003/09/01 23:20:14 chpe Exp $
  */
 
 #include "ephy-spinner-action.h"
 #include "ephy-spinner.h"
-#include "eggtoolitem.h"
-#include "eggtoolbar.h"
+
+#include <gtk/gtktoolitem.h>
+#include <gtk/gtktoolbar.h>
 
 static void ephy_spinner_action_init       (EphySpinnerAction *action);
 static void ephy_spinner_action_class_init (EphySpinnerActionClass *class);
 
+#define EPHY_SPINNER_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SPINNER_ACTION, EphySpinnerActionPrivate))
+
 struct EphySpinnerActionPrivate
 {
 	gboolean throbbing;
@@ -57,7 +62,7 @@ ephy_spinner_action_get_type (void)
 			(GInstanceInitFunc) ephy_spinner_action_init,
 		};
 
-		type = g_type_register_static (EGG_TYPE_ACTION,
+		type = g_type_register_static (GTK_TYPE_ACTION,
 					       "EphySpinnerAction",
 					       &type_info, 0);
 	}
@@ -65,7 +70,7 @@ ephy_spinner_action_get_type (void)
 }
 
 static void
-ephy_spinner_action_sync_throbbing (EggAction *action, GParamSpec *pspec,
+ephy_spinner_action_sync_throbbing (GtkAction *action, GParamSpec *pspec,
 			            GtkWidget *proxy)
 {
 	EphySpinner *spinner;
@@ -83,25 +88,25 @@ ephy_spinner_action_sync_throbbing (EggAction *action, GParamSpec *pspec,
 }
 
 static GtkWidget *
-create_tool_item (EggAction *action)
+create_tool_item (GtkAction *action)
 {
 	GtkWidget *item;
 	GtkWidget *spinner;
 
-	item = GTK_WIDGET (egg_tool_item_new ());
+	item = GTK_WIDGET (gtk_tool_item_new ());
 
 	spinner = ephy_spinner_new ();
 	gtk_widget_show (spinner);
 	gtk_container_add (GTK_CONTAINER (item), spinner);
-	egg_tool_item_set_pack_end (EGG_TOOL_ITEM (item), TRUE);
-	egg_tool_item_set_homogeneous (EGG_TOOL_ITEM (item), FALSE);
+	gtk_tool_item_set_pack_end (GTK_TOOL_ITEM (item), TRUE);
+	gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (item), FALSE);
 	g_object_set_data (G_OBJECT (item), "spinner", spinner);
 
 	return item;
 }
 
 static void
-toolbar_style_sync (EggToolbar *toolbar,
+toolbar_style_sync (GtkToolbar *toolbar,
 		    GtkToolbarStyle style,
 		    GtkWidget *proxy)
 {
@@ -117,23 +122,23 @@ toolbar_style_sync (EggToolbar *toolbar,
 static void
 item_parent_set_cb (GtkWidget *item, GtkWidget *previous_parent)
 {
-	EggToolbar *toolbar;
+	GtkToolbar *toolbar;
 	GtkToolbarStyle style;
 
 	if (item->parent == NULL) return;
 
-	toolbar = EGG_TOOLBAR (item->parent);
+	toolbar = GTK_TOOLBAR (item->parent);
 
 	g_signal_connect_object (toolbar, "style_changed",
 			         G_CALLBACK (toolbar_style_sync),
 			         item, 0);
 
-	style = egg_toolbar_get_style (toolbar);
+	style = gtk_toolbar_get_style (toolbar);
 	toolbar_style_sync (toolbar, style, item);
 }
 
 static void
-connect_proxy (EggAction *action, GtkWidget *proxy)
+connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
 	g_signal_connect_object (action, "notify::throbbing",
 				 G_CALLBACK (ephy_spinner_action_sync_throbbing),
@@ -142,7 +147,7 @@ connect_proxy (EggAction *action, GtkWidget *proxy)
 			         G_CALLBACK (item_parent_set_cb),
 			         proxy, 0);
 
-	(* EGG_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
+	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
 }
 
 static void
@@ -182,32 +187,18 @@ ephy_spinner_action_get_property (GObject *object,
 	}
 }
 
-static void
-ephy_spinner_action_finalize (GObject *object)
-{
-	EphySpinnerAction *action = EPHY_SPINNER_ACTION (object);
-
-	g_return_if_fail (action->priv != NULL);
-
-	g_free (action->priv);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
 static void
 ephy_spinner_action_class_init (EphySpinnerActionClass *class)
 {
-	EggActionClass *action_class;
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
 	parent_class = g_type_class_peek_parent (class);
-	action_class = EGG_ACTION_CLASS (class);
 
-	action_class->toolbar_item_type = EPHY_SPINNER_TYPE;
+	action_class->toolbar_item_type = EPHY_TYPE_SPINNER;
 	action_class->create_tool_item = create_tool_item;
 	action_class->connect_proxy = connect_proxy;
 
-	object_class->finalize = ephy_spinner_action_finalize;
 	object_class->set_property = ephy_spinner_action_set_property;
 	object_class->get_property = ephy_spinner_action_get_property;
 
@@ -218,10 +209,12 @@ ephy_spinner_action_class_init (EphySpinnerActionClass *class)
                                                                "Throbbing",
                                                                FALSE,
                                                                G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof(EphySpinnerActionPrivate));
 }
 
 static void
 ephy_spinner_action_init (EphySpinnerAction *action)
 {
-	action->priv = g_new0 (EphySpinnerActionPrivate, 1);
+	action->priv = EPHY_SPINNER_ACTION_GET_PRIVATE (action);
 }
