@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.53 2003/08/07 21:53:39 mpeseng Exp $
+ *  $Id: ephy-tab.c,v 1.59 2003/09/24 13:52:48 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +28,6 @@
 #include "ephy-prefs.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-debug.h"
-#include "egg-menu-merge.h"
 #include "ephy-string.h"
 #include "ephy-notebook.h"
 #include "ephy-file-helpers.h"
@@ -49,8 +48,12 @@
 #include <gtk/gtkselection.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmenu.h>
+#include <gtk/gtkuimanager.h>
+#include <gtk/gtkradioaction.h>
 #include <string.h>
 
+#define EPHY_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TAB, EphyTabPrivate))
+
 struct EphyTabPrivate
 {
 	EphyEmbed *embed;
@@ -68,7 +71,7 @@ struct EphyTabPrivate
 	int total_requests;
 	int width;
 	int height;
-	EggAction *action;
+	GtkToggleAction *action;
 	float zoom;
 	EmbedSecurityLevel security_level;
 	TabNavigationFlags nav_flags;
@@ -224,11 +227,15 @@ ephy_tab_get_property (GObject *object,
 }
 
 static void
-ephy_tab_action_activate_cb (EggAction *action, EphyTab *tab)
+ephy_tab_action_activate_cb (GtkAction *action, EphyTab *tab)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
-	ephy_window_jump_to_tab (tab->priv->window, tab);
+	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) &&
+	    ephy_window_get_active_tab (tab->priv->window) != tab)
+	{
+		ephy_window_jump_to_tab (tab->priv->window, tab);
+	}
 }
 
 static void
@@ -327,7 +334,7 @@ ephy_tab_class_init (EphyTabClass *class)
 					 g_param_spec_object ("window",
 							      "Window",
 							      "The tab's parent window",
-							      EPHY_WINDOW_TYPE,
+							      EPHY_TYPE_WINDOW,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
@@ -339,6 +346,8 @@ ephy_tab_class_init (EphyTabClass *class)
 							     ZOOM_MAXIMAL,
 							     1.0,
 							     G_PARAM_READABLE));
+
+	g_type_class_add_private (object_class, sizeof(EphyTabPrivate));
 }
 
 static void
@@ -362,13 +371,7 @@ ephy_tab_embed_destroy_cb (GtkWidget *widget, EphyTab *tab)
 static void
 ephy_tab_finalize (GObject *object)
 {
-        EphyTab *tab;
-
-	g_return_if_fail (IS_EPHY_TAB (object));
-
-	tab = EPHY_TAB (object);
-
-        g_return_if_fail (tab->priv != NULL);
+        EphyTab *tab = EPHY_TAB (object);
 
 	g_idle_remove_by_data (tab->priv->embed);
 
@@ -383,8 +386,6 @@ ephy_tab_finalize (GObject *object)
 	g_free (tab->priv->link_message);
 	g_free (tab->priv->status_message);
 
-        g_free (tab->priv);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
 	LOG ("EphyTab finalized %p", tab)
@@ -397,15 +398,15 @@ ephy_tab_new (void)
 {
 	EphyTab *tab;
 
-	tab = EPHY_TAB (g_object_new (EPHY_TAB_TYPE, NULL));
-	g_return_val_if_fail (tab->priv != NULL, NULL);
+	tab = EPHY_TAB (g_object_new (EPHY_TYPE_TAB, NULL));
+
 	return tab;
 }
 
 static void
 ephy_tab_set_load_status (EphyTab *tab, gboolean status)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	tab->priv->load_status = status;
 
@@ -415,7 +416,7 @@ ephy_tab_set_load_status (EphyTab *tab, gboolean status)
 gboolean
 ephy_tab_get_load_status (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), FALSE);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), FALSE);
 
 	return tab->priv->load_status;
 }
@@ -423,7 +424,7 @@ ephy_tab_get_load_status (EphyTab *tab)
 static void
 ephy_tab_set_link_message (EphyTab *tab, const char *message)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	g_free (tab->priv->link_message);
 	tab->priv->link_message = g_strdup (message);
@@ -434,7 +435,7 @@ ephy_tab_set_link_message (EphyTab *tab, const char *message)
 const char *
 ephy_tab_get_link_message (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), NULL);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
 
 	return tab->priv->link_message;
 }
@@ -442,7 +443,7 @@ ephy_tab_get_link_message (EphyTab *tab)
 EphyEmbed *
 ephy_tab_get_embed (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), NULL);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
 
 	return tab->priv->embed;
 }
@@ -450,8 +451,8 @@ ephy_tab_get_embed (EphyTab *tab)
 void
 ephy_tab_set_window (EphyTab *tab, EphyWindow *window)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
-	if (window) g_return_if_fail (IS_EPHY_WINDOW (window));
+	g_return_if_fail (EPHY_IS_TAB (tab));
+	if (window) g_return_if_fail (EPHY_IS_WINDOW (window));
 
 	if (window != tab->priv->window)
 	{
@@ -464,7 +465,7 @@ ephy_tab_set_window (EphyTab *tab, EphyWindow *window)
 EphyWindow *
 ephy_tab_get_window (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), NULL);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
 
 	return tab->priv->window;
 }
@@ -472,7 +473,7 @@ ephy_tab_get_window (EphyTab *tab)
 void
 ephy_tab_get_size (EphyTab *tab, int *width, int *height)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	*width = tab->priv->width;
 	*height = tab->priv->height;
@@ -481,7 +482,7 @@ ephy_tab_get_size (EphyTab *tab, int *width, int *height)
 gboolean
 ephy_tab_get_visibility (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), FALSE);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), FALSE);
 
 	return tab->priv->visibility;
 }
@@ -490,7 +491,7 @@ void
 ephy_tab_set_visibility (EphyTab *tab,
                          gboolean visible)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	tab->priv->visibility = visible;
 
@@ -519,7 +520,7 @@ ephy_tab_set_icon_address (EphyTab *tab, const char *address)
 	EphyBookmarks *eb;
 	EphyHistory *history;
 
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	g_free (tab->priv->icon_address);
 
@@ -542,7 +543,7 @@ ephy_tab_set_icon_address (EphyTab *tab, const char *address)
 const char *
 ephy_tab_get_icon_address (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), NULL);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
 
 	return tab->priv->icon_address;
 }
@@ -766,7 +767,7 @@ ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
 			/* tab load completed, save in session */
 			Session *s;
 
-			s = SESSION (ephy_shell_get_session (ephy_shell));
+			s = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
 			session_save (s, SESSION_CRASHED);
 
 			ephy_tab_set_load_percent (tab, 0);
@@ -822,7 +823,7 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 static void
 ephy_tab_destroy_brsr_cb (EphyEmbed *embed, EphyTab *tab)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 	g_return_if_fail (tab->priv->window != NULL);
 
 	ephy_window_remove_tab (tab->priv->window, tab);
@@ -909,7 +910,8 @@ open_link_in_new_tab (EphyTab *tab,
 	{
 		ephy_shell_new_tab (ephy_shell, window, tab,
 				    link_address,
-				    EPHY_NEW_TAB_OPEN_PAGE);
+				    EPHY_NEW_TAB_OPEN_PAGE |
+				    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 	}
 	else
 	{
@@ -929,7 +931,7 @@ ephy_tab_dom_mouse_click_cb  (EphyEmbed *embed,
 	window = ephy_tab_get_window (tab);
 	g_return_val_if_fail (window != NULL, FALSE);
 
-	g_assert (IS_EPHY_EMBED_EVENT(event));
+	g_assert (EPHY_IS_EMBED_EVENT(event));
 
 	ephy_embed_event_get_event_type (event, &type);
 	ephy_embed_event_get_context (event, &context);
@@ -980,7 +982,7 @@ ephy_tab_init (EphyTab *tab)
 	single = ephy_embed_shell_get_embed_single
 		(EPHY_EMBED_SHELL (ephy_shell));
 
-        tab->priv = g_new0 (EphyTabPrivate, 1);
+	tab->priv = EPHY_TAB_GET_PRIVATE (tab);
 
 	tab->priv->window = NULL;
 	tab->priv->status_message = NULL;
@@ -1001,16 +1003,19 @@ ephy_tab_init (EphyTab *tab)
 	tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
 
 	tab->priv->embed = ephy_embed_new (G_OBJECT(single));
+	g_assert (tab->priv->embed != NULL);
 
 	embed = G_OBJECT (tab->priv->embed);
 	embed_widget = G_OBJECT (tab->priv->embed);
 
 	id = g_strdup_printf ("Tab%lu", tab_id++);
 
-	tab->priv->action = g_object_new (EGG_TYPE_ACTION,
+	tab->priv->action = g_object_new (GTK_TYPE_TOGGLE_ACTION,
 					  "name", id,
 					  "label", _("Blank page"),
+					  "draw_as_radio", TRUE,
 					  NULL);
+
 	g_free (id);
 	g_signal_connect (tab->priv->action, "activate",
 			  G_CALLBACK (ephy_tab_action_activate_cb), tab);
@@ -1074,7 +1079,7 @@ ephy_tab_init (EphyTab *tab)
 void
 ephy_tab_set_load_percent (EphyTab *tab, int percent)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	if (percent != tab->priv->load_percent)
 	{
@@ -1087,7 +1092,7 @@ ephy_tab_set_load_percent (EphyTab *tab, int percent)
 int
 ephy_tab_get_load_percent (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), -1);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), -1);
 
 	return tab->priv->load_percent;
 }
@@ -1126,7 +1131,7 @@ ephy_tab_update_navigation_flags (EphyTab *tab)
 TabNavigationFlags
 ephy_tab_get_navigation_flags (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), 0);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), 0);
 
 	return tab->priv->nav_flags;
 }
@@ -1134,7 +1139,7 @@ ephy_tab_get_navigation_flags (EphyTab *tab)
 const char *
 ephy_tab_get_status_message (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), "");
+	g_return_val_if_fail (EPHY_IS_TAB (tab), "");
 
 	if (tab->priv->link_message && tab->priv->link_message[0] != '\0')
 	{
@@ -1158,7 +1163,7 @@ ephy_tab_set_title (EphyTab *tab, const char *new_title)
 	char *title_short = NULL;
 	char *title = NULL;
 
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	g_free (tab->priv->title);
 
@@ -1222,7 +1227,7 @@ ephy_tab_set_title (EphyTab *tab, const char *new_title)
 const char *
 ephy_tab_get_title (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), "");
+	g_return_val_if_fail (EPHY_IS_TAB (tab), "");
 
 	return tab->priv->title;
 }
@@ -1230,7 +1235,7 @@ ephy_tab_get_title (EphyTab *tab)
 const char *
 ephy_tab_get_location (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), "");
+	g_return_val_if_fail (EPHY_IS_TAB (tab), "");
 
 	return tab->priv->address;
 }
@@ -1240,7 +1245,7 @@ ephy_tab_set_location (EphyTab *tab,
 		       const char *address,
 		       TabAddressExpire expire)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	if (tab->priv->address) g_free (tab->priv->address);
 	tab->priv->address = g_strdup (address);
@@ -1261,7 +1266,7 @@ ephy_tab_set_location (EphyTab *tab,
 static void
 ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	tab->priv->security_level = level;
 
@@ -1271,7 +1276,7 @@ ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
 EmbedSecurityLevel
 ephy_tab_get_security_level (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), STATE_IS_UNKNOWN);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), STATE_IS_UNKNOWN);
 
 	return tab->priv->security_level;
 }
@@ -1279,7 +1284,7 @@ ephy_tab_get_security_level (EphyTab *tab)
 static void
 ephy_tab_set_zoom (EphyTab *tab, float zoom)
 {
-	g_return_if_fail (IS_EPHY_TAB (tab));
+	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	tab->priv->zoom = zoom;
 
@@ -1289,7 +1294,7 @@ ephy_tab_set_zoom (EphyTab *tab, float zoom)
 float
 ephy_tab_get_zoom (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), 1.0);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), 1.0);
 
 	return tab->priv->zoom;
 }
@@ -1297,7 +1302,7 @@ ephy_tab_get_zoom (EphyTab *tab)
 GObject *
 ephy_tab_get_action (EphyTab *tab)
 {
-	g_return_val_if_fail (IS_EPHY_TAB (tab), NULL);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
 
 	return G_OBJECT (tab->priv->action);
 }
