@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.17 2003/08/22 11:02:09 marco Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.18 2003/09/01 23:20:14 chpe Exp $
  */
 
 #include "ephy-toolbars-model.h"
@@ -56,6 +56,8 @@ enum
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_TOOLBARS_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBARS_MODEL, EphyToolbarsModelPrivate))
+
 struct EphyToolbarsModelPrivate
 {
 	EphyBookmarks *bookmarks;
@@ -321,7 +323,6 @@ static void
 ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *bookmarks)
 {
 	EggToolbarsModel *egg_model = EGG_TOOLBARS_MODEL (model);
-	gboolean success = FALSE;
 
 	model->priv->bookmarks = bookmarks;
 	g_object_ref (model->priv->bookmarks);
@@ -330,11 +331,10 @@ ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *book
 
 	if (g_file_test (model->priv->xml_file, G_FILE_TEST_EXISTS))
 	{
-		success = egg_toolbars_model_load (egg_model,
+		egg_toolbars_model_load (egg_model,
 					 model->priv->xml_file);
 	}
-
-	if (success == FALSE)
+	else
 	{
 		const char *default_xml;
 
@@ -405,8 +405,10 @@ ephy_toolbars_model_class_init (EphyToolbarsModelClass *klass)
                                          g_param_spec_object ("bookmarks",
                                                               "Bookmarks",
                                                               "Bookmarks",
-                                                              EPHY_BOOKMARKS_TYPE,
+                                                              EPHY_TYPE_BOOKMARKS,
                                                               G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof(EphyToolbarsModelPrivate));
 }
 
 static void
@@ -458,7 +460,8 @@ toolbar_removed (EphyToolbarsModel *model, int position)
 static void
 ephy_toolbars_model_init (EphyToolbarsModel *t)
 {
-	t->priv = g_new0 (EphyToolbarsModelPrivate, 1);
+	t->priv = EPHY_TOOLBARS_MODEL_GET_PRIVATE (t);
+
 	t->priv->bookmarks = NULL;
 	t->priv->loading = FALSE;
 	t->priv->xml_file = g_build_filename (ephy_dot_dir (),
@@ -476,17 +479,12 @@ ephy_toolbars_model_finalize (GObject *object)
 {
 	EphyToolbarsModel *t = EPHY_TOOLBARS_MODEL (object);
 
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_EPHY_TOOLBARS_MODEL (object));
-
 	save_changes (t);
 
 	g_object_unref (t->priv->bookmarks);
 
 	g_free (t->priv->xml_file);
 
-	g_free (t->priv);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -495,7 +493,7 @@ ephy_toolbars_model_new (EphyBookmarks *bookmarks)
 {
 	EphyToolbarsModel *t;
 
-	t = EPHY_TOOLBARS_MODEL (g_object_new (EPHY_TOOLBARS_MODEL_TYPE,
+	t = EPHY_TOOLBARS_MODEL (g_object_new (EPHY_TYPE_TOOLBARS_MODEL,
 					       "bookmarks", bookmarks,
 					       NULL));
 
