@@ -27,6 +27,7 @@
 
 #include <string.h>
 #include <bonobo/bonobo-i18n.h>
+#include <gtk/gtkclipboard.h>
 
 static EphyEmbedEvent *
 get_event_info (EphyWindow *window)
@@ -41,7 +42,7 @@ get_event_info (EphyWindow *window)
 }
 
 void
-popup_cmd_link_in_new_window (EggAction *action,
+popup_cmd_link_in_new_window (GtkAction *action,
 		              EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -61,7 +62,7 @@ popup_cmd_link_in_new_window (EggAction *action,
 }
 
 void
-popup_cmd_link_in_new_tab (EggAction *action,
+popup_cmd_link_in_new_tab (GtkAction *action,
 		           EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -81,7 +82,7 @@ popup_cmd_link_in_new_tab (EggAction *action,
 }
 
 void
-popup_cmd_image_in_new_tab (EggAction *action,
+popup_cmd_image_in_new_tab (GtkAction *action,
 			    EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -101,7 +102,7 @@ popup_cmd_image_in_new_tab (EggAction *action,
 }
 
 void
-popup_cmd_image_in_new_window (EggAction *action,
+popup_cmd_image_in_new_window (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -121,7 +122,7 @@ popup_cmd_image_in_new_window (EggAction *action,
 }
 
 void
-popup_cmd_bookmark_link (EggAction *action,
+popup_cmd_bookmark_link (GtkAction *action,
 			 EphyWindow *window)
 {
 	GtkWidget *new_bookmark;
@@ -179,7 +180,7 @@ popup_cmd_bookmark_link (EggAction *action,
 }
 
 void
-popup_cmd_frame_in_new_tab (EggAction *action,
+popup_cmd_frame_in_new_tab (GtkAction *action,
 			    EphyWindow *window)
 {
 	EphyTab *tab;
@@ -201,7 +202,7 @@ popup_cmd_frame_in_new_tab (EggAction *action,
 }
 
 void
-popup_cmd_frame_in_new_window (EggAction *action,
+popup_cmd_frame_in_new_window (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyTab *tab;
@@ -232,7 +233,7 @@ popup_cmd_copy_to_clipboard (EphyWindow *window, const char *text)
 }
 
 void
-popup_cmd_copy_link_address (EggAction *action,
+popup_cmd_copy_link_address (GtkAction *action,
 			     EphyWindow *window)
 {
 	EphyEmbedEvent *event;
@@ -240,7 +241,7 @@ popup_cmd_copy_link_address (EggAction *action,
 	const GValue *value;
 
 	event = get_event_info (window);
-	g_return_if_fail (IS_EPHY_EMBED_EVENT (event));
+	g_return_if_fail (EPHY_IS_EMBED_EVENT (event));
 
 	if (event->context & EMBED_CONTEXT_EMAIL_LINK)
 	{
@@ -257,11 +258,10 @@ popup_cmd_copy_link_address (EggAction *action,
 }
 
 static void
-save_property_url (EggAction *action,
+save_property_url (GtkAction *action,
 		   const char *title,
 		   EphyWindow *window,
 		   gboolean ask_dest,
-		   gboolean show_progress,
 		   const char *property)
 {
 	EphyEmbedEvent *info;
@@ -284,21 +284,15 @@ save_property_url (EggAction *action,
 
 	ephy_embed_persist_set_source (persist, location);
 
-	if (show_progress)
-	{
-		ephy_embed_persist_set_flags (persist,
-					      EMBED_PERSIST_SHOW_PROGRESS);
-	}
-
 	ephy_embed_utils_save (GTK_WIDGET (window), title,
 			       CONF_STATE_DOWNLOADING_DIR,
-			       ask_dest, FALSE, persist);
+			       ask_dest, persist);
 
 	g_object_unref (G_OBJECT(persist));
 }
 
 void
-popup_cmd_open_link (EggAction *action,
+popup_cmd_open_link (GtkAction *action,
 		     EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -317,21 +311,21 @@ popup_cmd_open_link (EggAction *action,
 }
 
 void
-popup_cmd_download_link (EggAction *action,
+popup_cmd_download_link (GtkAction *action,
 			 EphyWindow *window)
 {
 	save_property_url (action, _("Download link"), window,
 		           eel_gconf_get_boolean
 		           (CONF_ASK_DOWNLOAD_DEST),
-		           TRUE, "link");
+		           "link");
 }
 
 void
-popup_cmd_save_image_as (EggAction *action,
+popup_cmd_save_image_as (GtkAction *action,
 			 EphyWindow *window)
 {
 	save_property_url (action, _("Save Image As"),
-			   window, TRUE, FALSE, "image");
+			   window, TRUE, "image");
 }
 
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
@@ -360,7 +354,7 @@ background_download_completed (EphyEmbedPersist *persist,
 }
 
 void
-popup_cmd_set_image_as_background (EggAction *action,
+popup_cmd_set_image_as_background (GtkAction *action,
 				   EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -397,7 +391,7 @@ popup_cmd_set_image_as_background (EggAction *action,
 }
 
 void
-popup_cmd_copy_image_location (EggAction *action,
+popup_cmd_copy_image_location (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbedEvent *info;
@@ -415,15 +409,15 @@ popup_cmd_copy_image_location (EggAction *action,
 }
 
 void
-popup_cmd_save_background_as (EggAction *action,
+popup_cmd_save_background_as (GtkAction *action,
 			      EphyWindow *window)
 {
 	save_property_url (action, _("Save Background As"),
-			   window, TRUE, FALSE, "background_image");
+			   window, TRUE, "background_image");
 }
 
 void
-popup_cmd_open_frame (EggAction *action,
+popup_cmd_open_frame (GtkAction *action,
 		      EphyWindow *window)
 {
 	char *location;
@@ -440,7 +434,7 @@ popup_cmd_open_frame (EggAction *action,
 }
 
 void
-popup_cmd_open_image (EggAction *action,
+popup_cmd_open_image (GtkAction *action,
 		      EphyWindow *window)
 {
 	EphyEmbedEvent *info;
