@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ppview-toolbar.c,v 1.14 2003/09/05 16:50:00 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,12 +27,12 @@
 #include "ephy-bonobo-extensions.h"
 #include "ephy-string.h"
 #include "ephy-gui.h"
-#include "egg-menu-merge.h"
 
 #include <string.h>
 #include <bonobo/bonobo-i18n.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkmenu.h>
+#include <gtk/gtkuimanager.h>
 
 static void ppview_toolbar_class_init (PPViewToolbarClass *klass);
 static void ppview_toolbar_init (PPViewToolbar *t);
@@ -55,98 +57,99 @@ enum
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_PPVIEW_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PPVIEW_TOOLBAR, PPViewToolbarPrivate))
+
 struct PPViewToolbarPrivate
 {
 	EphyWindow *window;
 	EmbedChromeMask original_mask;
-	EggMenuMerge *ui_merge;
-	EggActionGroup *action_group;
+	GtkUIManager *ui_merge;
+	GtkActionGroup *action_group;
 	guint ui_id;
 	int current_page;
 };
 
 static void
-toolbar_cmd_ppv_goto_first (EggMenuMerge *merge,
+toolbar_cmd_ppv_goto_first (GtkUIManager *merge,
 			    PPViewToolbar *t);
 
 static void
-toolbar_cmd_ppv_goto_last (EggMenuMerge *merge,
+toolbar_cmd_ppv_goto_last (GtkUIManager *merge,
 			   PPViewToolbar *t);
 
 static void
-toolbar_cmd_ppv_go_back (EggMenuMerge *merge,
+toolbar_cmd_ppv_go_back (GtkUIManager *merge,
 			 PPViewToolbar *t);
 
 static void
-toolbar_cmd_ppv_go_forward (EggMenuMerge *merge,
+toolbar_cmd_ppv_go_forward (GtkUIManager *merge,
 			    PPViewToolbar *t);
 
 static void
-toolbar_cmd_ppv_close (EggMenuMerge *merge,
+toolbar_cmd_ppv_close (GtkUIManager *merge,
 		       PPViewToolbar *t);
 
-static EggActionGroupEntry entries [] = {
-	{ "PPVGotoFirst", N_("First"),
-	  GTK_STOCK_GOTO_FIRST, NULL,
+static GtkActionEntry entries [] = {
+	{ "PPVGotoFirst", GTK_STOCK_GOTO_FIRST,
+	  N_("First"), NULL,
 	  N_("Go to the first page"),
-	  (GCallback)toolbar_cmd_ppv_goto_first, NULL },
-	{ "PPVGotoLast", N_("Last"),
-	  GTK_STOCK_GOTO_LAST, NULL,
+	  (GCallback)toolbar_cmd_ppv_goto_first },
+	{ "PPVGotoLast", GTK_STOCK_GOTO_LAST,
+	  N_("Last"), NULL,
 	  N_("Go to the last page"),
-	  (GCallback)toolbar_cmd_ppv_goto_last, NULL },
-	{ "PPVGoBack", N_("Previous"),
-	  GTK_STOCK_GO_BACK, NULL,
+	  (GCallback)toolbar_cmd_ppv_goto_last },
+	{ "PPVGoBack", GTK_STOCK_GO_BACK,
+	  N_("Previous"), NULL,
 	  N_("Go to the previous page"),
-	  (GCallback)toolbar_cmd_ppv_go_back, NULL },
-	{ "PPVGoForward", N_("Next"),
-	  GTK_STOCK_GO_FORWARD, NULL,
+	  (GCallback)toolbar_cmd_ppv_go_back },
+	{ "PPVGoForward", GTK_STOCK_GO_FORWARD,
+	  N_("Next"), NULL,
 	  N_("Go to next page"),
-	  (GCallback)toolbar_cmd_ppv_go_forward, NULL },
-	{ "PPVClose", N_("Close"),
-	  GTK_STOCK_CLOSE, NULL,
+	  (GCallback)toolbar_cmd_ppv_go_forward },
+	{ "PPVClose", GTK_STOCK_CLOSE,
+	  N_("Close"), NULL,
 	  N_("Close print preview"),
-	  (GCallback)toolbar_cmd_ppv_close, NULL },
+	  (GCallback)toolbar_cmd_ppv_close },
 };
 static guint n_entries = G_N_ELEMENTS (entries);
 
 static const gchar *ui_info =
-"<Root>\n"
-"  <dockitem name=\"PPViewToolbar\">\n"
-"    <toolitem name=\"PPVGotoFirstItem\" verb=\"PPVGotoFirst\" />\n"
-"    <toolitem name=\"PPVGotoLastItem\" verb=\"PPVGotoLast\" />\n"
-"    <toolitem name=\"PPVGoBackItem\"verb=\"PPVGoBack\" />\n"
-"    <toolitem name=\"PPVGoForwardItem\" verb=\"PPVGoForward\" />\n"
-"    <toolitem name=\"PPVClose\" verb=\"PPVClose\" />\n"
-"  </dockitem>\n"
-"</Root>\n";
+"<ui>"
+"  <toolbar name=\"PPViewToolbar\">"
+"    <toolitem name=\"PPVGotoFirstItem\" action=\"PPVGotoFirst\" />"
+"    <toolitem name=\"PPVGotoLastItem\" action=\"PPVGotoLast\" />"
+"    <toolitem name=\"PPVGoBackItem\" action=\"PPVGoBack\" />"
+"    <toolitem name=\"PPVGoForwardItem\" action=\"PPVGoForward\" />"
+"    <toolitem name=\"PPVClose\" action=\"PPVClose\" />"
+"  </toolbar>\n"
+"</ui>\n";
 
 GType
 ppview_toolbar_get_type (void)
 {
-        static GType ppview_toolbar_type = 0;
+	static GType ppview_toolbar_type = 0;
 
-        if (ppview_toolbar_type == 0)
-        {
-                static const GTypeInfo our_info =
-                {
-                        sizeof (PPViewToolbarClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) ppview_toolbar_class_init,
-                        NULL,
-                        NULL, /* class_data */
-                        sizeof (PPViewToolbar),
-                        0, /* n_preallocs */
-                        (GInstanceInitFunc) ppview_toolbar_init
-                };
+	if (ppview_toolbar_type == 0)
+	{
+		static const GTypeInfo our_info =
+		{
+			sizeof (PPViewToolbarClass),
+			NULL, /* base_init */
+			NULL, /* base_finalize */
+			(GClassInitFunc) ppview_toolbar_class_init,
+			NULL,
+			NULL, /* class_data */
+			sizeof (PPViewToolbar),
+			0, /* n_preallocs */
+			(GInstanceInitFunc) ppview_toolbar_init
+		};
 
-                ppview_toolbar_type = g_type_register_static (G_TYPE_OBJECT,
-						       "PPViewToolbar",
-						       &our_info, 0);
+		ppview_toolbar_type = g_type_register_static (G_TYPE_OBJECT,
+							      "PPViewToolbar",
+							      &our_info, 0);
         }
 
-        return ppview_toolbar_type;
-
+	return ppview_toolbar_type;
 }
 
 static void
@@ -166,8 +169,11 @@ ppview_toolbar_class_init (PPViewToolbarClass *klass)
                                          g_param_spec_object ("EphyWindow",
                                                               "EphyWindow",
                                                               "Parent window",
-                                                              EPHY_WINDOW_TYPE,
-                                                              G_PARAM_READWRITE));
+                                                              EPHY_TYPE_WINDOW,
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY));
+
+	g_type_class_add_private (object_class, sizeof(PPViewToolbarPrivate));
 }
 
 static void
@@ -176,7 +182,7 @@ ppview_toolbar_set_property (GObject *object,
                       const GValue *value,
                       GParamSpec *pspec)
 {
-        PPViewToolbar *t = PPVIEW_TOOLBAR (object);
+        PPViewToolbar *t = EPHY_PPVIEW_TOOLBAR (object);
 
         switch (prop_id)
         {
@@ -192,7 +198,7 @@ ppview_toolbar_get_property (GObject *object,
                       GValue *value,
                       GParamSpec *pspec)
 {
-        PPViewToolbar *t = PPVIEW_TOOLBAR (object);
+        PPViewToolbar *t = EPHY_PPVIEW_TOOLBAR (object);
 
         switch (prop_id)
         {
@@ -208,8 +214,8 @@ toolbar_update_sensitivity (PPViewToolbar *t)
 	int pages, c_page;
 	EphyWindow *window = t->priv->window;
 	EphyEmbed *embed;
-	EggAction *action;
-	EggActionGroup *action_group = t->priv->action_group;
+	GtkAction *action;
+	GtkActionGroup *action_group = t->priv->action_group;
 
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
@@ -217,13 +223,13 @@ toolbar_update_sensitivity (PPViewToolbar *t)
 	ephy_embed_print_preview_num_pages (embed, &pages);
 	c_page = t->priv->current_page;
 
-	action = egg_action_group_get_action (action_group, "PPVGoBack");
+	action = gtk_action_group_get_action (action_group, "PPVGoBack");
 	g_object_set (action, "sensitive", c_page > 1, NULL);
-	action = egg_action_group_get_action (action_group, "PPVGotoFirst");
+	action = gtk_action_group_get_action (action_group, "PPVGotoFirst");
 	g_object_set (action, "sensitive", c_page > 1, NULL);
-	action = egg_action_group_get_action (action_group, "PPVGoForward");
+	action = gtk_action_group_get_action (action_group, "PPVGoForward");
 	g_object_set (action, "sensitive", c_page < pages, NULL);
-	action = egg_action_group_get_action (action_group, "PPVGotoLast");
+	action = gtk_action_group_get_action (action_group, "PPVGotoLast");
 	g_object_set (action, "sensitive", c_page < pages, NULL);
 }
 
@@ -233,15 +239,17 @@ ppview_toolbar_set_window (PPViewToolbar *t, EphyWindow *window)
 	g_return_if_fail (t->priv->window == NULL);
 
 	t->priv->window = window;
-	t->priv->ui_merge = EGG_MENU_MERGE (t->priv->window->ui_merge);
+	t->priv->ui_merge = GTK_UI_MANAGER (t->priv->window->ui_merge);
 
 	t->priv->original_mask = ephy_window_get_chrome (window);
 
-	t->priv->action_group = egg_action_group_new ("PPViewActions");
-	egg_action_group_add_actions (t->priv->action_group, entries, n_entries);
-	egg_menu_merge_insert_action_group (t->priv->ui_merge,
+	t->priv->action_group = gtk_action_group_new ("PPViewActions");
+	gtk_action_group_set_translation_domain (t->priv->action_group, NULL);
+	gtk_action_group_add_actions (t->priv->action_group, entries,	
+				      n_entries, t);
+	gtk_ui_manager_insert_action_group (t->priv->ui_merge,
 					    t->priv->action_group, 0);
-	t->priv->ui_id = egg_menu_merge_add_ui_from_string
+	t->priv->ui_id = gtk_ui_manager_add_ui_from_string
 		(t->priv->ui_merge, ui_info, -1, NULL);
 
 	toolbar_update_sensitivity (t);
@@ -250,38 +258,23 @@ ppview_toolbar_set_window (PPViewToolbar *t, EphyWindow *window)
 static void
 ppview_toolbar_init (PPViewToolbar *t)
 {
-	int i;
-
-        t->priv = g_new0 (PPViewToolbarPrivate, 1);
+	t->priv = EPHY_PPVIEW_TOOLBAR_GET_PRIVATE (t);
 
 	t->priv->window = NULL;
 	t->priv->ui_merge = NULL;
-
-	for (i = 0; i < n_entries; i++)
-	{
-		entries[i].user_data = t;
-	}
+	t->priv->current_page = 1;
 }
 
 static void
 ppview_toolbar_finalize (GObject *object)
 {
-	PPViewToolbar *t;
+	PPViewToolbar *t = EPHY_PPVIEW_TOOLBAR (object);
 
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_PPVIEW_TOOLBAR (object));
-
-	t = PPVIEW_TOOLBAR (object);
-
-        g_return_if_fail (t->priv != NULL);
-
-	egg_menu_merge_remove_ui (t->priv->ui_merge, t->priv->ui_id);
-	egg_menu_merge_remove_action_group (t->priv->ui_merge,
+	gtk_ui_manager_remove_ui (t->priv->ui_merge, t->priv->ui_id);
+	gtk_ui_manager_remove_action_group (t->priv->ui_merge,
 					    t->priv->action_group);
 	g_object_unref (t->priv->action_group);
 
-        g_free (t->priv);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -290,24 +283,22 @@ ppview_toolbar_new (EphyWindow *window)
 {
 	PPViewToolbar *t;
 
-	t = PPVIEW_TOOLBAR (g_object_new (PPVIEW_TOOLBAR_TYPE,
-					  "EphyWindow", window,
-					  NULL));
-
-	g_return_val_if_fail (t->priv != NULL, NULL);
+	t = EPHY_PPVIEW_TOOLBAR (g_object_new (EPHY_TYPE_PPVIEW_TOOLBAR,
+					       "EphyWindow", window,
+					       NULL));
 
 	return t;
 }
 
 static void
-toolbar_cmd_ppv_goto_first (EggMenuMerge *merge,
+toolbar_cmd_ppv_goto_first (GtkUIManager *merge,
 			    PPViewToolbar *t)
 {
 	EphyWindow *window = t->priv->window;
 	EphyEmbed *embed;
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	ephy_embed_print_preview_navigate (embed, PRINTPREVIEW_HOME, 0);
 
@@ -317,7 +308,7 @@ toolbar_cmd_ppv_goto_first (EggMenuMerge *merge,
 }
 
 static void
-toolbar_cmd_ppv_goto_last  (EggMenuMerge *merge,
+toolbar_cmd_ppv_goto_last  (GtkUIManager *merge,
 			    PPViewToolbar *t)
 {
 	EphyWindow *window = t->priv->window;
@@ -336,55 +327,81 @@ toolbar_cmd_ppv_goto_last  (EggMenuMerge *merge,
 	toolbar_update_sensitivity (t);
 }
 
+static int
+clamp_page_limits (PPViewToolbar *t, int page)
+{
+	EphyWindow *window = t->priv->window;
+	EphyEmbed *embed;
+	int pages;
+
+	embed = ephy_window_get_active_embed (window);
+	g_return_val_if_fail (embed != NULL, -1);
+
+	ephy_embed_print_preview_num_pages (embed, &pages);
+
+	return CLAMP (page, 1, pages);
+}
+
 static void
-toolbar_cmd_ppv_go_back  (EggMenuMerge *merge,
+toolbar_cmd_ppv_go_back  (GtkUIManager *merge,
 			  PPViewToolbar *t)
 {
 	EphyWindow *window = t->priv->window;
 	EphyEmbed *embed;
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	t->priv->current_page = clamp_page_limits (t, t->priv->current_page - 1);
 
 	ephy_embed_print_preview_navigate (embed,
-					   PRINTPREVIEW_PREV_PAGE,
-					   0);
-
-	t->priv->current_page --;
+					   PRINTPREVIEW_GOTO_PAGENUM,
+					   t->priv->current_page);
 
 	toolbar_update_sensitivity (t);
 }
 
 static void
-toolbar_cmd_ppv_go_forward (EggMenuMerge *merge,
+toolbar_cmd_ppv_go_forward (GtkUIManager *merge,
 			    PPViewToolbar *t)
 {
 	EphyWindow *window = t->priv->window;
 	EphyEmbed *embed;
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	t->priv->current_page = clamp_page_limits (t, t->priv->current_page + 1);
 
 	ephy_embed_print_preview_navigate (embed,
-					   PRINTPREVIEW_NEXT_PAGE,
-					   0);
-
-	t->priv->current_page ++;
+					   PRINTPREVIEW_GOTO_PAGENUM,
+					   t->priv->current_page);
 
 	toolbar_update_sensitivity (t);
 }
 
 static void
-toolbar_cmd_ppv_close (EggMenuMerge *merge,
+toolbar_cmd_ppv_close (GtkUIManager *merge,
 		       PPViewToolbar *t)
 {
-	EphyWindow *window = t->priv->window;
+	EphyWindow *window;
 	EphyEmbed *embed;
+	GtkWidget *notebook;
+
+	g_return_if_fail (EPHY_IS_PPVIEW_TOOLBAR (t));
+
+	window = t->priv->window;
+	g_return_if_fail (EPHY_IS_WINDOW (window));
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	ephy_window_set_chrome (t->priv->window, t->priv->original_mask);
+	ephy_window_set_chrome (window, t->priv->original_mask);
+
+	notebook = ephy_window_get_notebook (window);
+	g_return_if_fail (EPHY_IS_NOTEBOOK (notebook));
+
+	ephy_notebook_set_show_tabs (EPHY_NOTEBOOK (notebook), TRUE);
 
 	ephy_embed_print_preview_close (embed);
 }
