@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: prefs-dialog.c,v 1.46 2003/10/17 22:40:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -23,6 +25,8 @@
 #include "prefs-dialog.h"
 #include "ephy-dialog.h"
 #include "ephy-prefs.h"
+#include "ephy-embed-shell.h"
+#include "ephy-shell.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-single.h"
 #include "ephy-shell.h"
@@ -30,6 +34,8 @@
 #include "eel-gconf-extensions.h"
 #include "language-editor.h"
 #include "ephy-langs.h"
+#include "ephy-encodings.h"
+#include "ephy-debug.h"
 
 #include <bonobo/bonobo-i18n.h>
 #include <gtk/gtkframe.h>
@@ -78,6 +84,13 @@ struct
 }
 languages [] =
 {
+	/**
+	 * please translate like this: "<your language> (System setting)"
+	 * Examples:
+	 * "de"    translation: "Deutsch (Systemeinstellung)"
+	 * "en_AU" translation: "English, Australia (System setting)" or
+	 *                      "Australian English (System setting)"
+	 */ 
 	{ N_("System language"), "system" },
 	{ N_("Afrikaans"), "ak" },
 	{ N_("Albanian"), "sq" },
@@ -117,7 +130,7 @@ languages [] =
 	{ N_("Macedonian"), "mk" },
 	{ N_("Malay"), "ms" },
 	{ N_("Norwegian/Nynorsk"), "nn" },
-	{ N_("Norwegian/Bokmaal"), "nb" },
+	{ N_("Norwegian/Bokmal"), "nb" },
 	{ N_("Norwegian"), "no" },
 	{ N_("Polish"), "pl" },
 	{ N_("Portuguese"), "pt" },
@@ -138,27 +151,6 @@ languages [] =
 };
 static guint n_languages = G_N_ELEMENTS (languages);
 
-typedef struct
-{
-	gchar *title;
-	gchar *name;
-} EncodingAutodetectorInfo;
-
-static EncodingAutodetectorInfo encoding_autodetector[] =
-{
-	{ N_("Off"),			"" },
-	{ N_("Chinese"),		"zh_parallel_state_machine" },
-	{ N_("East Asian"),		"cjk_parallel_state_machine" },
-	{ N_("Japanese"),		"ja_parallel_state_machine" },
-	{ N_("Korean"),			"ko_parallel_state_machine" },
-	{ N_("Russian"),		"ruprob" },
-	{ N_("Simplified Chinese"),	"zhcn_parallel_state_machine" },
-	{ N_("Traditional Chinese"),	"zhtw_parallel_state_machine" },
-	{ N_("Universal"),		"universal_charset_detector" },
-	{ N_("Ukrainian"),		"ukprob" }
-};
-static guint n_encoding_autodetectors = G_N_ELEMENTS (encoding_autodetector);
-
 static const
 char *cookies_accept_enum [] =
 {
@@ -166,32 +158,16 @@ char *cookies_accept_enum [] =
 };
 static guint n_cookies_accept_enum = G_N_ELEMENTS (cookies_accept_enum);
 
-static const
-char *cache_compare_enum [] =
-{
-	"once per session", "every time", "never", "automatic"
-};
-static guint n_cache_compare_enum = G_N_ELEMENTS (cache_compare_enum);
-
-static const
-char *proportional_enum [] =
-{
-	"serif", "sans-serif"
-};
-static guint n_proportional_enum = G_N_ELEMENTS (proportional_enum);
-
 enum
 {
-	FONT_TYPE_SERIF,
-	FONT_TYPE_SANSSERIF,
+	FONT_TYPE_VARIABLE,
 	FONT_TYPE_MONOSPACE
 };
 
 const
 char *fonts_types[] =
 {
-	"serif",
-	"sans-serif",
+	"variable",
 	"monospace"
 };
 
@@ -216,34 +192,32 @@ enum
 	NOTEBOOK_PROP,
 
 	/* General */
-	OPEN_IN_TABS_PROP,
 	HOMEPAGE_ENTRY_PROP,
-	AUTO_ENCODING_PROP,
-	DEFAULT_ENCODING_PROP,
-	LANGUAGE_PROP,
 
-	/* Appeareance */
+	/* Fonts and Colors */
 	FONTS_LANGUAGE_PROP,
-	SERIF_PROP,
-	SANSSERIF_PROP,
+	VARIABLE_PROP,
 	MONOSPACE_PROP,
 	FIXED_SIZE_PROP,
 	VARIABLE_SIZE_PROP,
 	MIN_SIZE_PROP,
-	PROPORTIONAL_PROP,
 	USE_COLORS_PROP,
 	USE_FONTS_PROP,
 
-	/* Security */
+	/* Privacy */
 	ALLOW_POPUPS_PROP,
 	ALLOW_JAVA_PROP,
 	ALLOW_JS_PROP,
 	ACCEPT_COOKIES_PROP,
-
-	/* Advanced */
-	CACHE_COMPARE_PROP,
 	DISK_CACHE_PROP,
-	MEMORY_CACHE_PROP
+
+	/* Language */
+	AUTO_ENCODING_PROP,
+	DEFAULT_ENCODING_PROP,
+	LANGUAGE_PROP,
+	LANGUAGE_LABEL_PROP,
+	DEFAULT_ENCODING_LABEL_PROP,
+	AUTO_ENCODING_LABEL_PROP
 };
 
 #define CONF_FONTS_FOR_LANGUAGE	"/apps/epiphany/dialogs/preferences_font_language"
@@ -255,37 +229,45 @@ EphyDialogProperty properties [] =
 	{ NOTEBOOK_PROP, "prefs_notebook", NULL, PT_NORMAL, NULL },
 
 	/* General */
-	{ OPEN_IN_TABS_PROP, "open_in_tabs_checkbutton", CONF_TABS_TABBED, PT_AUTOAPPLY, NULL },
 	{ HOMEPAGE_ENTRY_PROP, "homepage_entry", CONF_GENERAL_HOMEPAGE, PT_AUTOAPPLY, NULL },
-	{ AUTO_ENCODING_PROP, "auto_encoding_optionmenu", NULL, PT_NORMAL, NULL },
-	{ DEFAULT_ENCODING_PROP, "default_encoding_optionmenu", NULL, PT_NORMAL, NULL },
-	{ LANGUAGE_PROP, "language_optionmenu", NULL, PT_NORMAL, NULL },
 
-	/* Appeareance */
+	/* Fonts and Colors */
 	{ FONTS_LANGUAGE_PROP, "fonts_language_optionmenu", CONF_FONTS_FOR_LANGUAGE, PT_AUTOAPPLY, NULL },
-	{ SERIF_PROP, "serif_combo", NULL, PT_NORMAL, NULL },
-	{ SANSSERIF_PROP, "sansserif_combo", NULL, PT_NORMAL, NULL },
+	{ VARIABLE_PROP, "variable_combo", NULL, PT_NORMAL, NULL },
 	{ MONOSPACE_PROP, "monospace_combo", NULL, PT_NORMAL, NULL },
 	{ FIXED_SIZE_PROP, "fixed_size_spinbutton", NULL, PT_NORMAL, NULL },
 	{ VARIABLE_SIZE_PROP, "variable_size_spinbutton", NULL, PT_NORMAL, NULL },
 	{ MIN_SIZE_PROP, "min_size_spinbutton", NULL, PT_NORMAL, NULL },
-	{ PROPORTIONAL_PROP, "proportional_optionmenu", CONF_RENDERING_DEFAULT_FONT, PT_AUTOAPPLY, NULL },
 	{ USE_COLORS_PROP, "use_colors_checkbutton", CONF_RENDERING_USE_OWN_COLORS, PT_AUTOAPPLY, NULL },
 	{ USE_FONTS_PROP, "use_fonts_checkbutton", CONF_RENDERING_USE_OWN_FONTS, PT_AUTOAPPLY, NULL },
 
-	/* Security */
+	/* Privacy */
 	{ ALLOW_POPUPS_PROP, "popups_allow_checkbutton", CONF_SECURITY_ALLOW_POPUPS, PT_AUTOAPPLY, NULL },
 	{ ALLOW_JAVA_PROP, "enable_java_checkbutton", CONF_SECURITY_JAVA_ENABLED, PT_AUTOAPPLY, NULL },
 	{ ALLOW_JS_PROP, "enable_javascript_checkbutton", CONF_SECURITY_JAVASCRIPT_ENABLED, PT_AUTOAPPLY, NULL },
 	{ ACCEPT_COOKIES_PROP, "cookies_radiobutton", CONF_SECURITY_COOKIES_ACCEPT, PT_AUTOAPPLY, NULL },
-
-	/* Advanced */
-	{ CACHE_COMPARE_PROP, "cache_compare_radiobutton", CONF_NETWORK_CACHE_COMPARE, PT_AUTOAPPLY, NULL },
 	{ DISK_CACHE_PROP, "disk_cache_spin", CONF_NETWORK_CACHE_SIZE, PT_AUTOAPPLY, NULL },
 
+	/* Languages */
+	{ AUTO_ENCODING_PROP, "auto_encoding_optionmenu", CONF_LANGUAGE_AUTODETECT_ENCODING, PT_AUTOAPPLY, NULL },
+	{ DEFAULT_ENCODING_PROP, "default_encoding_optionmenu", CONF_LANGUAGE_DEFAULT_ENCODING, PT_AUTOAPPLY, NULL },
+	{ LANGUAGE_PROP, "language_optionmenu", NULL, PT_NORMAL, NULL },
+	{ LANGUAGE_LABEL_PROP, "language_label", NULL, PT_NORMAL, NULL },
+	{ DEFAULT_ENCODING_LABEL_PROP, "default_encoding_label", NULL, PT_NORMAL, NULL },
+	{ AUTO_ENCODING_LABEL_PROP, "auto_encoding_label", NULL, PT_NORMAL, NULL },
+
 	{ -1, NULL, NULL }
 };
 
+static
+int lang_size_group [] =
+{
+	LANGUAGE_LABEL_PROP,
+	DEFAULT_ENCODING_LABEL_PROP,
+	AUTO_ENCODING_LABEL_PROP
+};
+static guint n_lang_size_group = G_N_ELEMENTS (lang_size_group);
+
 typedef struct
 {
 	gchar *name;
@@ -293,14 +275,14 @@ typedef struct
 	gchar *code;
 } EphyLangItem;
 
+#define EPHY_PREFS_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PREFS_DIALOG, PrefsDialogPrivate))
+
 struct PrefsDialogPrivate
 {
 	GtkWidget *notebook;
 	GtkWidget *window;
 
 	GList *langs;
-	GList *encodings;
-	GList *autodetectors;
 	GList *fonts_languages;
 
 	guint language;
@@ -329,7 +311,7 @@ prefs_dialog_get_type (void)
                         (GInstanceInitFunc) prefs_dialog_init
                 };
 
-                prefs_dialog_type = g_type_register_static (EPHY_DIALOG_TYPE,
+		prefs_dialog_type = g_type_register_static (EPHY_TYPE_DIALOG,
 							    "PrefsDialog",
 							    &our_info, 0);
         }
@@ -341,9 +323,9 @@ prefs_dialog_get_type (void)
 EphyDialog *
 prefs_dialog_new (GtkWidget *parent)
 {
-        EphyDialog *dialog;
+	EphyDialog *dialog;
 
-        dialog = EPHY_DIALOG (g_object_new (PREFS_DIALOG_TYPE,
+	dialog = EPHY_DIALOG (g_object_new (EPHY_TYPE_PREFS_DIALOG,
 					    "ParentWindow", parent,
 					    NULL));
 
@@ -358,6 +340,8 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
         parent_class = g_type_class_peek_parent (klass);
 
         object_class->finalize = prefs_dialog_finalize;
+
+	g_type_class_add_private (object_class, sizeof(PrefsDialogPrivate));
 }
 
 static void
@@ -374,29 +358,14 @@ free_lang_item (EphyLangItem *item, gpointer user_data)
 static void
 prefs_dialog_finalize (GObject *object)
 {
-        PrefsDialog *pd;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_PREFS_DIALOG (object));
-
-	pd = PREFS_DIALOG (object);
-
-        g_return_if_fail (pd->priv != NULL);
+	PrefsDialog *pd = EPHY_PREFS_DIALOG (object);
 
 	g_list_foreach (pd->priv->langs, (GFunc) free_lang_item, NULL);
 	g_list_free (pd->priv->langs);
 
-	g_list_foreach (pd->priv->encodings, (GFunc) encoding_info_free, NULL);
-	g_list_free (pd->priv->encodings);
-
-	g_list_foreach (pd->priv->autodetectors, (GFunc) g_free, NULL);
-	g_list_free (pd->priv->autodetectors);
-
 	g_list_foreach (pd->priv->fonts_languages, (GFunc) g_free, NULL);
 	g_list_free (pd->priv->fonts_languages);
 
-        g_free (pd->priv);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -420,15 +389,15 @@ prefs_dialog_show_help (PrefsDialog *pd)
 	ephy_gui_help (GTK_WINDOW (pd->priv->window), "epiphany", help_preferences[id]);
 }
 
-static const gchar *
+static const char *
 get_current_language_code (PrefsDialog *dialog)
 {
 	GList *lang;
-	FontsLanguageInfo *info;
+	const EphyFontsLanguageInfo *info;
 
 	lang = g_list_nth (dialog->priv->fonts_languages, dialog->priv->language);
 	g_assert (lang != NULL);
-	info = (FontsLanguageInfo *) lang->data;
+	info = (EphyFontsLanguageInfo *) lang->data;
 
 	return info->code;
 }
@@ -438,11 +407,9 @@ setup_font_menu (PrefsDialog *dialog,
 		 const char *type,
 		 GtkWidget *combo)
 {
-	char *default_font;
-	GList *fonts;
+	GList *fonts = NULL;
 	gchar *name;
 	char key[255];
-	int pos;
 	GtkWidget *entry = GTK_COMBO(combo)->entry;
 	EphyEmbedSingle *single;
 
@@ -451,7 +418,7 @@ setup_font_menu (PrefsDialog *dialog,
 
 	ephy_embed_single_get_font_list (single,
 					 get_current_language_code (dialog),
-					 type, &fonts, &default_font);
+					 &fonts);
 
 	/* Get the default font */
 	g_snprintf (key, 255, "%s_%s_%s", CONF_RENDERING_FONT, type,
@@ -459,7 +426,14 @@ setup_font_menu (PrefsDialog *dialog,
 	name = eel_gconf_get_string (key);
 	if (name == NULL)
 	{
-		name = g_strdup (default_font);
+		if (strcmp (type, "variable") == 0)
+		{
+			name = g_strdup ("sans-serif");
+		}
+		else
+		{
+			name = g_strdup ("monospace");
+		}
 	}
 
 	/* set popdown doesnt like NULL */
@@ -473,13 +447,14 @@ setup_font_menu (PrefsDialog *dialog,
 	/* set the default value */
 	if (name != NULL)
 	{
+		int pos = 0;
+
 		gtk_editable_delete_text (GTK_EDITABLE(entry), 0, -1);
 		gtk_editable_insert_text (GTK_EDITABLE(entry),
-					  name, g_utf8_strlen (name, -1),
+					  name, strlen (name),
 					  &pos);
 	}
 
-	g_free (default_font);
 	g_free (name);
 
 	g_list_foreach (fonts, (GFunc)g_free, NULL);
@@ -541,10 +516,8 @@ attach_font_signal (PrefsDialog *dialog, int prop,
 static void
 attach_fonts_signals (PrefsDialog *dialog)
 {
-	attach_font_signal (dialog, SERIF_PROP,
-			    GINT_TO_POINTER(FONT_TYPE_SERIF));
-	attach_font_signal (dialog, SANSSERIF_PROP,
-			    GINT_TO_POINTER(FONT_TYPE_SANSSERIF));
+	attach_font_signal (dialog, VARIABLE_PROP,
+			    GINT_TO_POINTER(FONT_TYPE_VARIABLE));
 	attach_font_signal (dialog, MONOSPACE_PROP,
 			    GINT_TO_POINTER(FONT_TYPE_MONOSPACE));
 }
@@ -620,21 +593,15 @@ setup_size_controls (PrefsDialog *dialog)
 
 	spin = ephy_dialog_get_control (EPHY_DIALOG(dialog),
 					  FIXED_SIZE_PROP);
-	setup_size_control (dialog, CONF_RENDERING_FONT_FIXED_SIZE, 12, spin);
+	setup_size_control (dialog, CONF_RENDERING_FONT_FIXED_SIZE, 10, spin);
 
 	spin = ephy_dialog_get_control (EPHY_DIALOG(dialog),
 					  VARIABLE_SIZE_PROP);
-	setup_size_control (dialog, CONF_RENDERING_FONT_VAR_SIZE, 16, spin);
+	setup_size_control (dialog, CONF_RENDERING_FONT_VAR_SIZE, 11, spin);
 
 	spin = ephy_dialog_get_control (EPHY_DIALOG(dialog),
 					  MIN_SIZE_PROP);
-	setup_size_control (dialog, CONF_RENDERING_FONT_MIN_SIZE, 0, spin);
-}
-
-static gint
-fonts_language_info_cmp (const FontsLanguageInfo *i1, const FontsLanguageInfo *i2)
-{
-	return g_utf8_collate (i1->title, i2->title);
+	setup_size_control (dialog, CONF_RENDERING_FONT_MIN_SIZE, 7, spin);
 }
 
 static void
@@ -645,12 +612,8 @@ setup_fonts (PrefsDialog *dialog)
 	dialog->priv->switching = TRUE;
 
 	combo = ephy_dialog_get_control (EPHY_DIALOG(dialog),
-					 SERIF_PROP);
-	setup_font_menu (dialog, "serif", combo);
-
-	combo = ephy_dialog_get_control (EPHY_DIALOG(dialog),
-					 SANSSERIF_PROP);
-	setup_font_menu (dialog, "sans-serif", combo);
+					 VARIABLE_PROP);
+	setup_font_menu (dialog, "variable", combo);
 
 	combo = ephy_dialog_get_control (EPHY_DIALOG(dialog),
 					 MONOSPACE_PROP);
@@ -659,41 +622,47 @@ setup_fonts (PrefsDialog *dialog)
 	dialog->priv->switching = FALSE;
 }
 
+static int
+fonts_language_info_cmp (const EphyFontsLanguageInfo *i1,
+			 const EphyFontsLanguageInfo *i2)
+{
+	return g_utf8_collate (i1->title, i2->title);
+}
+
 static void
 create_fonts_language_menu (PrefsDialog *dialog)
 {
 	GtkWidget *optionmenu, *menu;
-	GList *l = NULL;
-	guint i;
-	guint n_fonts_languages;
-	const FontsLanguageInfo *fonts_language;
+	GList *list = NULL, *l;
+	guint n_fonts_languages, i;
 	char **lang_codes;
-
-	n_fonts_languages = ephy_langs_get_n_font_languages ();
-	fonts_language = ephy_langs_get_font_languages ();
-
-	for (i = 0; i < n_fonts_languages; i++)
-	{
-		FontsLanguageInfo *info;
-
-		info = g_new0 (FontsLanguageInfo, 1);
-		info->title = _(fonts_language[i].title);
-		info->code = fonts_language[i].code;
-
-		l = g_list_prepend (l, info);
-	}
-
-	l = g_list_sort (l, (GCompareFunc) fonts_language_info_cmp);
-	dialog->priv->fonts_languages = l;
+	const EphyFontsLanguageInfo *fonts_languages;
 
 	optionmenu = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 					      FONTS_LANGUAGE_PROP);
 
 	menu = gtk_menu_new ();
 
+	fonts_languages = ephy_font_languages ();
+	n_fonts_languages = ephy_font_n_languages ();
+	
+	for (i = 0; i < n_fonts_languages; i++)
+	{
+		EphyFontsLanguageInfo *info;
+
+		info = g_new0 (EphyFontsLanguageInfo, 1);
+		info->title = _(fonts_languages[i].title);
+		info->code = fonts_languages[i].code;
+
+		list = g_list_prepend (list, info);
+	}
+
+	dialog->priv->fonts_languages =
+		g_list_sort (list, (GCompareFunc) fonts_language_info_cmp);
+
 	for (l = dialog->priv->fonts_languages; l != NULL; l = l->next)
 	{
-		FontsLanguageInfo *info = (FontsLanguageInfo *) l->data;
+		EphyFontsLanguageInfo *info = (EphyFontsLanguageInfo *) l->data;
 		GtkWidget *item;
 
 		item = gtk_menu_item_new_with_label (info->title);
@@ -704,17 +673,17 @@ create_fonts_language_menu (PrefsDialog *dialog)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(optionmenu), menu);
 
 	lang_codes = g_new0 (char *, n_fonts_languages);
-	i = 0;
-	for (l = dialog->priv->fonts_languages; l != NULL; l = l->next)
+	for (l = dialog->priv->fonts_languages, i=0; l != NULL; l = l->next)
 	{
-		FontsLanguageInfo *info = (FontsLanguageInfo *) l->data;
+		EphyFontsLanguageInfo *info = (EphyFontsLanguageInfo *) l->data;
 
 		lang_codes[i] = info->code;
-		
+
 		i++;
 	}
 	ephy_dialog_add_enum (EPHY_DIALOG (dialog), FONTS_LANGUAGE_PROP,
 			      n_fonts_languages, (const char **) lang_codes);
+	/* the entries themselves are const, so don't use g_strfreev here */
 	g_free (lang_codes);
 
 	dialog->priv->language =
@@ -725,166 +694,97 @@ create_fonts_language_menu (PrefsDialog *dialog)
 			  dialog);
 }
 
-static void
-default_encoding_menu_changed_cb (GtkOptionMenu *option_menu,
-				  PrefsDialog *dialog)
+static int
+find_encoding_in_list_cmp (gconstpointer info, const char *encoding)
 {
-	GList *encoding;
-	gint i;
-	EncodingInfo *info;
+	EphyNode *node = (EphyNode *) info;
+	const char *code;
 
-	i = gtk_option_menu_get_history (option_menu);
-	encoding = g_list_nth (dialog->priv->encodings, i);
-	g_assert (encoding != NULL);
+	code = ephy_node_get_property_string
+			(node, EPHY_NODE_ENCODING_PROP_ENCODING);
 
-	info = (EncodingInfo *) encoding->data;
-	eel_gconf_set_string (CONF_LANGUAGE_DEFAULT_ENCODING, info->encoding);
+	return strcmp (code, encoding);
 }
 
-static gint
-find_encoding_in_list_cmp (const EncodingInfo *info, const gchar *encoding)
+static int
+sort_encodings (gconstpointer a, gconstpointer b)
 {
-	return strcmp (info->encoding, encoding);
+	EphyNode *node1 = (EphyNode *) a;
+	EphyNode *node2 = (EphyNode *) b;
+	const char *key1, *key2;
+
+	key1 = ephy_node_get_property_string
+			(node1, EPHY_NODE_ENCODING_PROP_COLLATION_KEY);
+	key2 = ephy_node_get_property_string
+			(node2, EPHY_NODE_ENCODING_PROP_COLLATION_KEY);
+
+	return strcmp (key1, key2);
 }
 
 static void
-create_default_encoding_menu (PrefsDialog *dialog)
+create_optionmenu (PrefsDialog *dialog,
+		   int property,
+		   GList *list,
+		   const char *key,
+		   const char *default_value)
 {
-	GList *l;
+	GList *element, *l;
 	GtkWidget *menu, *optionmenu;
-	gchar *encoding;
-	EphyEmbedSingle *single;
-
-	single = ephy_embed_shell_get_embed_single
-		(EPHY_EMBED_SHELL (ephy_shell));
-
-	ephy_embed_single_get_encodings (single, LG_ALL, TRUE,
-					 &dialog->priv->encodings);
+	char *value;
+	char **codes;
+	guint pos, i, num;
 
 	menu = gtk_menu_new ();
 
 	optionmenu = ephy_dialog_get_control (EPHY_DIALOG (dialog),
-					      DEFAULT_ENCODING_PROP);
+					      property);
 
-	for (l = dialog->priv->encodings; l != NULL; l = l->next)
+	list = g_list_sort (list, (GCompareFunc) sort_encodings);
+
+	num = g_list_length (list);
+	codes = g_new0 (char *, num);
+
+	for (l = list, i=0; l != NULL; l = l->next, i++)
 	{
-		EncodingInfo *info = (EncodingInfo *) l->data;
+		EphyNode *node = (EphyNode *) l->data;
+		const char *title, *code;
 		GtkWidget *item;
 
-		item = gtk_menu_item_new_with_label (info->title);
+		title = ephy_node_get_property_string
+				(node, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED);
+
+		item = gtk_menu_item_new_with_label (title);
 		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
 		gtk_widget_show (item);
-	}
 
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(optionmenu), menu);
-
-	/* init value */
-	encoding = eel_gconf_get_string (CONF_LANGUAGE_DEFAULT_ENCODING);
-	/* fallback */
-	if (encoding == NULL) encoding = g_strdup ("ISO-8859-1");
-
-	l = g_list_find_custom (dialog->priv->encodings, encoding,
-				(GCompareFunc) find_encoding_in_list_cmp);
-	gtk_option_menu_set_history (GTK_OPTION_MENU(optionmenu),
-				     g_list_position (dialog->priv->encodings, l));
-	g_free (encoding);
-
-	g_signal_connect (optionmenu, "changed",
-			  G_CALLBACK (default_encoding_menu_changed_cb),
-			  dialog);
-}
-
-static void
-autodetect_encoding_menu_changed_cb (GtkOptionMenu *option_menu, gpointer data)
-{
-	GList *l;
-	guint i;
-	EncodingAutodetectorInfo *info;
-
-	g_return_if_fail (IS_PREFS_DIALOG (data));
-
-	i = gtk_option_menu_get_history (option_menu);
-
-	l = g_list_nth (PREFS_DIALOG (data)->priv->autodetectors, i);
-
-	if (l)
-	{
-		info = (EncodingAutodetectorInfo *) l->data;
-
-		eel_gconf_set_string (CONF_LANGUAGE_AUTODETECT_ENCODING, info->name);
-	}
-}
-
-static gint
-autodetector_info_cmp (const EncodingAutodetectorInfo *i1, const EncodingAutodetectorInfo *i2)
-{
-	return g_utf8_collate (i1->title, i2->title);
-}
-
-static gint
-find_autodetector_info (const EncodingAutodetectorInfo *info, const gchar *name)
-{
-	return strcmp (info->name, name);
-}
-
-static void
-create_encoding_autodetectors_menu (PrefsDialog *dialog)
-{
-	GtkWidget *optionmenu, *menu, *item;
-	gint i, position = 0;
-	GList *l, *list = NULL;
-	gchar *detector = NULL;
-	EncodingAutodetectorInfo *info;
-
-	optionmenu = ephy_dialog_get_control (EPHY_DIALOG (dialog),
-					      AUTO_ENCODING_PROP);
-
-	for (i = 0; i < n_encoding_autodetectors; i++)
-	{
-		info = g_new0 (EncodingAutodetectorInfo, 1);
-
-		info->title = _(encoding_autodetector[i].title);
-		info->name = encoding_autodetector[i].name;
-
-		list = g_list_prepend (list, info);
-	}
-
-	list = g_list_sort (list, (GCompareFunc) autodetector_info_cmp);
-	dialog->priv->autodetectors = list;
-
-	menu = gtk_menu_new ();
-
-	for (l = list; l != NULL; l = l->next)
-	{
-		info = (EncodingAutodetectorInfo *) l->data;
-
-		item = gtk_menu_item_new_with_label (info->title);
-		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
-		gtk_widget_show (item);
-		g_object_set_data (G_OBJECT (item), "desc", info->title);
+		code = ephy_node_get_property_string
+				(node, EPHY_NODE_ENCODING_PROP_ENCODING);
+		codes[i] = (char *) code;
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), menu);
 
 	/* init value */
-	detector = eel_gconf_get_string (CONF_LANGUAGE_AUTODETECT_ENCODING);
-	if (detector == NULL) detector = g_strdup ("");
-
-	l = g_list_find_custom (list, detector,
-				(GCompareFunc) find_autodetector_info);
-
-	g_free (detector);
-
-	if (l)
+	value = eel_gconf_get_string (key);
+	/* fallback */
+	if (value == NULL || value[0] == '\0')
 	{
-		position = g_list_position (list, l);
+		g_free (value);
+		value = g_strdup (default_value);
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU(optionmenu), position);
+	element = g_list_find_custom (list, value,
+				(GCompareFunc) find_encoding_in_list_cmp);
+	g_free (value);
+	pos = g_list_position (list, element);
 
-	g_signal_connect (optionmenu, "changed",
-			  G_CALLBACK (autodetect_encoding_menu_changed_cb),
-			  dialog);
+	ephy_dialog_add_enum (EPHY_DIALOG (dialog), property,
+			      num, (const char **) codes);
+
+	gtk_option_menu_set_history (GTK_OPTION_MENU(optionmenu), pos);
+
+	/* the entries themselves are const, so we don't use g_strfreev here */
+	g_free (codes);
 }
 
 static gint
@@ -984,7 +884,7 @@ language_menu_changed_cb (GtkOptionMenu *option_menu,
 	GSList *list = NULL;
 	GList *lang = NULL;
 
-	g_return_if_fail (IS_PREFS_DIALOG (data));
+	g_return_if_fail (EPHY_IS_PREFS_DIALOG (data));
 
 	list = eel_gconf_get_string_list (CONF_RENDERING_LANGUAGE);
 	g_return_if_fail (list != NULL);
@@ -992,7 +892,7 @@ language_menu_changed_cb (GtkOptionMenu *option_menu,
 	/* Subst the first item according to the optionmenu */
 	i = gtk_option_menu_get_history (option_menu);
 
-	lang = g_list_nth (PREFS_DIALOG (data)->priv->langs, i);
+	lang = g_list_nth (EPHY_PREFS_DIALOG (data)->priv->langs, i);
 
 	if (lang)
 	{
@@ -1052,13 +952,13 @@ set_homepage_entry (EphyDialog *dialog,
 		    const char *new_location)
 {
 	GtkWidget *entry;
-	int pos;
+	int pos = 0;
 
 	entry = ephy_dialog_get_control (dialog, HOMEPAGE_ENTRY_PROP);
 
 	gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
 	gtk_editable_insert_text (GTK_EDITABLE (entry), new_location,
-				  g_utf8_strlen (new_location, -1),
+				  strlen (new_location),
 				  &pos);
 }
 
@@ -1067,27 +967,26 @@ static void
 prefs_dialog_init (PrefsDialog *pd)
 {
 	EphyDialog *dialog = EPHY_DIALOG (pd);
+	EphyEncodings *encodings;
 	GdkPixbuf *icon;
+	GList *list;
 
-	pd->priv = g_new0 (PrefsDialogPrivate, 1);
+	pd->priv = EPHY_PREFS_DIALOG_GET_PRIVATE (pd);
 
 	ephy_dialog_construct (EPHY_DIALOG (pd),
 			       properties,
 			       "prefs-dialog.glade",
 			       "prefs_dialog");
 
-	ephy_dialog_add_enum (EPHY_DIALOG (pd), CACHE_COMPARE_PROP,
-			      n_cache_compare_enum, cache_compare_enum);
 	ephy_dialog_add_enum (EPHY_DIALOG (pd), ACCEPT_COOKIES_PROP,
 			      n_cookies_accept_enum, cookies_accept_enum);
-	ephy_dialog_add_enum (EPHY_DIALOG (pd), PROPORTIONAL_PROP,
-			      n_proportional_enum, proportional_enum);
+
+	ephy_dialog_set_size_group (EPHY_DIALOG (pd), lang_size_group,
+				    n_lang_size_group);
 
 	pd->priv->window = ephy_dialog_get_control (dialog, WINDOW_PROP);
 	pd->priv->notebook = ephy_dialog_get_control (dialog, NOTEBOOK_PROP);
 	pd->priv->langs = NULL;
-	pd->priv->encodings = NULL;
-	pd->priv->autodetectors = NULL;
 	pd->priv->fonts_languages = NULL;
 
 	icon = gtk_widget_render_icon (pd->priv->window,
@@ -1099,18 +998,26 @@ prefs_dialog_init (PrefsDialog *pd)
 
 	pd->priv->switching = FALSE;
 	create_fonts_language_menu (pd);
-	setup_fonts (pd);
-	setup_size_controls (pd);
 	attach_fonts_signals (pd);
 	attach_size_controls_signals (pd);
 	create_languages_list (pd);
-	create_default_encoding_menu (pd);
-	create_encoding_autodetectors_menu (pd);
+
+	encodings = EPHY_ENCODINGS (ephy_embed_shell_get_encodings
+					(EPHY_EMBED_SHELL (ephy_shell)));
+
+	list = ephy_encodings_get_encodings (encodings, LG_ALL);
+	create_optionmenu (pd, DEFAULT_ENCODING_PROP, list,
+			   CONF_LANGUAGE_DEFAULT_ENCODING, "ISO-8859-1");
+	g_list_free (list);
+
+	list = ephy_encodings_get_detectors (encodings);
+	create_optionmenu (pd, AUTO_ENCODING_PROP, list,
+			   CONF_LANGUAGE_AUTODETECT_ENCODING, "");
+	g_list_free (list);
+
 	create_language_menu (pd);
 }
 
-/* Network page callbacks */
-
 void
 prefs_dialog_response_cb (GtkDialog *dialog, gint response_id, gpointer data)
 {
@@ -1142,7 +1049,7 @@ fonts_language_optionmenu_changed_cb (GtkWidget *optionmenu,
 				      EphyDialog *dialog)
 {
 	guint i;
-	PrefsDialog *pd = PREFS_DIALOG (dialog);
+	PrefsDialog *pd = EPHY_PREFS_DIALOG (dialog);
 
 	i = gtk_option_menu_get_history
 		(GTK_OPTION_MENU (optionmenu));
@@ -1176,7 +1083,7 @@ void
 prefs_homepage_blank_button_clicked_cb (GtkWidget *button,
 					EphyDialog *dialog)
 {
-	set_homepage_entry (dialog, "about:blank");
+	set_homepage_entry (dialog, "");
 }
 
 static void
@@ -1203,11 +1110,11 @@ fill_language_editor (LanguageEditor *le, PrefsDialog *dialog)
 		{
 			i = g_list_position (dialog->priv->langs, lang);
 			li = (EphyLangItem *) lang->data;
-			
+
 			language_editor_add (le, li->name, i);
 		}
 	}
-	
+
 	g_slist_foreach (strings, (GFunc) g_free, NULL);
 	g_slist_free (strings);
 }
@@ -1254,12 +1161,12 @@ prefs_language_more_button_clicked_cb (GtkWidget *button,
 	GtkWidget *menu;
 	GtkWidget *toplevel;
 
-	menu = general_prefs_new_language_menu (PREFS_DIALOG (dialog));
+	menu = general_prefs_new_language_menu (EPHY_PREFS_DIALOG (dialog));
 
 	toplevel = gtk_widget_get_toplevel (button);
 	editor = language_editor_new (toplevel);
 	language_editor_set_menu (editor, menu);
-	fill_language_editor (editor, PREFS_DIALOG (dialog));
+	fill_language_editor (editor, EPHY_PREFS_DIALOG (dialog));
 	ephy_dialog_set_modal (EPHY_DIALOG(editor), TRUE);
 
 	g_signal_connect (editor, "changed",
