@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: session.c,v 1.22 2003/09/24 18:45:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,6 +64,8 @@ static void session_dispose (GObject *object);
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_SESSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SESSION, SessionPrivate))
+
 struct SessionPrivate
 {
 	GList *windows;
@@ -137,6 +141,8 @@ session_class_init (SessionClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_OBJECT);
+
+	g_type_class_add_private (object_class, sizeof(SessionPrivate));
 }
 
 static char *
@@ -323,13 +329,7 @@ static void
 session_die_cb (GnomeClient* client,
 		Session *session)
 {
-	g_object_ref (ephy_shell);
-
 	session_close (session);
-
-	ephy_shell_set_server_mode (ephy_shell, FALSE);
-
-	g_object_unref (ephy_shell);
 }
 
 static void
@@ -353,7 +353,8 @@ gnome_session_init (Session *session)
 static void
 session_init (Session *session)
 {
-        session->priv = g_new0 (SessionPrivate, 1);
+	session->priv = EPHY_SESSION_GET_PRIVATE (session);
+
 	session->priv->windows = NULL;
 	session->priv->dont_remove_crashed = FALSE;
 
@@ -399,7 +400,7 @@ session_delete (Session *session,
 static void
 session_dispose (GObject *object)
 {
-	Session *session = SESSION(object);
+	Session *session = EPHY_SESSION(object);
 
 	if (!session->priv->dont_remove_crashed)
 	{
@@ -410,30 +411,10 @@ session_dispose (GObject *object)
 static void
 session_finalize (GObject *object)
 {
-	Session *t;
-	GnomeClient *client;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_SESSION (object));
-
-	t = SESSION (object);
-
-        g_return_if_fail (t->priv != NULL);
+	Session *t = EPHY_SESSION (object);
 
 	g_list_free (t->priv->windows);
 
-	client = gnome_master_client ();
-
-	g_signal_handlers_disconnect_by_func (G_OBJECT (client),
-					      G_CALLBACK (save_yourself_cb),
-					      t);
-
-	g_signal_handlers_disconnect_by_func (G_OBJECT (client),
-					      G_CALLBACK (session_die_cb),
-					      t);
-
-        g_free (t->priv);
-
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -447,13 +428,7 @@ session_finalize (GObject *object)
 Session *
 session_new (void)
 {
-	Session *t;
-
-	t = SESSION (g_object_new (SESSION_TYPE, NULL));
-
-	g_return_val_if_fail (t->priv != NULL, NULL);
-
-	return t;
+	return EPHY_SESSION (g_object_new (EPHY_TYPE_SESSION, NULL));
 }
 
 static void
@@ -464,7 +439,6 @@ save_tab (EphyWindow *window,
 {
 	EmbedChromeMask chrome;
 	char *location;
-	const char *title;
         xmlNodePtr embed_node;
 	EphyEmbed *embed;
 
@@ -474,12 +448,7 @@ save_tab (EphyWindow *window,
         if (chrome & EMBED_CHROME_OPENASCHROME) return;
 
 	/* make a new XML node */
-        embed_node = xmlNewDocNode (doc, NULL,
-                                    "embed", NULL);
-
-        /* store title in the node */
-	title = ephy_tab_get_title (tab);
-	xmlSetProp (embed_node, "title", title);
+        embed_node = xmlNewDocNode (doc, NULL, "embed", NULL);
 
         /* otherwise, use the actual location. */
 	embed = ephy_tab_get_embed (tab);
@@ -512,12 +481,6 @@ session_save (Session *session,
 
 	save_to = get_session_filename (filename);
 
-	if (session->priv->windows == NULL)
-	{
-		session_delete (session, filename);
-		return;
-	}
-
         doc = xmlNewDoc ("1.0");
 
         /* create and set the root node for the session */
@@ -580,13 +543,11 @@ parse_embed (xmlNodePtr child, EphyWindow *window)
 	{
 		if (strcmp (child->name, "embed") == 0)
 		{
-			char *url;
-			char *title;
+			xmlChar *url;
 
 			g_return_if_fail (window != NULL);
 
 			url = xmlGetProp (child, "url");
-			title = xmlGetProp (child, "title");
 
 			ephy_shell_new_tab (ephy_shell, window, NULL, url,
 					    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
@@ -594,7 +555,6 @@ parse_embed (xmlNodePtr child, EphyWindow *window)
 					    EPHY_NEW_TAB_APPEND_LAST);
 
 			xmlFree (url);
-			xmlFree (title);
 		}
 
 		child = child->next;
@@ -621,12 +581,6 @@ session_load (Session *session,
 	save_to = get_session_filename (filename);
 
 	doc = xmlParseFile (save_to);
-	if (doc == NULL)
-	{
-		g_warning ("Failed to load session file %s!\n", save_to);
-		g_free (save_to);
-		return;
-	}
 
 	child = xmlDocGetRootElement (doc);
 
@@ -675,7 +629,7 @@ session_load (Session *session,
 const GList *
 session_get_windows (Session *session)
 {
-	g_return_val_if_fail (IS_SESSION (session), NULL);
+	g_return_val_if_fail (EPHY_IS_SESSION (session), NULL);
 
 	return session->priv->windows;
 }
