@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2000 Marco Pesenti Gritti
- *            (C) 2001, 2002 Jorn Baayen
+ *  Copyright (C) 2001, 2002 Jorn Baayen
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: toolbar.c,v 1.67 2003/10/14 11:36:37 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -22,7 +24,6 @@
 #endif
 
 #include "toolbar.h"
-#include "egg-menu-merge.h"
 #include "ephy-file-helpers.h"
 #include "ephy-shell.h"
 #include "ephy-location-entry.h"
@@ -41,9 +42,12 @@
 #include "ephy-debug.h"
 #include "ephy-new-bookmark.h"
 #include "ephy-stock-icons.h"
-#include "eggtoolbar.h"
+#include "ephy-toolbars-model.h"
 
 #include <string.h>
+#include <bonobo/bonobo-i18n.h>
+#include <gtk/gtkuimanager.h>
+#include <gtk/gtktoolbar.h>
 
 static void toolbar_class_init (ToolbarClass *klass);
 static void toolbar_init (Toolbar *t);
@@ -63,7 +67,7 @@ toolbar_get_property (GObject *object,
 static GtkTargetEntry drag_targets[] = {
   { EGG_TOOLBAR_ITEM_TYPE, 0, 0 },
   { EPHY_DND_TOPIC_TYPE, 0, 1 },
-  { EPHY_DND_BOOKMARK_TYPE, 0, 2 },
+  { EPHY_DND_URL_TYPE, 0, 2 },
 };
 static int n_drag_targets = G_N_ELEMENTS (drag_targets);
 
@@ -75,13 +79,15 @@ enum
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBAR, ToolbarPrivate))
+
 struct ToolbarPrivate
 {
 	EphyWindow *window;
-	EggMenuMerge *ui_merge;
-	EggActionGroup *action_group;
+	GtkUIManager *ui_merge;
+	GtkActionGroup *action_group;
 	gboolean visibility;
-	gboolean can_set_location;
+	gboolean updating_address;
 	GtkWidget *spinner;
 	GtkWidget *favicon;
 	GtkWidget *go;
@@ -117,58 +123,35 @@ toolbar_get_type (void)
 }
 
 static void
-go_location_cb (EggAction *action, char *location, EphyWindow *window)
+go_location_cb (GtkAction *action, char *location, EphyWindow *window)
 {
 	ephy_window_load_url (window, location);
 }
 
 static void
-zoom_to_level_cb (EggAction *action, float zoom, EphyWindow *window)
+zoom_to_level_cb (GtkAction *action, float zoom, EphyWindow *window)
 {
 	ephy_window_set_zoom (window, zoom);
 }
 
-static void
-topic_destroy_cb (EphyNode *node,
-		  Toolbar *t)
-{
-	EggAction *action;
-	char *name;
-	EphyToolbarsModel *model;
-	long id;
-
-	model = ephy_shell_get_toolbars_model (ephy_shell);
-
-	id = ephy_node_get_id (node);
-	name = g_strdup_printf ("GoTopicId%ld", ephy_node_get_id (node));
-	action = egg_action_group_get_action (t->priv->action_group, name);
-	if (action)
-	{
-		ephy_toolbars_model_remove_bookmark (model, TRUE, id);
-		egg_action_group_remove_action (t->priv->action_group, action);
-	}
-
-	g_free (name);
-}
-
 static void
 bookmark_destroy_cb (EphyNode *node,
 		     Toolbar *t)
 {
-	EggAction *action;
+	GtkAction *action;
 	char *name;
 	EphyToolbarsModel *model;
 	long id;
 
-	model = ephy_shell_get_toolbars_model (ephy_shell);
+	model = EPHY_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 
 	id = ephy_node_get_id (node);
-	name = g_strdup_printf ("GoBookmarkId%ld", id);
-	action = egg_action_group_get_action (t->priv->action_group, name);
+	name = ephy_toolbars_model_get_action_name (model, id);
+	action = gtk_action_group_get_action (t->priv->action_group, name);
 	if (action)
 	{
-		ephy_toolbars_model_remove_bookmark (model, FALSE, id);
-		egg_action_group_remove_action (t->priv->action_group, action);
+		gtk_action_group_remove_action (t->priv->action_group, action);
 	}
 
 	g_free (name);
@@ -178,71 +161,55 @@ static void
 toolbar_ensure_action (Toolbar *t,
 		       const char *name)
 {
-	EggAction *action = NULL;
-	long id = 0;
+	GtkAction *action = NULL;
+	EphyToolbarsModel *model;
 	EphyBookmarks *bookmarks;
+	EphyNode *bmks, *topics;
+
+	model = EPHY_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	bmks = ephy_bookmarks_get_bookmarks (bookmarks);
+	topics = ephy_bookmarks_get_keywords (bookmarks);
 
 	LOG ("Ensure action %s", name)
 
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-
-	if (g_str_has_prefix (name, "GoBookmarkId"))
+	if (g_str_has_prefix (name, "GoBookmark-"))
 	{
 		EphyNode *node;
 
-		if (!ephy_string_to_int (name + strlen ("GoBookmarkId"), &id))
+		node = ephy_toolbars_model_get_node (model,name);
+		g_return_if_fail (node != NULL);
+
+		if (ephy_node_has_child (topics, node))
 		{
-			return;
+			action = ephy_topic_action_new (name, ephy_node_get_id (node));
+		}
+		else if (ephy_node_has_child (bmks, node))
+		{
+			action = ephy_bookmark_action_new (name, ephy_node_get_id (node));
 		}
 
-		LOG ("Create action %s", name)
+		g_return_if_fail (action != NULL);
 
-		action = ephy_bookmark_action_new (name, id);
 		g_signal_connect (action, "go_location",
 				  G_CALLBACK (go_location_cb), t->priv->window);
-		egg_action_group_add_action (t->priv->action_group, action);
+		gtk_action_group_add_action (t->priv->action_group, action);
 		g_object_unref (action);
 
-		node = ephy_bookmarks_get_from_id (bookmarks, id);
 		ephy_node_signal_connect_object (node,
 					         EPHY_NODE_DESTROY,
 					         (EphyNodeCallback) bookmark_destroy_cb,
 					         G_OBJECT (t));
 	}
-	else if (g_str_has_prefix (name, "GoTopicId"))
-	{
-		EphyNode *node;
-
-		if (!ephy_string_to_int (name + strlen ("GoTopicId"), &id))
-		{
-			return;
-		}
-
-		LOG ("Create action %s", name)
-
-		action = ephy_topic_action_new (name, id);
-		g_signal_connect (action, "go_location",
-				  G_CALLBACK (go_location_cb),
-				  t->priv->window);
-		egg_action_group_add_action (t->priv->action_group, action);
-		g_object_unref (action);
-
-		node = ephy_bookmarks_get_from_id (bookmarks, id);
-		ephy_node_signal_connect_object (node,
-					         EPHY_NODE_DESTROY,
-					         (EphyNodeCallback) topic_destroy_cb,
-					         G_OBJECT (t));
-	}
 }
 
 static void
 toolbar_class_init (ToolbarClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	EggEditableToolbarClass *eet_class;
 
         parent_class = g_type_class_peek_parent (klass);
-	eet_class = EGG_EDITABLE_TOOLBAR_CLASS (klass);
 
         object_class->finalize = toolbar_finalize;
 	object_class->set_property = toolbar_set_property;
@@ -250,11 +217,14 @@ toolbar_class_init (ToolbarClass *klass)
 
 	g_object_class_install_property (object_class,
                                          PROP_EPHY_WINDOW,
-                                         g_param_spec_object ("EphyWindow",
-                                                              "EphyWindow",
+                                         g_param_spec_object ("window",
+                                                              "Window",
                                                               "Parent window",
-                                                              EPHY_WINDOW_TYPE,
-                                                              G_PARAM_READWRITE));
+							      EPHY_TYPE_WINDOW,
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY));
+
+	g_type_class_add_private (object_class, sizeof(ToolbarPrivate));
 }
 
 static void
@@ -263,13 +233,13 @@ toolbar_set_property (GObject *object,
                       const GValue *value,
                       GParamSpec *pspec)
 {
-        Toolbar *t = TOOLBAR (object);
+        Toolbar *t = EPHY_TOOLBAR (object);
 
         switch (prop_id)
         {
 		case PROP_EPHY_WINDOW:
-		toolbar_set_window (t, g_value_get_object (value));
-		break;
+			toolbar_set_window (t, g_value_get_object (value));
+			break;
         }
 }
 
@@ -279,7 +249,7 @@ toolbar_get_property (GObject *object,
                       GValue *value,
                       GParamSpec *pspec)
 {
-        Toolbar *t = TOOLBAR (object);
+        Toolbar *t = EPHY_TOOLBAR (object);
 
         switch (prop_id)
         {
@@ -289,54 +259,78 @@ toolbar_get_property (GObject *object,
         }
 }
 
+static void
+sync_user_input_cb (EphyLocationAction *action, GParamSpec *pspec, Toolbar *t)
+{
+	EphyTab *tab;
+	const char *address;
+
+	LOG ("sync_user_input_cb")
+
+	if (t->priv->updating_address) return;
+
+	tab = ephy_window_get_active_tab (t->priv->window);
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	address = ephy_location_action_get_address (action);
+
+	t->priv->updating_address = TRUE;
+	ephy_tab_set_location (tab, address, TAB_ADDRESS_EXPIRE_CURRENT);
+	t->priv->updating_address = FALSE;
+}
+
 static void
 toolbar_setup_actions (Toolbar *t)
 {
-	EggAction *action;
+	GtkAction *action;
 
-	t->priv->action_group = egg_action_group_new ("SpecialToolbarActions");
+	t->priv->action_group = gtk_action_group_new ("SpecialToolbarActions");
 
 	action = g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
 			       "name", "NavigationBack",
 			       "label", _("Back"),
 			       "stock_id", GTK_STOCK_GO_BACK,
+			       "tooltip", _("Go back"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_BACK,
+			       "is_important", TRUE,
 			       NULL);
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_cmd_go_back), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
 			       "name", "NavigationForward",
 			       "label", _("Forward"),
 			       "stock_id", GTK_STOCK_GO_FORWARD,
+			       "tooltip", _("Go forward"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_FORWARD,
 			       NULL);
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_cmd_go_forward), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_NAVIGATION_ACTION,
 			       "name", "NavigationUp",
 			       "label", _("Up"),
+			       "stock_id", GTK_STOCK_GO_UP,
+			       "tooltip", _("Go up"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_UP,
-			       "stock_id", GTK_STOCK_GO_UP,
 			       NULL);
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_cmd_go_up), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_SPINNER_ACTION,
 			       "name", "Spinner",
 			       "label", _("Spinner"),
 			       NULL);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	/* FIXME: I'm still waiting for the exact term to 
@@ -346,20 +340,24 @@ toolbar_setup_actions (Toolbar *t)
 			       "name", "Location",
 			       "label", _("Address Entry"),
 			       "stock_id", EPHY_STOCK_ENTRY,
+			       "tooltip", _("Enter a web address to open, or a phrase to search for on the web"),
 			       NULL);
 	g_signal_connect (action, "go_location",
 			  G_CALLBACK (go_location_cb), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	g_signal_connect (action, "notify::address",
+			  G_CALLBACK (sync_user_input_cb), t);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_ZOOM_ACTION,
 			       "name", "Zoom",
 			       "label", _("Zoom"),
+			       "tooltip", _("Adjust the text size"),
 			       "zoom", 1.0,
 			       NULL);
 	g_signal_connect (action, "zoom_to_level",
 			  G_CALLBACK (zoom_to_level_cb), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_FAVICON_ACTION,
@@ -367,17 +365,18 @@ toolbar_setup_actions (Toolbar *t)
 			       "label", _("Favicon"),
 			       "window", t->priv->window,
 			       NULL);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 
 	action = g_object_new (EPHY_TYPE_GO_ACTION,
 			       "name", "ToolbarGo",
 			       "label", _("Go"),
 			       "stock_id", GTK_STOCK_JUMP_TO,
+			       "tooltip", _("Go to the address entered in the address entry"),
 			       NULL);
 	g_signal_connect (action, "activate",
 			  G_CALLBACK (window_cmd_load_location), t->priv->window);
-	egg_action_group_add_action (t->priv->action_group, action);
+	gtk_action_group_add_action (t->priv->action_group, action);
 	g_object_unref (action);
 }
 
@@ -386,7 +385,7 @@ action_request_cb (EggEditableToolbar *etoolbar,
 		   char *action_name,
 		   gpointer data)
 {
-	toolbar_ensure_action (TOOLBAR (etoolbar), action_name);
+	toolbar_ensure_action (EPHY_TOOLBAR (etoolbar), action_name);
 }
 
 static void
@@ -395,7 +394,8 @@ init_bookmarks_toolbar (Toolbar *t)
 	EphyToolbarsModel *model;
 	int i, n_toolbars;
 
-	model = ephy_shell_get_toolbars_model (ephy_shell);
+	model = EPHY_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 	n_toolbars = egg_toolbars_model_n_toolbars
 		(EGG_TOOLBARS_MODEL (model));
 
@@ -452,55 +452,13 @@ update_toolbar_remove_flag (EphyToolbarsModel *model, gpointer data)
 	}
 }
 
-static GtkWidget *
-get_location_entry (Toolbar *t)
-{
-	EggAction *action;
-	GtkWidget *location;
-
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
-
-	return location;
-}
-
 static void
-location_user_changed_cb (GtkWidget *entry, Toolbar *t)
-{
-	EphyTab *tab;
-	char *address;
-
-	tab = ephy_window_get_active_tab (t->priv->window);
-	g_return_if_fail (IS_EPHY_TAB (tab));
-
-	t->priv->can_set_location = FALSE;
-	address = ephy_location_entry_get_location (EPHY_LOCATION_ENTRY (entry));
-	ephy_tab_set_location (tab, address, TAB_ADDRESS_EXPIRE_CURRENT);
-	g_free (address);
-	t->priv->can_set_location = TRUE;
-}
-
-static void
-toolbar_set_window (Toolbar *t, EphyWindow *window)
+init_normal_mode (Toolbar *t)
 {
 	EphyToolbarsModel *model;
 
-	g_return_if_fail (t->priv->window == NULL);
-
-	t->priv->window = window;
-	t->priv->ui_merge = EGG_MENU_MERGE (window->ui_merge);
-
-	toolbar_setup_actions (t);
-	egg_menu_merge_insert_action_group (t->priv->ui_merge,
-					    t->priv->action_group, 1);
-
-	g_signal_connect (t, "action_request",
-			  G_CALLBACK (action_request_cb),
-			  NULL);
-
-	model = ephy_shell_get_toolbars_model (ephy_shell);
+	model = EPHY_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 	g_signal_connect (EGG_TOOLBARS_MODEL (model), "toolbar_added",
 			  G_CALLBACK (update_toolbar_remove_flag),
 			  NULL);
@@ -509,48 +467,89 @@ toolbar_set_window (Toolbar *t, EphyWindow *window)
 			  NULL);
 	g_object_set (G_OBJECT (t),
 		      "ToolbarsModel", model,
-		      "MenuMerge", t->priv->ui_merge,
 		      NULL);
 	init_bookmarks_toolbar (t);
+}
 
-	g_signal_connect_object (get_location_entry (t), "user_changed",
-			         G_CALLBACK (location_user_changed_cb),
+static void
+init_fullscreen_mode (Toolbar *t)
+{
+	EggToolbarsModel *model;
+	
+	model = EGG_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, TRUE));
+
+	g_object_set (G_OBJECT (t),
+		      "ToolbarsModel", model,
+		      NULL);
+}
+
+static gboolean
+window_state_event_cb (GtkWidget *widget, GdkEventWindowState *event, Toolbar *t)
+{
+	if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
+	{
+		gboolean fullscreen;
+
+		fullscreen = event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN;
+		if (fullscreen)
+		{
+			init_fullscreen_mode (t);
+		}
+		else
+		{
+			init_normal_mode (t);
+		}
+	}
+
+	return FALSE;
+}
+
+static void
+toolbar_set_window (Toolbar *t, EphyWindow *window)
+{
+	g_return_if_fail (t->priv->window == NULL);
+
+	t->priv->window = window;
+	t->priv->ui_merge = GTK_UI_MANAGER (window->ui_merge);
+
+	toolbar_setup_actions (t);
+	gtk_ui_manager_insert_action_group (t->priv->ui_merge,
+					    t->priv->action_group, 1);
+	g_signal_connect (t, "action_request",
+			  G_CALLBACK (action_request_cb),
+			  NULL);
+	g_signal_connect_object (window, "window-state-event",
+			         G_CALLBACK (window_state_event_cb),
 			         t, 0);
+
+	g_object_set (G_OBJECT (t),
+		      "MenuMerge", t->priv->ui_merge,
+		      NULL);
+
+	init_normal_mode (t);
 }
 
 static void
 toolbar_init (Toolbar *t)
 {
-        t->priv = g_new0 (ToolbarPrivate, 1);
+	t->priv = EPHY_TOOLBAR_GET_PRIVATE (t);
 
 	t->priv->window = NULL;
 	t->priv->ui_merge = NULL;
 	t->priv->visibility = TRUE;
-	t->priv->can_set_location = TRUE;
+	t->priv->updating_address = FALSE;
 }
 
 static void
 toolbar_finalize (GObject *object)
 {
-	Toolbar *t;
-	ToolbarPrivate *p;
-	EggMenuMerge *merge;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_TOOLBAR (object));
-
-	t = TOOLBAR (object);
-	p = t->priv;
-	merge = EGG_MENU_MERGE (t->priv->window->ui_merge);
-
-        g_return_if_fail (p != NULL);
+	Toolbar *t = EPHY_TOOLBAR (object);
 
+	/* FIXME: why not at the end? */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
 	g_object_unref (t->priv->action_group);
-	egg_menu_merge_remove_action_group (merge, t->priv->action_group);
-
-        g_free (t->priv);
 
 	LOG ("Toolbar finalized")
 }
@@ -558,87 +557,63 @@ toolbar_finalize (GObject *object)
 Toolbar *
 toolbar_new (EphyWindow *window)
 {
-	Toolbar *t;
-
-	t = TOOLBAR (g_object_new (TOOLBAR_TYPE,
-				   "EphyWindow", window,
-				   NULL));
-
-	g_return_val_if_fail (t->priv != NULL, NULL);
-
-	return t;
-}
-
-static void
-location_finished_cb (GtkWidget *location, GtkWidget *toolbar)
-{
-	gtk_widget_hide (toolbar);
-
-	g_signal_handlers_disconnect_by_func (G_OBJECT (location),
-                                              G_CALLBACK (location_finished_cb),
-                                              toolbar);
+	return EPHY_TOOLBAR (g_object_new (EPHY_TYPE_TOOLBAR,
+					   "window", window,
+					   NULL));
 }
 
 void
 toolbar_activate_location (Toolbar *t)
 {
-	GtkWidget *location;
-	GtkWidget *location_tb;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
-	location = get_location_entry (t);
-	g_return_if_fail (location != NULL);
+	action_group = t->priv->action_group;
+	action = gtk_action_group_get_action (action_group, "Location");
 
-	location_tb = gtk_widget_get_ancestor (location, EGG_TYPE_TOOLBAR);
-	g_return_if_fail (location_tb != NULL);
-
-	if (!GTK_WIDGET_VISIBLE (location_tb))
-	{
-		g_signal_connect (location, "finished",
-				  G_CALLBACK (location_finished_cb), location_tb);
-		gtk_widget_show (location_tb);
-	}
-
-	ephy_location_entry_activate
-		(EPHY_LOCATION_ENTRY(location));
+	gtk_action_activate (action);
 }
 
 void
 toolbar_spinner_start (Toolbar *t)
 {
-	EggActionGroup *action_group;
-	EggAction *action;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
 	action_group = t->priv->action_group;
-	action = egg_action_group_get_action (action_group, "Spinner");
+	action = gtk_action_group_get_action (action_group, "Spinner");
 	g_object_set (action, "throbbing", TRUE, NULL);
 }
 
 void
 toolbar_spinner_stop (Toolbar *t)
 {
-	EggActionGroup *action_group;
-	EggAction *action;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
 	action_group = t->priv->action_group;
-	action = egg_action_group_get_action (action_group, "Spinner");
+	action = gtk_action_group_get_action (action_group, "Spinner");
 	g_object_set (action, "throbbing", FALSE, NULL);
 }
 
 void
 toolbar_set_location (Toolbar *t,
-		      const char *alocation)
+		      const char *address)
 {
-	GtkWidget *location;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
-	if (t->priv->can_set_location)
-	{
-		location = get_location_entry (t);
-		g_return_if_fail (location != NULL);
+	LOG ("toolbar set location %s", address)
+	LOG ("updating is %d", t->priv->updating_address)
 
-		ephy_location_entry_set_location
-			(EPHY_LOCATION_ENTRY (location),
-			 alocation ? alocation : "");
-	}
+	if (t->priv->updating_address) return;
+
+	action_group = t->priv->action_group;
+	action = gtk_action_group_get_action (action_group, "Location");
+
+	t->priv->updating_address = TRUE;
+	ephy_location_action_set_address (EPHY_LOCATION_ACTION (action), address);
+	t->priv->updating_address = FALSE;
 }
 
 void
@@ -646,51 +621,40 @@ toolbar_update_favicon (Toolbar *t)
 {
 	EphyTab *tab;
 	const char *url;
-	EggActionGroup *action_group;
-	EggAction *action;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
 	tab = ephy_window_get_active_tab (t->priv->window);
 	url = ephy_tab_get_icon_address (tab);
 	action_group = t->priv->action_group;
-	action = egg_action_group_get_action (action_group, "Favicon");
+	action = gtk_action_group_get_action (action_group, "Favicon");
 	g_object_set (action, "icon", url, NULL);
 }
 
-char *
+const char *
 toolbar_get_location (Toolbar *t)
 {
-	GtkWidget *location;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
-	location = get_location_entry (t);
-	g_return_val_if_fail (location != NULL, NULL);
+	action_group = t->priv->action_group;
+	action = gtk_action_group_get_action (action_group, "Location");
 
-	return ephy_location_entry_get_location
-		(EPHY_LOCATION_ENTRY (location));
-}
-
-void
-toolbar_clear_location_history (Toolbar *t)
-{
-	GtkWidget *location;
-
-	location = get_location_entry (t),
-	g_return_if_fail (location != NULL);
-
-	ephy_location_entry_clear_history (EPHY_LOCATION_ENTRY (location));
+	return ephy_location_action_get_address (EPHY_LOCATION_ACTION (action));
 }
 
 void
 toolbar_update_navigation_actions (Toolbar *t, gboolean back, gboolean forward, gboolean up)
 {
-	EggActionGroup *action_group;
-	EggAction *action;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
 	action_group = t->priv->action_group;
-	action = egg_action_group_get_action (action_group, "NavigationBack");
+	action = gtk_action_group_get_action (action_group, "NavigationBack");
 	g_object_set (action, "sensitive", back, NULL);
-	action = egg_action_group_get_action (action_group, "NavigationForward");
+	action = gtk_action_group_get_action (action_group, "NavigationForward");
 	g_object_set (action, "sensitive", forward, NULL);
-	action = egg_action_group_get_action (action_group, "NavigationUp");
+	action = gtk_action_group_get_action (action_group, "NavigationUp");
 	g_object_set (action, "sensitive", up, NULL);
 }
 
@@ -702,7 +666,8 @@ toolbar_set_visibility (Toolbar *t,
 	EphyToolbarsModel *model;
 	int i, n_toolbars;
 
-	model = ephy_shell_get_toolbars_model (ephy_shell);
+	model = EPHY_TOOLBARS_MODEL
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 	n_toolbars = egg_toolbars_model_n_toolbars
 		(EGG_TOOLBARS_MODEL (model));
 
@@ -745,10 +710,10 @@ toolbar_set_visibility (Toolbar *t,
 void
 toolbar_update_zoom (Toolbar *t, float zoom)
 {
-	EggActionGroup *action_group;
-	EggAction *action;
+	GtkActionGroup *action_group;
+	GtkAction *action;
 
 	action_group = t->priv->action_group;
-	action = egg_action_group_get_action (action_group, "Zoom");
+	action = gtk_action_group_get_action (action_group, "Zoom");
 	g_object_set (action, "zoom", zoom, NULL);
 }
